﻿using System.Text;

using ZXR.Core;
using ZXR.IO;

using CAUtility.Logic.PostThread;
using CAUtility.Logic.BBS;
using CAUtility.Plugin;

namespace CAUtility.BuiltinPlugin
{
    internal class Forum : ContentPluginBase, IContentInlinePlugin
    {

        private int QueryString_PageIndex = 0;

        public string RegionString
        {
            get { return @"^(Forum\()(\s*[0-9]{1,}\s*|\s*[0-9]{1,}\s*[,]\s*[0-9]{1,}\s*)(\))$"; }
        }

        public System.Collections.Generic.List<System.Web.UI.Control> ConvertControls(params string[] param)
        {
            if (ZXR.Core.Validate.ValidateInteger(System.Web.HttpContext.Current.Request.QueryString["Page"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_PageIndex = System.Convert.ToInt32(System.Web.HttpContext.Current.Request.QueryString["Page"]);

            int forumParamID = System.Convert.ToInt32(param[0].Trim());
            int onePageMaxItemSize = param.Length == 2 ? System.Convert.ToInt32(param[1].Trim()) : CaSettings.ForumPageSize;

            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Forum.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.PageInstance.Header.Controls.Add(myHtmlLink1);

            StringBuilder genResult = new StringBuilder();
            int pageIndex = QueryString_PageIndex == 0 ? 1 : QueryString_PageIndex;

            ListPostThreadBizProcess threadParam = new ListPostThreadBizProcess();
            threadParam.ForumId = forumParamID;
            threadParam.PageIndex = pageIndex;
            threadParam.OnePageMaxItemsCount = onePageMaxItemSize;

            ListPostThreadBizLogic logic = new ListPostThreadBizLogic();
            ListPostThreadBizResult result = (ListPostThreadBizResult)logic.Execute(threadParam);

            base.PageDividerControl.Visible = true;
            base.PageDividerControl.ItemCount = result.TotalThreadCount;
            base.PageDividerControl.OnePageMaxItemCount = onePageMaxItemSize;

            string framePath = System.Web.HttpContext.Current.Server.MapPath("~/bin/BuiltinPlugin/Template/ForumFrame.html");
            string frame = FileIO.ReadWholeFile(framePath);
            string linePath = System.Web.HttpContext.Current.Server.MapPath("~/bin/BuiltinPlugin/Template/ForumLine.html");
            string line = FileIO.ReadWholeFile(linePath);

            StringBuilder lines = new StringBuilder();
            foreach (ListPostThreadBizResultElement ele in result.DataList)
            {
                lines.Append(
                    string.Format(line,
                        ele.ID,
                        ele.ForumId,
                        System.Web.HttpContext.Current.Request.QueryString["PageId"],
                        ele.PostTitle,
                        ele.ClickCount,
                        ele.ReplyCount)
                   );
            }
            genResult.Append("<div style='float: right;'>");

            genResult.Append(string.Format(
                  "<a href=\"PushlishThread.aspx?Action=Insert&ForumId={0}&PageId={1}\">{2}</a>",
                  forumParamID,
                   System.Web.HttpContext.Current.Request.QueryString["PageId"],
                   MessageManager.GetValue(MessageKey.PageD0042)
                   )
               );

            string currentCulture = SupportCulture.GetCultureFromUrl();
            if (string.IsNullOrEmpty(currentCulture))
                currentCulture = CaSettings.PageDefaultCulture;

            genResult.Append("&nbsp;&nbsp;<a href=\"");
            genResult.Append(CAUtility.Utility.UrlPathUtil.RootPath);
            genResult.Append("Rss2.0.aspx?PageID=");
            genResult.Append(System.Web.HttpContext.Current.Request.QueryString["PageId"]);
            genResult.Append("&Culture=");
            genResult.Append(currentCulture);
            genResult.Append("&Target=Forum");
            genResult.Append("&ID=");
            genResult.Append(forumParamID);
            genResult.Append("\"><img src=\"" + CAUtility.Utility.UrlPathUtil.RootPath + "App_Themes/Default/Images/System/rss.jpg\" height=\"15\" /></a>");
            genResult.Append("</div><br />");

            genResult.Append(
                string.Format(
                    frame,
                    MessageManager.GetValue(MessageKey.PageD0043),
                    MessageManager.GetValue(MessageKey.PageD0044),
                    MessageManager.GetValue(MessageKey.PageD0045),
                    lines.ToString())
                );

            System.Collections.Generic.List<System.Web.UI.Control> controls = new System.Collections.Generic.List<System.Web.UI.Control>();
            controls.Add(new System.Web.UI.LiteralControl(genResult.ToString()));
            return controls;
        }
    }
}
