﻿using System;
using System.Web;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Controls;

using CAUtility.Logic.Products;
using CAUtility.Plugin;

namespace CAUtility.BuiltinPlugin
{

    internal class Production : ContentPluginBase, IContentInlinePlugin
    {

        private const string ShoppingCartCookieName = "ShoppingCart";

        private string TransitionDefinition_Postback = "ShoppingCart.aspx";

        public string RegionString
        {
            get { return @"^(Production\(\s*)([0-9]{1,}\s*)(\))$"; }
        }

        public System.Collections.Generic.List<System.Web.UI.Control> ConvertControls(params string[] param)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Product.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.PageInstance.Header.Controls.Add(myHtmlLink1);

            System.Collections.Generic.List<System.Web.UI.Control> result = new System.Collections.Generic.List<System.Web.UI.Control>();

            result.Add(ShowProductNode(param[0]));

            return result;
        }

        MenuTable menuTableProductList = new MenuTable();

        private MenuTable ShowProductNode(string kindsId)
        {
            DisplayProductListBizProcess param = new DisplayProductListBizProcess();
            param.KindsID = kindsId;
            param.PageIndex = base.CurrentPageIndex;
            param.OnePageMaxItemsCount = CaSettings.ProductCountInPage;

            DisplayProductListBizLogic logic = new DisplayProductListBizLogic();
            DisplayProductListBizResult result = (DisplayProductListBizResult)logic.Execute(param);

            base.PageDividerControl.Visible = true;
            base.PageDividerControl.ItemCount = result.TotalProductCount;
            base.PageDividerControl.OnePageMaxItemCount = CaSettings.ProductCountInPage;

            menuTableProductList.InitTable(MenuTableDisplayType.RowDisplay);
            menuTableProductList.TurnBackNumber = CaSettings.ProductColumnCount;

            menuTableProductList.RowCount = result.DataList.Count / CaSettings.ProductColumnCount + 1;
            menuTableProductList.CssClass = "ProductListTable";
            menuTableProductList.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;

            foreach (DisplayProductListBizResultElement xx in result.DataList)
            {

                HidenInfoPanel productInfoPanel = new HidenInfoPanel();

                ImageCanClick image = new ImageCanClick();
                image.DefaultWidth = 120;
                image.Width = 120;
                image.ImageUrl = xx.ImagePath;
                image.PostBackUrl = "ProductDetail.aspx?ProductID=" + xx.ID + "&PageID=" + base.CurrentPageID;
                productInfoPanel.Controls.Add(image);

                Label outlineLabel = new Label();
                outlineLabel.Text = "<br />" + xx.Name;
                productInfoPanel.Controls.Add(outlineLabel);

                if (CaSettings.IsShoppingMode)
                {
                    if (xx.StockCount > 0)
                    {
                        Label priceLabel = new Label();
                        priceLabel.Text = "<br />" + MessageManager.GetValue(MessageKey.ShoppingD0004) + "：" + xx.Price.ToString() + "<br />";
                        productInfoPanel.Controls.Add(priceLabel);

                        Label stockCountLable = new Label();
                        stockCountLable.Text = MessageManager.GetValue(MessageKey.ShoppingD0010) + "：" + xx.StockCount.ToString() + "<br />";
                        productInfoPanel.Controls.Add(stockCountLable);

                        Label buyCountLabel = new Label();
                        buyCountLabel.Text = MessageManager.GetValue(MessageKey.ShoppingD0005) + "：";
                        productInfoPanel.Controls.Add(buyCountLabel);

                        ValidatorTextBox countTextBox = new ValidatorTextBox();
                        countTextBox.ID = "CountTextBox" + xx.ID;
                        countTextBox.Text = "1";
                        countTextBox.Width = new System.Web.UI.WebControls.Unit(20);
                        productInfoPanel.Controls.Add(countTextBox);

                        ValidatorButton buyButton = new ValidatorButton();
                        buyButton.ID = "BusButton" + xx.ID;
                        buyButton.Text = MessageManager.GetValue(MessageKey.ShoppingD0007);
                        buyButton.UserDatas["ProductID"] = xx.ID.ToString();
                        buyButton.Click += new EventHandler(buyButton_Click);
                        productInfoPanel.Controls.Add(buyButton);

                        productInfoPanel.Controls.Add(new System.Web.UI.LiteralControl("<br />"));
                    }
                    else
                    {
                        Label stockCountLable = new Label();
                        stockCountLable.Text = "<br />" + MessageManager.GetValue(MessageKey.ShoppingD0015);
                        stockCountLable.ForeColor = System.Drawing.Color.Red;
                        productInfoPanel.Controls.Add(stockCountLable);
                    }
                }
                menuTableProductList.AddControl(productInfoPanel, "ProductCell");
            }
            menuTableProductList.Flush();

            return menuTableProductList;
        }

        void buyButton_Click(object sender, EventArgs e)
        {

            if (ClientInfoContext.Current == null
                || ClientInfoContext.Current.UserPrincipal == null
                || ClientInfoContext.Current.UserPrincipal.IsLogined == false)
            {
                throw new ZxrException("[Production]"){ ErrorType = ErrorType.AccessDenied };
            }

            string productId = ((ValidatorButton)sender).UserDatas["ProductID"];
            ValidatorTextBox textbox = menuTableProductList.FindControl("CountTextBox" + productId) as ValidatorTextBox;

            if (textbox == null)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };

            CookieManager shoppingCookie = new CookieManager(ShoppingCartCookieName);

            string existAmountString = shoppingCookie.GetValue(productId);

            try
            {
                GetProductDetailsBizProcess param = new GetProductDetailsBizProcess();
                param.ID = productId;

                GetProductDetailsBizLogic logic = new GetProductDetailsBizLogic();
                GetProductDetailsBizResult result = (GetProductDetailsBizResult)logic.Execute(param);

                if (System.Convert.ToInt32(textbox.Text) > result.StockCount || System.Convert.ToInt32(textbox.Text) <= 0)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.ShoppingE0002));
                    return;
                }
            }
            catch
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.ShoppingE0003));
                return;
            }

            if (!string.IsNullOrEmpty(existAmountString))
            {
                shoppingCookie.SetValue(productId, (System.Convert.ToInt32(textbox.Text) + System.Convert.ToInt32(existAmountString)).ToString());
            }
            else
            {
                shoppingCookie.SetValue(productId, textbox.Text);
            }

            HttpContext.Current.Response.Redirect(TransitionDefinition_Postback + "?PageId=" + base.CurrentPageID);
        }

    }
}
