﻿using System;

using ZXR.Web.Controls;
using ZXR.Web.Validator;
using ZXR.Core;
using CAUtility.Logic.QuestionnaireManager.Question;
using CAUtility.Logic.QuestionnaireManager.QuestionItem;
using CAUtility.Plugin;
using ZXR.BusinessLogic;
using ZXR.DataAccess;
using ZXR.Web;

using CAUtility.Utility;
using CAUtility.Logic.QuestionnaireManager.Questionnaire;
using CAUtility.Logic.QuestionnaireManager.Response;

namespace CAUtility.BuiltinPlugin
{

    internal class Questionnaire : ContentPluginBase, IContentInlinePlugin
    {

        private const string FormSessionIdViewName = "{0}FormSessionId";

        private string formId_ = string.Empty;

        public string FormId
        {
            get { return formId_; }
            set { formId_ = value; }
        }

        private string formSessionId_ = string.Empty;

        private System.Web.UI.WebControls.Panel panel_ = new System.Web.UI.WebControls.Panel();

        public string FormSessionId
        {
            get
            {
                object obj = WebContext.Current.ViewState[string.Format(FormSessionIdViewName, this.ClientID)];
                return obj == null ? this.formSessionId_ : Convert.ToString(obj);
            }
            set
            {
                this.formSessionId_ = value;
                WebContext.Current.ViewState[string.Format(FormSessionIdViewName, this.ClientID)] = this.formSessionId_;
            }
        }

        public string RegionString
        {
            get { return @"(^(Questionnaire\()([0-9]{1,})(\))$)"; }
        }

        public System.Collections.Generic.List<System.Web.UI.Control> ConvertControls(params string[] param)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Form.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.PageInstance.Header.Controls.Add(myHtmlLink1);

            if (this.PageInstance.IsPostBack == false)
            {

                FormSessionId = Guid.NewGuid().ToString("N");
            }

            System.Collections.Generic.List<System.Web.UI.Control> result = new System.Collections.Generic.List<System.Web.UI.Control>();

            result.Add(createForm(param));
            return result;
        }

        private MenuTable createForm(string[] param)
        {
            this.FormId = param[0].Trim();

            ListQuestionBizProcess questionParam = new ListQuestionBizProcess();
            questionParam.QuestionnaireID = this.FormId;

            ListQuestionBizLogic questionLogic = new ListQuestionBizLogic();
            ListQuestionBizResult questionResult = (ListQuestionBizResult)questionLogic.Execute(questionParam);

            MenuTable resultTable = new MenuTable();
            resultTable.InitTable(MenuTableDisplayType.RowDisplay);
            resultTable.TurnBackNumber = 1;
            resultTable.RowCount = questionResult.DataList.Count * 2 + 2;
            resultTable.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;
            resultTable.Width = new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage);
            resultTable.CellPadding = 0;
            resultTable.CellSpacing = 0;

            foreach (ListQuestionBizResultElement qEle in questionResult.DataList)
            {
                Label contentLable = new Label();
                contentLable.Text = qEle.Contents;
                resultTable.AddControl(contentLable, "QuestionnaireTitle");

                if (string.Equals(qEle.QuestionType, "2"))//入力の場合
                {
                    System.Web.UI.WebControls.Panel Panel = new System.Web.UI.WebControls.Panel();

                    TextBox inputTextbox = new TextBox();
                    inputTextbox.ID = FormSessionId + "InputQuestion" + qEle.ID;
                    inputTextbox.Columns = 50;
                    inputTextbox.ValidationGroup = FormSessionId;

                    if (System.Convert.ToInt32(qEle.TextInputRows) > 1)
                        inputTextbox.TextMode = System.Web.UI.WebControls.TextBoxMode.MultiLine;

                    inputTextbox.Rows = System.Convert.ToInt32(qEle.TextInputRows);
                    Panel.Controls.Add(inputTextbox);

                    RequiredFieldValidator rfv = new RequiredFieldValidator();
                    rfv.ControlToValidate = inputTextbox.ID;
                    rfv.ValidationGroup = FormSessionId;
                    Panel.Controls.Add(rfv);

                    RangeStringValidator rsv = new RangeStringValidator();
                    rsv.ControlToValidate = inputTextbox.ID;
                    rsv.MinimumValue = 2;
                    rsv.MaximumValue = 120;
                    rsv.ValidationGroup = FormSessionId;
                    Panel.Controls.Add(rsv);

                    resultTable.AddControl(Panel, "QuestionnaireQuestion");
                }
                else
                {
                    ListQuestionItemBizProcess itemParam = new ListQuestionItemBizProcess();
                    itemParam.QuestionID = qEle.ID;

                    ListQuestionItemBizLogic itemLogic = new ListQuestionItemBizLogic();
                    ListQuestionItemBizResult itemResult = (ListQuestionItemBizResult)itemLogic.Execute(itemParam);

                    MenuTable subTable = new MenuTable();
                    subTable.InitTable(MenuTableDisplayType.RowDisplay);
                    subTable.TurnBackNumber = 1;
                    subTable.RowCount = itemResult.DataList.Count + 1;
                    subTable.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;
                    int index = 0;

                    System.Web.UI.WebControls.CheckBoxList cbl = new System.Web.UI.WebControls.CheckBoxList();
                    cbl.ValidationGroup = FormSessionId;
                    cbl.ID = FormSessionId + "SelectQuestion" + qEle.ID;
                    System.Web.UI.WebControls.Panel Panel = new System.Web.UI.WebControls.Panel();

                    bool hasRadioButton = false;
                    foreach (ListQuestionItemBizResultElement iEle in itemResult.DataList)
                    {
                        if (string.Equals(qEle.QuestionType, "0"))//単一選択
                        {
                            RadioButton rb = new RadioButton();
                            rb.ID = FormSessionId + "Item" + iEle.ID;
                            rb.Text = iEle.ItemContents;
                            rb.Checked = index == 0;

                            rb.GroupName = FormSessionId + "SelectQuestion" + qEle.ID;

                            subTable.AddControl(rb);

                            hasRadioButton = true;
                        }
                        else if (string.Equals(qEle.QuestionType, "1"))//複数選択
                        {
                            System.Web.UI.WebControls.ListItem cb = new System.Web.UI.WebControls.ListItem();
                            cb.Text = iEle.ItemContents;
                            cb.Value = FormSessionId + "Item" + iEle.ID;
                            cbl.Items.Add(cb);
                        }
                        index++;
                    }

                    if (hasRadioButton)
                    {

                        subTable.Flush();

                        resultTable.AddControl(subTable, "QuestionnaireQuestion");
                    }
                    else
                    {

                        Panel.Controls.Add(cbl);

                        CheckBoxListValidator cbv = new CheckBoxListValidator();
                        cbv.ValidationGroup = FormSessionId;
                        cbv.ControlToValidate = cbl.ID;
                        Panel.Controls.Add(cbv);

                        resultTable.AddControl(Panel, "QuestionnaireQuestion");
                    }
                }
            }

            if (CaSettings.IsFormUseVerifyImage)
            {

                VerifyCodeTextBox verifyCodeTextBox = new VerifyCodeTextBox();
                verifyCodeTextBox.ValidationGroup = FormSessionId;
                resultTable.AddControl(verifyCodeTextBox, "QuestionnaireButtonCell");
            }

            Button submitButton = new Button();

            submitButton.Text = MessageManager.GetValue(MessageKey.PageD0010);
            submitButton.ValidationGroup = FormSessionId;
            submitButton.CssClass = "PageButton";
            submitButton.Click += new System.EventHandler(submitButton_Click);

            resultTable.AddControl(submitButton, "QuestionnaireButtonCell");

            resultTable.Flush();

            return resultTable;
        }

        void submitButton_Click(object sender, System.EventArgs e)
        {

            DateTime dt = DateTime.Now;
            string sessionId = Guid.NewGuid().ToString("N");
            ZxrTransaction insertTransaction = new ZxrTransaction();

            foreach (string key in System.Web.HttpContext.Current.Request.Form.AllKeys)
            {
                int iIndex = key.IndexOf("InputQuestion");
                if (iIndex > 1)
                {
                    InsertResponseBizProcess param = new InsertResponseBizProcess();
                    string qNo = key.Substring(iIndex + 13);
                    param.QuestionID = qNo;
                    param.Content = System.Web.HttpContext.Current.Request.Form[key];
                    param.QuestionItemID = "0";
                    param.QuestionnaireID = this.FormId;
                    param.ResponseDatatime = dt.ToString();
                    param.ResponseSession = sessionId;

                    InsertResponseBizLogic logic = new InsertResponseBizLogic();
                    logic.JoinTransaction(insertTransaction);
                    logic.Execute(param);

                    continue;
                }

                int qIndex = key.IndexOf("SelectQuestion");
                if (qIndex > 1)
                {
                    string[] items = StringUtility.SpiltString(System.Web.HttpContext.Current.Request.Form[key], ",");

                    foreach (string item in items)
                    {
                        InsertResponseBizProcess param = new InsertResponseBizProcess();
                        string qNo = key.Substring(qIndex + 14);
                        if (qNo.IndexOf("$") > 0)
                        {
                            System.Web.UI.WebControls.CheckBoxList checkBoxList = this.PageInstance.FindControl(key) as System.Web.UI.WebControls.CheckBoxList;

                            param.QuestionID = qNo.Split('$')[0];
                            string temp = checkBoxList.Items[Convert.ToInt32(qNo.Split('$')[1])].Value;
                            param.QuestionItemID = temp.Substring(temp.IndexOf("Item") + 4);
                        }
                        else
                        {
                            param.QuestionID = qNo;
                            param.QuestionItemID = item.Substring(item.IndexOf("Item") + 4);
                        }
                        param.Content = " ";
                        param.QuestionnaireID = this.FormId;
                        param.ResponseDatatime = dt.ToString();
                        param.ResponseSession = sessionId;

                        InsertResponseBizLogic logic = new InsertResponseBizLogic();
                        logic.JoinTransaction(insertTransaction);
                        logic.Execute(param);
                    }
                }
            }

            insertTransaction.Commit();

            GetQuestionnaireNameBizProcess questionnaireParam = new GetQuestionnaireNameBizProcess();
            questionnaireParam.ID = this.FormId;

            GetQuestionnaireNameBizLogic questionnaireLogic = new GetQuestionnaireNameBizLogic();
            BizResult result = questionnaireLogic.Execute(questionnaireParam);

            string questionnaireTitle = result.ResultData.ToString();

            MailUtil mail = new MailUtil();
            mail.SendMail(
                 "【アンケート】「" + questionnaireTitle + "」の回答がある",
                 "「" + questionnaireTitle + "」に回答が来ました。"
                 );

            System.Web.HttpContext.Current.Response.Redirect("UserOperateResult.aspx?Result=true&MessageId=" + MessageKey.PageD0031);
        }

    }
}
