﻿using System;
using System.Reflection;

using ZXR.Data;
using ZXR.IO;
using ZXR.Core;

namespace CAUtility
{

    public class CaInitialization
    {

        private const string PLUGIN_INTERFACE_NAME = "CAUtility.Plugin.IContentInlinePlugin";

        private const string SIDE_PLUGIN_INTERFACE_NAME = "CAUtility.Plugin.ISideAreaPlugin";

        public static void InitApp()
        {
            string phyPath = System.Web.HttpContext.Current.Server.MapPath(CaSettings.BackupPath);
            if (!DirectoryIO.FolderExists(phyPath))
                DirectoryIO.CreateFolder(phyPath);
        }

        public static void InitPlugin()
        {

            Assembly assembly = Assembly.GetExecutingAssembly();

            Type[] ts = assembly.GetTypes();
            foreach (Type t in ts)
            {
                if (t.GetInterfaces().Length == 0)
                    continue;

                Type fInterface = t.GetInterfaces()[0];
                if (string.Equals(fInterface.FullName, PLUGIN_INTERFACE_NAME))
                {
                    CaContext.Current.PluginList.Add(t);
                }
                else if (string.Equals(fInterface.FullName, SIDE_PLUGIN_INTERFACE_NAME))
                {
                    CaContext.Current.SidePluginList.Add(t);
                }
            }
        }

        public static void InitUtilityContext()
        {
            XMLKeyOfValueData xk = new XMLKeyOfValueData(
                System.Web.HttpContext.Current.Server.MapPath("~/App_Data/ContentsSetting.xml")
            );

            SupportCulture.Init();

            if (!SupportCulture.LanguageList.Contains(CaSettings.PageDefaultCulture))
                SupportCulture.LanguageList.Add(CaSettings.PageDefaultCulture);

            CaContext.Current.CompanyName = xk.GetValue(ContentsSettingArgs.COMPANY_NAME);

            foreach (string culture in SupportCulture.LanguageList)
            {
                CaContext.Current.PageFooter[culture] = xk.GetValue(ContentsSettingArgs.FOOTER + culture);
                CaContext.Current.SideArea[culture] = xk.GetValue(ContentsSettingArgs.SIDE + culture);
                CaContext.Current.MemberTopPage[culture] = xk.GetValue(ContentsSettingArgs.MEMBER + culture);
            }
        }
    }
}
