﻿using System;
using System.Collections.Generic;

using ZXR.Core;

namespace CAUtility
{
    public class CaSettings
    {

        public static bool IsShoppingMode
        {
            get
            {
                return Convert.ToBoolean(SettingManager.GetSettingValue("IsShoppingMode"));
            }
        }

        public static bool EnableProductInfo
        {
            get
            {
                return Convert.ToBoolean(SettingManager.GetSettingValue("EnableProductInfo"));
            }
        }

        public static int ProductColumnCount
        {
            get
            {
                return Convert.ToInt32(SettingManager.GetSettingValue("ProductColumnCount"));
            }
        }

        public static bool IsSiteOpen
        {
            get
            {
                return Convert.ToBoolean(SettingManager.GetSettingValue("IsSiteOpen"));
            }
        }

        public static bool AllowRegist
        {
            get
            {
                return Convert.ToBoolean(SettingManager.GetSettingValue("AllowRegist"));
            }
        }

        public static int ProductCountInPage
        {
            get
            {
                string result = SettingManager.GetSettingValue("ProductCountInPage");

                if (string.IsNullOrEmpty(result))
                    return 0;
                else
                    return Convert.ToInt32(result);
            }
        }

        public static int ForumPageSize
        {
            get
            {
                string result = SettingManager.GetSettingValue("ForumPageSize");

                if (string.IsNullOrEmpty(result))
                    return 10;
                else
                    return Convert.ToInt32(result);
            }
        }

        public static int NewsCountInPage
        {
            get
            {
                int result = Convert.ToInt32(SettingManager.GetSettingValue("NewsCountInPage"));

                if (result == 0)
                    result = 1;

                return result;
            }
        }

        public static int AdminTableMaxDataCount
        {
            get
            {
                int result = Convert.ToInt32(SettingManager.GetSettingValue("AdminTableMaxDataCount"));

                if (result == 0)
                    result = 5;

                return result;
            }
        }

        public static int AdminTablePageDividerDisplayCount
        {
            get
            {
                int result = Convert.ToInt32(SettingManager.GetSettingValue("AdminTablePageDividerDisplayCount"));

                if (result == 0)
                    result = 5;

                return result;
            }
        }

        public static int UserPasswordExpires
        {
            get
            {
                int result = Convert.ToInt32(SettingManager.GetSettingValue("UserPasswordExpires"));

                return result;
            }
        }

        public static string AdminEmail
        {
            get
            {
                return SettingManager.GetSettingValue("AdminEmail");
            }
        }

        public static string PageDefaultCulture
        {
            get
            {
                string result = SettingManager.GetSettingValue("PageDefaultCulture");

                if (string.IsNullOrEmpty(result))
                    return "ja-JP";
                else
                    return result;
            }
        }

        public static string AdminCulture
        {
            get
            {
                string result = SettingManager.GetSettingValue("AdminCulture");

                if (string.IsNullOrEmpty(result))
                {
                    result = CoreSettings.CoreCulture;

                    if (string.IsNullOrEmpty(result))
                        return "ja-JP";
                    else
                        return result;
                }
                else
                    return result;
            }
        }

        public static string BackupPath
        {
            get
            {
                string result = SettingManager.GetSettingValue("BackupPath");

                if (string.IsNullOrEmpty(result))
                    result = "~/Backup/";

                return result;
            }
        }

        public static string SkinDirectory
        {
            get
            {
                string result = SettingManager.GetSettingValue("SkinDirectory");

                if (string.IsNullOrEmpty(result))
                    result = "~/App_Themes/Soffic/";

                return result;
            }
        }

        public static int AdminPageUserGroup
        {
            get
            {
                int result = Convert.ToInt32(SettingManager.GetSettingValue("AdminPageUserGroup"));

                if (result == 0)
                    result = 1;

                return result;
            }
        }

        public static List<string> InternalPageUserGroup
        {
            get
            {
                return SettingManager.GetListValue("InternalPageUserGroup");
            }
        }

        public static int NewRegistUserGroup
        {
            get
            {
                string result = SettingManager.GetSettingValue("NewRegistUserGroup");

                if (string.IsNullOrEmpty(result))
                    return 9;
                else
                    return Convert.ToInt32(result);
            }
        }

        public static bool IsBBsUseVerifyImage
        {
            get
            {
                string result = SettingManager.GetSettingValue("IsBBsUseVerifyImage");

                if (string.IsNullOrEmpty(result))
                    return true;
                else
                    return Convert.ToBoolean(result);
            }
        }

        public static bool IsFormUseVerifyImage
        {
            get
            {
                string result = SettingManager.GetSettingValue("IsFormUseVerifyImage");

                if (string.IsNullOrEmpty(result))
                    return true;
                else
                    return Convert.ToBoolean(result);
            }
        }

        public static bool IsReservationUseVerifyImage
        {
            get
            {
                string result = SettingManager.GetSettingValue("IsReservationUseVerifyImage");

                if (string.IsNullOrEmpty(result))
                    return true;
                else
                    return Convert.ToBoolean(result);
            }
        }

        public static bool IsUserUseVerifyImage
        {
            get
            {
                string result = SettingManager.GetSettingValue("IsUserUseVerifyImage");

                if (string.IsNullOrEmpty(result))
                    return true;
                else
                    return Convert.ToBoolean(result);
            }
        }

        public static List<string> ForbidsNickName
        {
            get
            {
                return SettingManager.GetListValue("ForbidsNickName");
            }
        }

        public static string MailSmtpServerName
        {
            get { return SettingManager.GetSettingValue("MailSmtpServerName"); }
        }

        public static int MailSmtpServerPort
        {
            get
            {
                string result = SettingManager.GetSettingValue("MailSmtpServerPort");

                if (string.IsNullOrEmpty(result))
                    return 25;
                else
                    return Convert.ToInt32(result);
            }
        }

        public static string MailSmtpUsername
        {
            get { return SettingManager.GetSettingValue("MailSmtpUsername"); }
        }

        public static string MailSmtpPs
        {
            get { return SettingManager.GetCryptoSettingValue("MailSmtpPs"); }
        }
    }
}
