﻿
using System;

using ZXR.Data;
using ZXR.DataAccess;

namespace CAUtility.Dal.PostThread
{

    public class ListPostThreadDalFetch : DalSelectFetch
    {

        public ListPostThreadDalFetch()
        {

        }

        protected override void SetSelectCommand(FetchProcessParam param)
        {
            if (((ListPostThreadDalProcess)param).PageIndex == 1)
            {
                SelectCommand = @"
select 
    top " + ((ListPostThreadDalProcess)param).OnePageMaxItemsCount + @"
    id,
    forumid,
    parentthreadid,
    username,
    posttitle,
    postcontent,
    IIf([username]='', usernickname, (select friendlyname from userinfo where userinfo.username=postthread.username)) as nickname,
    postdatetime,
    updatedatetime,
    clickcount,
    (select Count(*) from postthread as replayPost where replayPost.parentthreadid = postthread.id) as replyCount
from postthread
where parentthreadid = 0 and forumid = " + ((ListPostThreadDalProcess)param).ForumId + " order by postdatetime desc";
            }
            else
            {
                SelectCommand = @"
select 
    top " + ((ListPostThreadDalProcess)param).OnePageMaxItemsCount + @"
    id,
    forumid,
    parentthreadid,
    username,
    posttitle,
    postcontent,
    IIf([username]='', usernickname, (select friendlyname from userinfo where userinfo.username=postthread.username)) as nickname,
    postdatetime,
    updatedatetime,
    clickcount,
    (select Count(*) from postthread as replayPost where replayPost.parentthreadid = postthread.id) as replyCount
from postthread
where parentthreadid = 0 and forumid = " + ((ListPostThreadDalProcess)param).ForumId + " and id not in (select top " +
                                      ((((ListPostThreadDalProcess)param).PageIndex - 1) * ((ListPostThreadDalProcess)param).OnePageMaxItemsCount)
                                         + @" Id from postthread where parentthreadid = 0 and forumid = " + ((ListPostThreadDalProcess)param).ForumId + " order by postdatetime desc) order by postdatetime desc";
            }
        }

        protected override DalSelectResult SelectResultProcessing(DalDataContainer dataContainer)
        {
            ListPostThreadDalResult result = new ListPostThreadDalResult();

            foreach (Row row in dataContainer.Rows)
            {
                ListPostThreadDalResultElement param = new ListPostThreadDalResultElement();
                param.ID = Convert.ToInt32(row[0].ToString());
                param.ForumId = Convert.ToInt32(row[1].ToString());
                param.ParentThreadId = Convert.ToInt32(row[2].ToString());
                param.UserName = row[3].ToString();
                param.PostTitle = row[4].ToString();
                param.PostContent = row[5].ToString();
                param.UserNickName = row[6].ToString();
                param.PostDatetime = Convert.ToDateTime(row[7].ToString());

                if (!string.IsNullOrEmpty(row[8].ToString()))
                    param.UpdateDatetime = Convert.ToDateTime(row[8].ToString());
                else
                    param.UpdateDatetime = DateTime.MinValue;

                param.ClickCount = Convert.ToInt32(row[9].ToString());

                param.ReplyCount = Convert.ToInt32(row[10].ToString());

                result.Add(param);
            }

            return result;
        }
    }
}
