﻿
using System;

using ZXR.Data;
using ZXR.DataAccess;

namespace CAUtility.Dal.ReservationData
{

    public class SearchReservationDataDalFetch : DalSelectFetch
    {

        public SearchReservationDataDalFetch()
        {

        }

        protected override void SetSelectCommand(FetchProcessParam param)
        {
            if (ZXR.Core.CoreSettings.DbType == DbType.Access)
            {
                SelectCommand = @"
select 
    reservationdata.id, itemid, begindatetime, enddatetime,
    reservationtime, username, userphone, usermail,
    reservationnumber , reservationitem.iname,
    reservationdata.status ,
    reservationitem.runit
from 
    reservationdata inner join reservationitem on reservationitem.id = reservationdata.itemid

where begindatetime > #" + DateTime.Now.AddMonths(-1) +"#";

                if (string.Equals(((SearchReservationDataDalProcess)param).Status, "All"))
                {
                    SelectCommand += " and (reservationdata.status = '" + DataStatus.Normal + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.Cancel + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.DummyDelete + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.PeriodPassed + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.Processing + "') ";
                }
                else
                {
                    SelectCommand += " and reservationdata.status = '" + ((SearchReservationDataDalProcess)param).Status + "' ";
                }

                if (!string.IsNullOrEmpty(((SearchReservationDataDalProcess)param).ReservationNumber))
                {
                    SelectCommand += " and reservationdata.reservationnumber = '"+ ((SearchReservationDataDalProcess)param).ReservationNumber + "'";
                }

                if (!string.IsNullOrEmpty(((SearchReservationDataDalProcess)param).UserName))
                {
                    SelectCommand += " and reservationdata.username = '"+ ((SearchReservationDataDalProcess)param).UserName + "'";
                }

                if (((SearchReservationDataDalProcess)param).RegistDate > DateTime.MinValue )
                {
                    SelectCommand += " and datediff ( 'd' , reservationdata.reservationtime , #"+ ((SearchReservationDataDalProcess)param).RegistDate.ToString("yyyy/MM/dd") + "#) = 0";
                }

                SelectCommand += " order by reservationtime desc;";
            }
            else
            {
                SelectCommand = @"
select 
    reservationdata.id, itemid, begindatetime, enddatetime,
    reservationtime, username, userphone, usermail,
    reservationnumber , reservationitem.iname,
    reservationdata.status ,
    reservationitem.runit
from 
    reservationdata inner join reservationitem on reservationitem.id = reservationdata.itemid

where begindatetime > '" + DateTime.Now.AddMonths(-1) +"'";

                if (string.Equals(((SearchReservationDataDalProcess)param).Status, "All"))
                {
                    SelectCommand += " and (reservationdata.status = '" + DataStatus.Normal + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.Cancel + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.DummyDelete + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.PeriodPassed + "' or ";
                    SelectCommand += " reservationdata.status = '" + DataStatus.Processing + "') ";
                }
                else
                {
                    SelectCommand += " and status = '" + ((SearchReservationDataDalProcess)param).Status + "' ";
                }

                if (!string.IsNullOrEmpty(((SearchReservationDataDalProcess)param).ReservationNumber))
                {
                    SelectCommand += " and reservationdata.reservationnumber = '"+ ((SearchReservationDataDalProcess)param).ReservationNumber + "'";
                }

                if (!string.IsNullOrEmpty(((SearchReservationDataDalProcess)param).UserName))
                {
                    SelectCommand += " and reservationdata.username = '"+ ((SearchReservationDataDalProcess)param).UserName + "'";
                }

                if (((SearchReservationDataDalProcess)param).RegistDate > DateTime.MinValue )
                {
                    SelectCommand += " and datediff(d, reservationdata.reservationtime, '" + ((SearchReservationDataDalProcess)param).RegistDate.ToString("yyyy/MM/dd") + "') = 0";
                }

                SelectCommand += " order by reservationtime desc;";
            }
        }

        protected override DalSelectResult SelectResultProcessing(DalDataContainer dataContainer)
        {
            SearchReservationDataDalResult result = new SearchReservationDataDalResult();

            foreach (Row row in dataContainer.Rows)
            {
                SearchReservationDataDalResultElement param = new SearchReservationDataDalResultElement();
                param.ID = row[0].ToString();
                param.ItemID = row[1].ToString();
                param.ReservationBegin = Convert.ToDateTime(row[2].ToString());
                param.ReservationEnd = Convert.ToDateTime(row[3].ToString());
                param.ReservateRegDate = Convert.ToDateTime(row[4].ToString());
                param.UserName = row[5].ToString();
                param.UserPhone = row[6].ToString();
                param.UserMail = row[7].ToString();
                param.ReservationNumber = row[8].ToString();
                param.ItemName = row[9].ToString();
                param.Status = row[10].ToString();
                param.ReservationType = Convert.ToInt32(row[11].ToString());

                result.Add(param);
            }

            return result;
        }
    }
}
