﻿
using System;
using System.Data;
using System.Collections.Generic;
using ZXR.Core;

using ZXR.BusinessLogic;
using ZXR.DataAccess;
using ZXR.Security;
using CAUtility.Dal.ReservationItem;
using CAUtility.Dal.ReservationData;

namespace CAUtility.Logic.ReservationItem
{

    public class DisplayReservationBizLogic : BizLogic
    {

        private List<RangeDateTime> reservatedDatetimeList_ = null;

        public DisplayReservationBizLogic()
        {

        }

        protected override BizResult BusinessLogicExecute(BizProcessParm param)
        {
            DisplayReservationBizResult result = new DisplayReservationBizResult();

            GetItemDetailDalResult itemDetail = GetItemDetail(((DisplayReservationBizProcess)param).ItemId);

            GetReservatedList(itemDetail.ID);
            result.ReservatedDatetimeList = reservatedDatetimeList_;

            DataSet ds = GetReservationDate(itemDetail);

            result.DateList = ds.Tables["Date"];

            result.Unit = Convert.ToInt32(itemDetail.Unit);

            result.BeginTimeList = ds.Tables["BeginTime"];

            result.EndTimeList = ds.Tables["EndTime"];

            result.ItemName = itemDetail.Name;
            result.ItemDetails = itemDetail.ItemDetail;

            result.HolidayList = itemDetail.HolidayList;

            result.DatetimeLength = itemDetail.DatetimeLength;

            result.SimultaneousNumber = Convert.ToInt32(itemDetail.SimultaneousNumber);

            return result;
        }

        private DataSet GetReservationDateOnly(GetItemDetailDalResult itemDetail)
        {
            DataSet ds = new DataSet();

            DataTable reservationDate = new DataTable("Date");
            ds.Tables.Add(reservationDate);

            return ds;
        }

        private DataSet GetReservationDate(GetItemDetailDalResult itemDetail)
        {
            DataSet ds = new DataSet();

            DataTable reservationBeginTime = new DataTable("BeginTime");
            ds.Tables.Add(reservationBeginTime);

            DataColumn startCol = new DataColumn();
            startCol.ColumnName = "Start";
            DataColumn startValueCol = new DataColumn();
            startValueCol.ColumnName = "StartValue";
            DataColumn dateCol = new DataColumn();
            dateCol.ColumnName = "Date";

            reservationBeginTime.Columns.Add(startCol);
            reservationBeginTime.Columns.Add(startValueCol);
            reservationBeginTime.Columns.Add(dateCol);

            DataTable reservationEndTime = new DataTable("EndTime");
            ds.Tables.Add(reservationEndTime);
            DataColumn endCol = new DataColumn();
            endCol.ColumnName = "End";
            reservationEndTime.Columns.Add(endCol);
            DataColumn endValueCol = new DataColumn();
            endValueCol.ColumnName = "EndValue";
            reservationEndTime.Columns.Add(endValueCol);
            DataColumn endDateColu = new DataColumn();
            endDateColu.ColumnName = "Date";
            reservationEndTime.Columns.Add(endDateColu);

            DataTable reservationDate = new DataTable("Date");
            ds.Tables.Add(reservationDate);

            DataColumn dateColu = new DataColumn();
            dateColu.ColumnName = "Date";
            reservationDate.Columns.Add(dateColu);
            DataColumn dateValueColu = new DataColumn();
            dateValueColu.ColumnName = "DateValue";
            reservationDate.Columns.Add(dateValueColu);

            int dayCount = 0;

            if (Convert.ToInt32(itemDetail.Unit) >= 0)
                dayCount = 0;
            else if (Convert.ToInt32(itemDetail.Unit) < 0)
                dayCount = 1;

            while (reservationDate.Rows.Count <= Convert.ToInt32(itemDetail.DisplayDateCount))
            {
                DateTime dt = DateTime.Now + TimeSpan.FromDays(Convert.ToDouble(dayCount));

                if (!string.IsNullOrEmpty(itemDetail.HolidayList))
                {
                    bool isHoliday = false;
                    foreach (CycleDatetime zxrDatetime in CycleDatetime.ParseListFormat(itemDetail.HolidayList))
                    {
                        if (CycleDatetime.Compare(dt, zxrDatetime))
                        {
                            isHoliday = true;
                            break;
                        }
                    }

                    if (isHoliday)
                    {
                        dayCount++;
                        continue;
                    }
                }

                if (Convert.ToInt32(itemDetail.Unit) == 1 || Convert.ToInt32(itemDetail.Unit) == 0)
                {
                    DateTime begin = Convert.ToDateTime(itemDetail.ReservationBeginTime);
                    begin = dt.Date + begin.TimeOfDay;

                    DateTime end = Convert.ToDateTime(itemDetail.ReservationEndTime);
                    end = dt.Date + end.TimeOfDay;

                    int oneDayCount = 0;
                    while (DatetimeUtil.ComparerTime(begin, end) == -1 || DatetimeUtil.ComparerTime(begin, end) == 0)
                    {

                        if (Convert.ToInt32(itemDetail.Unit) == 1 && !string.IsNullOrEmpty(itemDetail.IntervalTime))
                        {
                            RangeDateTime rd = RangeDateTime.Parse(itemDetail.IntervalTime);

                            DateTime tempEnd = begin + TimeSpan.FromMinutes(Convert.ToInt32(itemDetail.DatetimeLength));
                            if (DatetimeUtil.ComparerTime(tempEnd, rd.Start) == 1
                                && DatetimeUtil.ComparerTime(tempEnd, rd.End) == -1)
                            {
                                begin = rd.End;
                            }
                        }

                        if (Convert.ToInt32(itemDetail.Unit) == 1 && !IsReservatedTime(reservatedDatetimeList_, begin, Convert.ToInt32(itemDetail.SimultaneousNumber)))
                        {
                            DataRow beginRow = reservationBeginTime.NewRow();
                            beginRow["Date"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                            beginRow["Start"] = begin.ToString("HH:mm");
                            beginRow["StartValue"] = begin.ToString("HH:mm");
                            reservationBeginTime.Rows.Add(beginRow);

                            oneDayCount++;
                        }
                        else if (Convert.ToInt32(itemDetail.Unit) == 0 && !IsReservatedRangeTime(reservatedDatetimeList_, begin, Convert.ToInt32(itemDetail.SimultaneousNumber)))
                        {
                            DataRow beginRow = reservationBeginTime.NewRow();
                            beginRow["Date"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                            beginRow["Start"] = begin.ToString("HH:mm");
                            beginRow["StartValue"] = begin.ToString("HH:mm");
                            reservationBeginTime.Rows.Add(beginRow);

                            oneDayCount++;
                        }

                        if (DatetimeUtil.ComparerTime(begin, begin.AddMinutes(Convert.ToInt32(itemDetail.DatetimeLength))) == -1)
                        {
                            begin = begin.AddMinutes(Convert.ToInt32(itemDetail.DatetimeLength));
                        }
                        else
                        {
                            oneDayCount++;
                            break;
                        }
                    }

                    if (oneDayCount > 0)
                    {

                        DataRow dateRow = reservationDate.NewRow();
                        dateRow["Date"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        dateRow["DateValue"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        reservationDate.Rows.Add(dateRow);
                    }
                }
                else if (Convert.ToInt32(itemDetail.Unit) == -1)//終日予約
                {
                    if (!IsReservatedData(reservatedDatetimeList_, dt, Convert.ToInt32(itemDetail.SimultaneousNumber)))
                    {

                        DataRow dateRow = reservationDate.NewRow();
                        dateRow["Date"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        dateRow["DateValue"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        reservationDate.Rows.Add(dateRow);
                    }
                }
                else if (Convert.ToInt32(itemDetail.Unit) == -2)//連続日
                {
                    if (!IsReservatedRangeData(reservatedDatetimeList_, dt, Convert.ToInt32(itemDetail.SimultaneousNumber)))
                    {
                        DataRow beginRow = reservationBeginTime.NewRow();
                        beginRow["Date"] = FormatDateTime.GetDate(dt.Date, "/", "/");

                        beginRow["Start"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        beginRow["StartValue"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        reservationBeginTime.Rows.Add(beginRow);

                        DataRow endRow = reservationEndTime.NewRow();
                        endRow["Date"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        endRow["End"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        endRow["EndValue"] = FormatDateTime.GetDate(dt.Date, "/", "/");
                        reservationEndTime.Rows.Add(endRow);

                        if (reservationBeginTime.Rows.Count > Convert.ToInt32(itemDetail.DisplayDateCount))
                        {
                            break;
                        }
                    }
                }

                dayCount++;
            }

            return ds;
        }

        private bool IsReservatedTime(List<RangeDateTime> list, DateTime datetime, int simultaneousNumber)
        {
            int count = list.FindAll(delegate(RangeDateTime rd)
            {
                return (DateTime.Compare(rd.Start, datetime) == 0);
            }
            ).Count;

            if (count >= simultaneousNumber)
                return true;
            else
                return false;
        }

        private bool IsReservatedData(List<RangeDateTime> list, DateTime datetime, int simultaneousNumber)
        {
            int count = list.FindAll(delegate(RangeDateTime rd)
            {
                return (DatetimeUtil.ComparerDate(rd.Start, datetime) == 0);
            }
            ).Count;

            if (count >= simultaneousNumber)
                return true;
            else
                return false;
        }

        private bool IsReservatedRangeData(List<RangeDateTime> list, DateTime datetime, int simultaneousNumber)
        {
            int count = list.FindAll(delegate(RangeDateTime rd)
            {
                return rd.IsInDateRange(datetime);
            }
            ).Count;

            if (count >= simultaneousNumber)
                return true;
            else
                return false;
        }

        private bool IsReservatedRangeTime(List<RangeDateTime> list, DateTime datetime, int simultaneousNumber)
        {
            int count = list.FindAll(delegate(RangeDateTime rd)
            {
                return rd.IsInTimeRange(datetime, true);
            }
            ).Count;

            if (count >= simultaneousNumber)
                return true;
            else
                return false;
        }

        private void GetReservatedList(string itemId)
        {
            reservatedDatetimeList_ = new List<RangeDateTime>();

            ListDataDalProcess getParam = new ListDataDalProcess();
            getParam.ItemID = itemId;
            getParam.IsFromNow = true;

            DalSelectFetch fetch = new ListDataDalFetch();
            ListDataDalResult fetchResult = (ListDataDalResult)fetch.SelectExecuteLogic(getParam);

            foreach (ListDataDalResultElement ele in fetchResult)
            {
                reservatedDatetimeList_.Add(new RangeDateTime(ele.ReservationBegin, ele.ReservationEnd));
            }
        }

        private GetItemDetailDalResult GetItemDetail(string itemId)
        {
            GetItemDetailDalProcess getParam = new GetItemDetailDalProcess();
            getParam.ID = itemId;

            DalSelectFetch fetch = new GetItemDetailDalFetch();
            GetItemDetailDalResult result = (GetItemDetailDalResult)fetch.SelectExecuteLogic(getParam);

            return result;
        }
    }
}
