﻿using System;
using System.Collections.Generic;

using ZXR.Data;
using ZXR.Core;
using ZXR.DataAccess;
using ZXR.BusinessLogic;

using CAUtility.Logic.Page;

namespace CAUtility.Menu
{
    public class PageInfoMenu
    {

        private static string menu_ = string.Empty;

        private static string productPageName_ = string.Empty;

        private static TreeData menuTreeData_ = null;

        private static LinkedList<TreeDataNode> naviMenu_ = new LinkedList<TreeDataNode>();

        private static string homeString_ = string.Empty;

        static PageInfoMenu()
        {
           
        }

        public static void Init()
        {
            string culture = SupportCulture.GetCultureFromUrl();
            GetPageListBizProcess param = new GetPageListBizProcess();

            if (string.IsNullOrEmpty(culture))
                param.Culture = CaSettings.PageDefaultCulture;
            else
                param.Culture = culture;

            param.TopPageId = "";
            param.Status = DataStatus.Normal.ToString();
            param.IsShowInMenu = "1";

            BizLogic logic = new GetPageListBizLogic();
            GetPageListBizResult pageList = (GetPageListBizResult)logic.Execute(param);

            List<TreeDataNode> tempList = new List<TreeDataNode>();

            foreach (GetPageListBizResultElement ele in pageList.DataList)
            {
                TreeDataNode node = new TreeDataNode();
                node.ID = Int32.Parse(ele.ID);
                node.ParentID = Int32.Parse(ele.TopPageId);
                node.Value = ele.DisplayText;
                node["PageId"] = ele.ID;
                node["Status"] = ele.Status;
                node["IsSoweInMenu"] = ele.IsShowInMenu;
                node["LinkImage"] = ele.LinkImage;
                node.SortIndex = Int32.Parse(ele.PageOrder);

                tempList.Add(node);
            }

            menuTreeData_ = new TreeData();
            menuTreeData_.AddChildFromList(tempList);
        }

        public static string Navigation(int pageId)
        {

            string culture = SupportCulture.GetCultureFromUrl();
            if (string.IsNullOrEmpty(culture))
                MessageManager.CultureTarget = new System.Globalization.CultureInfo(CaSettings.AdminCulture);
            else
                MessageManager.CultureTarget = new System.Globalization.CultureInfo(culture);

            homeString_ = MessageManager.GetValue(MessageKey.PageD0036);

            naviMenu_ = new LinkedList<TreeDataNode>();

            foreach (TreeDataNode node in menuTreeData_)
            {
                if (node.ID == pageId)
                {
                    getNavi(node);
                    break;
                }
            }

            string result = "<a href=\"./\">" + homeString_ + "</a>";

            foreach (TreeDataNode node in naviMenu_)
            {
                result += " &gt; <a href=\"Page.aspx?PageID=" + node.ID + "\">" + node.Value + "</a>";
            }

            return result;
        }

        private static void getNavi(TreeDataNode node)
        {
            if (node.ParentID != -1)
            {
                foreach (TreeDataNode subNode in menuTreeData_)
                {
                    if (subNode.ID == node.ParentID)
                    {
                        naviMenu_.AddFirst(node);
                        getNavi(subNode);
                        break;
                    }
                }
            }
        }

        public static void GetPageMenu()
        {
            menu_ = "\r\n<ul id=\"TreeMenu\">\r\n";

            writeMenu(menuTreeData_.RootNode);

            menu_ += "</ul>\r\n";

            System.Web.HttpContext.Current.Response.Write(menu_);
        }

        public static string GetPageMenuHtmlTag()
        {
            menu_ = "\r\n<ul id=\"TreeMenu\">\r\n";

            writeMenu(menuTreeData_.RootNode);

            menu_ += "</ul>\r\n";

            return menu_;
        }

        private static void writeMenu(TreeDataNode node)
        {
            foreach (TreeDataNode subNode in node.Children)
            {
                menu_ += "\r\n    <li>";

                menu_ += "<a ";
                if (subNode.Children.Count > 0)
                {
                    menu_ += "class=\"SubMenuStyle\"";
                }

                menu_ += " href=\"Page.aspx?PageID=" + subNode["PageId"] + "\">";

                if (subNode["LinkImage"] != null && !string.IsNullOrEmpty(subNode["LinkImage"].ToString()))
                {
                    menu_ += "<img src=\"" + subNode["LinkImage"] + "\"/></a>";
                }
                else //独自リンク画像の設定がない場合、文字列でリンクを表示します。
                {
                    menu_ += subNode.Value + "</a>";
                }

                if (subNode.Children.Count > 0)
                {
                    menu_ += "\r\n    <ul>";
                    writeMenu(subNode);
                    menu_ += "    </ul>\r\n";
                }

                menu_ += "</li>\r\n";
            }

        }

    }
}