﻿using System;
using System.Collections.Generic;
using System.ComponentModel;

using ZXR.BusinessLogic;
using ZXR.Web.Pages;
using ZXR.Core;
using CAUtility.Logic.Page;

namespace CAUtility.Pages
{

    public abstract class PluginFunctionPage : ZxrPageBase
    {

        private const string HostPageIdViewName = "{0}HostPageId";

        private string hostPageId_ = "";

        [Browsable(false)]
        public string HostPageId
        {
            get
            {
                object obj = this.ViewState[string.Format(HostPageIdViewName, this.ID)];
                return obj == null ? this.hostPageId_ : Convert.ToString(obj);
            }
            private set
            {
                this.hostPageId_ = value;
                this.ViewState[string.Format(HostPageIdViewName, this.ID)] = this.hostPageId_;
            }
        }

        protected override void OnPreInit(EventArgs e)
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["PageID"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                this.HostPageId = Request.QueryString["PageID"];

            base.OnPreInit(e);
        }

        protected override void OnPreLoad(EventArgs e)
        {
            base.OnPreLoad(e);

            GetSinglePageBizProcess param = new GetSinglePageBizProcess();
            param.ID = this.HostPageId;

            BizLogic logic = new GetSinglePageBizLogic();
            GetSinglePageBizResult pageInfo_ = (GetSinglePageBizResult)logic.Execute(param);

            if (pageInfo_ == null || !string.Equals(pageInfo_.Status, ZXR.DataAccess.DataStatus.Normal.ToString()))
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }

            string disText = StringUtility.StringDecode(pageInfo_.Contents);
            CAUtility.Plugin.ContentConvertor cc = new CAUtility.Plugin.ContentConvertor();

            List<string> hostPagePluginList = new List<string>();
            int index = 0;
            foreach ( string plugin in cc.GetTargets(disText))
            {
                if (index % 2 != 0)
                    hostPagePluginList.Add(plugin);

                index++;
            }

            if (hostPagePluginList.Count == 0)
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
            else
            {
                if (!AuthValidate(hostPagePluginList))
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

        public abstract bool AuthValidate(List<string> hostPagePluginList);

    }
}
