﻿
using System;
using System.Web;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Pages;

using CAUtility.Logic.UserInfo;

namespace CAUtility.Pages
{

    public abstract class SecurityPage : ZxrPageBase
    {

        private const string UserInfoCookieName = "UserInfo";

        protected override void OnPreLoad(EventArgs e)
        {
            this.Culture = CaSettings.AdminCulture;
            CoreSettings.Culture = CaSettings.AdminCulture;

            if (DesignMode)
            {
                base.OnPreLoad(e);
                return;
            }

            if (ClientInfoContext.Current == null
                || ClientInfoContext.Current.UserPrincipal == null
                || ClientInfoContext.Current.UserPrincipal.IsLogined == false)
            {
                CookieManager userInfoCookie = new CookieManager(UserInfoCookieName);
                string userName = userInfoCookie.GetValue("UserName");
                string userToken = userInfoCookie.GetValue("UserToken");

                if (!string.IsNullOrEmpty(userName) && !string.IsNullOrEmpty(userToken))
                {
                    ValidationUserBizProcess param = new ValidationUserBizProcess();
                    param.UserToken = userToken;
                    param.UserName = userName;

                    ValidationUserBizLogic logic = new ValidationUserBizLogic();
                    ValidationUserBizResult result = (ValidationUserBizResult)logic.Execute(param);

                    if (result.Result == true)
                    {

                        ClientInfoContext.Current.UserPrincipal.IsLogined = true;
                        ClientInfoContext.Current.UserPrincipal.UserGroup = result.UserGroup;
                        ClientInfoContext.Current.UserPrincipal.UserToken = userToken;
                        ClientInfoContext.Current.UserPrincipal.UserName = userName;
                        ClientInfoContext.Current.UserPrincipal.FriendlyName = result.FriendlyName;
                    }
                }
            }
            else
            {
                CookieManager userInfoCookie = new CookieManager(UserInfoCookieName);
                userInfoCookie.SetValue("UserName", ClientInfoContext.Current.UserPrincipal.UserName);
                userInfoCookie.SetValue("UserToken", ClientInfoContext.Current.UserPrincipal.UserToken);
            }

            if (ClientInfoContext.Current.UserPrincipal.UserGroup != CaSettings.AdminPageUserGroup) 
            {
                CAUtility.Utility.LoginTransfer.Transfer("~/Admin/Default.aspx");
            }

            base.OnPreLoad(e);
        }

        protected override void OnPreRender(EventArgs e)
        {

            base.OnPreRender(e);
        }
    }
}
