﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Text.RegularExpressions;
using System.Globalization;

using ZXR.IO;

namespace CAUtility
{

    public static class SupportCulture
    {

        private static List<string> languageList_ = null;

        public static List<string> LanguageList
        {
            get
            {
                return languageList_;
            }
        }

        static SupportCulture()
        {

        }

        public static void Init()
        {
            string searchDir = AppDomain.CurrentDomain.BaseDirectory;

            languageList_ = new List<string>();

            foreach (string strDir in DirectoryIO.GetSubfolderInDirectory(searchDir))
            { // ArrayListに取得したフォルダを追加
                string folderName = strDir.Replace(searchDir, "");
                Regex regex = new Regex("^[a-zA-Z]{2}-[a-zA-Z]{2}$");
                Match match = regex.Match(folderName);
                if (match.Success)
                {
                    if (!languageList_.Contains(folderName))
                        languageList_.Add(folderName);
                }
            }

            if (!languageList_.Contains(CaSettings.PageDefaultCulture))
                languageList_.Add(CaSettings.PageDefaultCulture);
        }

        public static string ConvertCodeToText(string cultureCode)
        {
            string result = string.Empty;
            string temp = new System.Globalization.CultureInfo(cultureCode).NativeName;
            Regex regex = new Regex(@"(.*)(\(.*\))");
            result = regex.Replace(temp, "$1");

            return result;
        }

        public static string SpecifieCultureForUrl(string cultureCode)
        {
            string result = "";
            Regex regex = new Regex("(.*)(/[a-zA-Z]{2}-[a-zA-Z]{2}/)(.*)");
            Match match = regex.Match(HttpContext.Current.Request.Url.AbsoluteUri);
            if (match.Success)
            {
                result = regex.Replace(HttpContext.Current.Request.Url.AbsoluteUri, "$1/" + cultureCode + "/$3");
            }

            return result;
        }

        public static string GetCultureUrl(string url)
        {
            string result = "";

            Regex regex = new Regex("(.*)(/[a-zA-Z]{2}-[a-zA-Z]{2}/)(.*)");
            Match match = regex.Match(url);
            if (match.Success)
            {
                result = regex.Replace(url, "$1$2");
            }

            return result;
        }

        public static CultureInfo GetCultureFormFileName(string str)
        {
            string result = "";

            Regex regex = new Regex(@"(.*)([\.][a-zA-Z]{2}-[a-zA-Z]{2}[\.])(.*)");
            Match match = regex.Match(str);
            if (match.Success)
            {
                result = regex.Replace(str, "$2");
                result = result.Replace(".", "");
            }

            return new CultureInfo(result);
        }

        public static string GetCultureFromUrl()
        {
            if (HttpContext.Current == null)
            {

                return string.Empty;
            }

            string result = "";
            string url = HttpContext.Current.Request.Url.ToString ();

            Regex regex = new Regex("(.*)(/[a-zA-Z]{2}-[a-zA-Z]{2}/)(.*)");
            Match match = regex.Match(url);
            if (match.Success)
            {
                result = regex.Replace(url, "$2");
                result = result.Replace("/", "");
            }

            return result;
        }

        public static bool IsSupport(string cultureCode)
        {
            return languageList_.Contains(cultureCode);
        }

        public static string GetCultureFlagForWeb(string cultureCode, string imagePath)
        {
            if (string.Equals(cultureCode, "zh-CN"))
                return imagePath + "china.png";
            else if (string.Equals(cultureCode, "ja-JP"))
                return imagePath + "japan.png";
            else if (string.Equals(cultureCode, "en-US"))
                return imagePath + "england.png";
            else
                return "";
        }

    }
}
