﻿namespace CaManager.Controls
{
    using System;
    using System.Collections.Generic;
    using System.Reflection;
    using System.Windows;
    using System.Windows.Controls;
    using System.Windows.Input;

    public class CustomDataForm : DataForm
    {
        private Dictionary<string, DataField> fields = new Dictionary<string, DataField>();

        public Dictionary<string, DataField> Fields
        {
            get { return this.fields; }
        }

        protected override void OnAutoGeneratingField(DataFormAutoGeneratingFieldEventArgs e)
        {
            if (e == null)
            {
                throw new ArgumentNullException("e");
            }

            PropertyInfo propertyInfo = this.CurrentItem.GetType().GetProperty(e.PropertyName);

            if (e.Field.Content is TextBox && this.IsPasswordProperty(propertyInfo))
            {
                e.Field.ReplaceTextBox(new PasswordBox(), PasswordBox.PasswordProperty);
            }

            this.fields[e.PropertyName] = e.Field;

            base.OnAutoGeneratingField(e);
        }

        protected virtual bool IsPasswordProperty(PropertyInfo propertyInfo)
        {
            if (propertyInfo == null)
            {
                throw new ArgumentNullException("propertyInfo");
            }

            return propertyInfo.Name.IndexOf("Password", StringComparison.OrdinalIgnoreCase) != -1;
        }
    }
}
