﻿using System;
using System.ComponentModel.DataAnnotations;
using System.ServiceModel.DomainServices.Client;
using System.ServiceModel.DomainServices.Client.ApplicationServices;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel;

using SilverlightFramework.Core;

namespace CaManager.Models
{

    public class LoginInfo : ModelClassBase
    {
        private string userName;
        private bool rememberMe;
        private LoginOperation currentLoginOperation;

        [Display(Name = "ID001", ResourceType = typeof(CaManager.Assets.Resources.View.Home))]
        [Required]
        public string UserName
        {
            get
            {
                return this.userName;
            }

            set
            {
                if (this.userName != value)
                {
                    this.ValidateProperty("UserName", value);
                    this.userName = value;
                    this.RaisePropertyChanged("UserName");
                }
            }
        }

        private string password_;

        [Display(Name = "ID002", ResourceType = typeof(CaManager.Assets.Resources.View.Home))]
        [Required]
        public string Password
        {
            get
            {
                return password_;
            }
            set
            {
                if (this.password_ != value)
                {
                    this.ValidateProperty("Password", value);
                    this.password_ = value;
                    this.RaisePropertyChanged("Password");
                }
            }
        }

        [Display(Name = "ID003", ResourceType = typeof(CaManager.Assets.Resources.View.Home))]
        public bool RememberMe
        {
            get
            {
                return this.rememberMe;
            }
            set
            {
                if (this.rememberMe != value)
                {
                    this.ValidateProperty("RememberMe", value);
                    this.rememberMe = value;
                    this.RaisePropertyChanged("RememberMe");
                }
            }
        }

        internal LoginOperation CurrentLoginOperation
        {
            get
            {
                return this.currentLoginOperation;
            }
            set
            {
                if (this.currentLoginOperation != value)
                {
                    if (this.currentLoginOperation != null)
                    {
                        this.currentLoginOperation.Completed -= (s, e) => this.CurrentLoginOperationChanged();
                    }

                    this.currentLoginOperation = value;

                    if (this.currentLoginOperation != null)
                    {
                        this.currentLoginOperation.Completed += (s, e) => this.CurrentLoginOperationChanged();
                    }

                    this.CurrentLoginOperationChanged();
                }
            }
        }

        [Display(AutoGenerateField = false)]
        public bool IsLoggingIn
        {
            get
            {
                return this.CurrentLoginOperation != null && !this.CurrentLoginOperation.IsComplete;
            }
        }

        [Display(AutoGenerateField = false)]
        public bool CanLogIn
        {
            get
            {
                return !this.IsLoggingIn;
            }
        }

        private void CurrentLoginOperationChanged()
        {
            this.RaisePropertyChanged("IsLoggingIn");
            this.RaisePropertyChanged("CanLogIn");
        }

    }
}
