﻿using System;

using ZXR.Core;
using CAUtility;
using CAUtility.Pages;

using ZXR.Web;
using ZXR.Log;
using ZXR.Security;
using ZXR.Web.Controls;

using CAUtility.Logic.UserInfo;

namespace WebApplication.Admin
{

    public partial class Default : NormalPage
    {

        private const string TransitionDefinition_Postback = "AdminPage.aspx";

        private const string UserInfoCookieName = "UserInfo";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {

            if (ClientInfoContext.Current.UserPrincipal.UserGroup == CaSettings.AdminPageUserGroup)
            {
                Response.Redirect(TransitionDefinition_Postback);
            }
        }

        protected void ButtonLogin_Click(object sender, EventArgs e)
        {
            LoginValidator lv = new LoginValidator();

            if (lv.CanLogin)
            {
                ValidationUserBizProcess param = new ValidationUserBizProcess();
                param.UserName = this.TextBoxUsername.Text;
                param.Password = Md5Cryptogram.Md5Hash(this.TextBoxPassword.Text);

                ValidationUserBizLogic logic = new ValidationUserBizLogic();
                ValidationUserBizResult result = (ValidationUserBizResult)logic.Execute(param);

                if (result.Result == true)
                {
                    lv.LoginSuccess();

                    CookieManager shooppingCookie = new CookieManager(UserInfoCookieName);
                    shooppingCookie.SetValue("UserName", this.TextBoxUsername.Text);
                    shooppingCookie.SetValue("UserToken", result.UserToken);

                    ClientInfoContext.Current.UserPrincipal.IsLogined = true;
                    ClientInfoContext.Current.UserPrincipal.UserGroup = result.UserGroup;
                    ClientInfoContext.Current.UserPrincipal.UserToken = result.UserToken;
                    ClientInfoContext.Current.UserPrincipal.UserName = this.TextBoxUsername.Text;
                    ClientInfoContext.Current.UserPrincipal.FriendlyName = result.FriendlyName;

                    Logger.Info(MessageManager.GetValue(MessageKey.UserLoginS0033, this.TextBoxUsername.Text));
                    this.ButtonLogin.Visible = false;

                    if (ClientInfoContext.Current.UserPrincipal.UserGroup == CaSettings.AdminPageUserGroup)
                        Response.Redirect(TransitionDefinition_Postback);
                }

                Logger.Info(MessageManager.GetValue(MessageKey.UserLoginS0034, this.TextBoxUsername.Text));
                lv.LoginFailed();
                this.ButtonLogin.Visible = true;
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminE0010));
            }
            else
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0032));
            }
        }

        private void InitInterface()
        {
            string culture = SupportCulture.GetCultureFromUrl();
            if (string.IsNullOrEmpty(culture))
                culture = CaSettings.PageDefaultCulture;

            MessageManager.CultureTarget = new System.Globalization.CultureInfo(culture);

            this.ButtonLogin.Text = MessageManager.GetValue(MessageKey.UserLoginS0003);
            this.LabelUserName.Text = MessageManager.GetValue(MessageKey.UserLoginS0001);
            this.LabelPassword.Text = MessageManager.GetValue(MessageKey.UserLoginS0002);
        }

    }
}
