﻿using System;

using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;
using ZXR.DataAccess;

using CAUtility.Logic.NewsLetter.News;
using CAUtility.Logic.NewsLetter.NewsTags;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.NewsLetter
{

    public partial class NewsLetterEdit : SecurityPage
    {

        private const string TransitionDefinition_OperationResult = "NewsLetterManager.aspx";

        private string QueryString_Action = string.Empty;

        private string QueryString_ID = string.Empty;

        private int QueryString_TagId = 0;

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            if (string.IsNullOrEmpty(QueryString_Action ))
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0015)) { ErrorType = ErrorType.IntrusionAttempt };
            }

            if (!IsPostBack)
            {
                InitTagsList();

                if (string.Equals(QueryString_Action, "append"))
                {

                    this.CustomDropDownListTagList.SelectedValue = QueryString_TagId.ToString();
                }

                else if (string.Equals(QueryString_Action, "edit"))
                {
                    if (string.IsNullOrEmpty(Request.QueryString["newsid"]))
                    {
                        throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0015)) { ErrorType = ErrorType.IntrusionAttempt };
                    }

                    InitPage(Request.QueryString["newsid"]);
                }
                else if (string.Equals(QueryString_Action, "delete"))
                {
                    DeleteNewsBizProcess param = new DeleteNewsBizProcess();
                    param.NewsID = QueryString_ID;

                    DeleteNewsBizLogic logic = new DeleteNewsBizLogic();
                    BizResult result = logic.Execute(param);

                    if (result.Result == true)
                    {
                        WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                    }
                }

            }
        }

        private void InitInterface()
        {
            this.DisplayLabelTitle.Text = MessageManager.GetValue(MessageKey.AdminD0119);
            this.DisplayLabelContent.Text = MessageManager.GetValue(MessageKey.AdminD0121);
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0195);
            this.DisplayLabelAddTag.Text = MessageManager.GetValue(MessageKey.AdminD0122);
            this.DisplayLabelTags.Text = MessageManager.GetValue(MessageKey.AdminD0120);
            this.LabelNewTags.Text = MessageManager.GetValue(MessageKey.AdminC0007);
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["newsid"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ID = Request.QueryString["newsid"];

            if (string.IsNullOrEmpty(Request.QueryString["action"]))
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Action = Request.QueryString["action"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["TagID"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_TagId = Convert.ToInt32(Request.QueryString["TagID"]);
        }

        private void InitPage(string newLetterId)
        {
            GetOneNewsBizProcess param = new GetOneNewsBizProcess();
            param.NewsID = Request.QueryString["newsid"];

            GetOneNewsBizLogic logic = new GetOneNewsBizLogic();
            GetOneNewsBizResult result = (GetOneNewsBizResult)logic.Execute(param);

            this.CustomDropDownListTagList.SelectedValue = result.NewsTagId;
            this.CustomTextBoxTitle.Text = result.NewsTitle;
            this.ZxrEditorBox1.Text = StringUtility.StringDecode(result.NewsContent);
        }

        public void InitTagsList()
        {
            ListTagsBizLogic logic = new ListTagsBizLogic();
            ListTagsBizResult result = (ListTagsBizResult)logic.Execute(null);

            this.CustomDropDownListTagList.Items.Clear();
            foreach (ListTagsBizResultElement ele in result.DataList)
            {
                this.CustomDropDownListTagList.AddItem(ele.TagName, ele.TagID);
            }
        }

        protected void CustomButtonUpdate_Click(object sender, EventArgs e)
        {

            string tagId = string.Empty;

            if (!string.IsNullOrEmpty(this.CustomTextBoxAddTag.Text))
            {
                ZxrTransaction insertTagTransaction = new ZxrTransaction();
                InsertTagBizProcess insertTagParam = new InsertTagBizProcess();
                insertTagParam.TagName = this.CustomTextBoxAddTag.Text;

                InsertTagBizLogic insertTagLogic = new InsertTagBizLogic();
                insertTagLogic.JoinTransaction(insertTagTransaction);
                insertTagLogic.Execute(insertTagParam);

                GetCurrentInsertedBizLogic getTagIdLogic = new GetCurrentInsertedBizLogic();
                getTagIdLogic.JoinTransaction(insertTagTransaction);
                BizResult result = getTagIdLogic.Execute(null);

                insertTagTransaction.Commit();

                tagId = result.ResultData.ToString();
            }

            else
            {
                tagId = this.CustomDropDownListTagList.SelectedValue;
            }

            if (string.IsNullOrEmpty(tagId))
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0197));
                return;
            }

            if (string.Equals(Request.QueryString["action"], "append"))
            {
                InsertNewsBizProcess insertNewsParam = new InsertNewsBizProcess();
                insertNewsParam.NewsContent = this.ZxrEditorBox1.Text;
                insertNewsParam.NewsTag = tagId;
                insertNewsParam.NewsTitle = this.CustomTextBoxTitle.Text;
                insertNewsParam.RegDatetime = DateTime.Now.ToString();

                InsertNewsBizLogic insetNesLogic = new InsertNewsBizLogic();
                BizResult result = insetNesLogic.Execute(insertNewsParam);

                if (result.Result == true)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }
            }
            else
            {
                UpdateNewsBizProcess updateNewParam = new UpdateNewsBizProcess();
                updateNewParam.NewsContent = this.ZxrEditorBox1.Text;
                updateNewParam.NewsID = Request.QueryString["newsid"];
                updateNewParam.NewsTagId = tagId;
                updateNewParam.NewsTitle = this.CustomTextBoxTitle.Text;

                UpdateNewsBizLogic updateNewsLogic = new UpdateNewsBizLogic();
                BizResult result = updateNewsLogic.Execute(updateNewParam);

                if (result.Result == true)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }
            }
        }

    }
}
