﻿using System;

using ZXR.Core;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;

using CAUtility.Logic.NewsLetter.News;
using CAUtility.Logic.NewsLetter.NewsTags;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.NewsLetter
{

    public partial class NewsLetterManager : SecurityPage
    {

        private const string TransitionDefinition_Postback = "NewsLetterEdit.aspx";

        private int QueryString_TagId = 0;

        private int QueryString_PageIndex = 1;

        private const string TransitionDefinition_OperationResult = "NewsLetterManager.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();
            initTagsList();

            if (QueryString_TagId != 0)
                InitNewsList();

            if (QueryString_TagId != 0)
            {
                this.ButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0020, System.Web.HttpUtility.UrlDecode(Request.QueryString["TagName"]));
            }
        }

        private void InitInterface()
        {
            this.ButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0052);
        }

        private void initTagsList()
        {
            ListTagsBizLogic logic = new ListTagsBizLogic();
            ListTagsBizResult result = (ListTagsBizResult)logic.Execute(null);

            foreach (ListTagsBizResultElement ele in result.DataList)
            {
                this.LabelTagList.Text += "<a href='NewsLetterManager.aspx?TagID=" + ele.TagID + "&TagName=" + System.Web.HttpUtility.UrlEncode(ele.TagName) + "'>" + ele.TagName + "</a>&nbsp;&nbsp;";
            }
        }

        private void InitNewsList()
        {
            ListNewsBizProcess param = new ListNewsBizProcess();
            param.TagID = QueryString_TagId;
            param.PageIndex = QueryString_PageIndex;
            param.OnePageMaxItemsCount = CaSettings.NewsCountInPage;

            ListNewsBizLogic logic = new ListNewsBizLogic();
            ListNewsBizResult result = (ListNewsBizResult)logic.Execute(param);

            this.PageDivider1.OnePageMaxItemCount = CaSettings.NewsCountInPage;
            this.PageDivider1.DispalyPageCount = CaSettings.AdminTablePageDividerDisplayCount;
            this.PageDivider1.ItemCount = result.TotalPostCount;

            this.ZxrGridView1.DataSource = result.DataList;
            this.ZxrGridView1.DataBind();
        }

        protected void ZxrGridView1_RowDeleting(object sender, System.Web.UI.WebControls.GridViewDeleteEventArgs e)
        {
            DeleteNewsBizProcess param = new DeleteNewsBizProcess();
            param.NewsID = this.ZxrGridView1.Rows[e.RowIndex].Cells[0].Text;

            DeleteNewsBizLogic logic = new DeleteNewsBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["TagID"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_TagId = Convert.ToInt32(Request.QueryString["TagID"]);

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Page"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_PageIndex = Convert.ToInt32(Request.QueryString["Page"]);
                QueryString_PageIndex = QueryString_PageIndex == 0 ? 1 : QueryString_PageIndex;
            }
        }

        protected void ButtonAppend_Click(object sender, EventArgs e)
        {
            Response.Redirect("NewsLetterEdit.aspx?action=append&TagID=" + QueryString_TagId);
        }

    }
}
