﻿using System;

using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.NewsLetter.News;
using CAUtility.Logic.NewsLetter.NewsTags;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.NewsLetter
{

    public partial class NewsTagsManager : SecurityPage
    {
        private const string NewsLetterPrefix = "NewsLetter";

        private const string DocumentPrefix = "Document";

        private const string TransitionDefinition_OperationResult = "NewsTagsManager.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }
        
        protected void Page_Load(object sender, EventArgs e)
        {
            InitTagsList();
        }

        private void InitInterface()
        {
            this.DisplayLabelTagName.Text = MessageManager.GetValue(MessageKey.AdminD0120);
            this.CustomButtonAddTag.Text = MessageManager.GetValue(MessageKey.AdminD0036);
            this.LabelTitle.Text = "新しいタブを追加する";
        }

        private void InitTagsList()
        {
            ListTagsBizLogic logic = new ListTagsBizLogic();
            ListTagsBizResult result = (ListTagsBizResult)logic.Execute(null);

            this.MenuTableNewsTagList.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTableNewsTagList.RowCount = result.DataList.Count + 1;
            this.MenuTableNewsTagList.TurnBackNumber = 4;
            this.MenuTableNewsTagList.CssClass = "AdminTable";

            if (result.DataList.Count > 0)
            {
                this.MenuTableNewsTagList.AddContex(MessageManager.GetValue(MessageKey.AdminD0120));
                this.MenuTableNewsTagList.AddContex(MessageManager.GetValue(MessageKey.AdminD0179));
                this.MenuTableNewsTagList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableNewsTagList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            }

            int rowIndex = 1;
            foreach (ListTagsBizResultElement ele in result.DataList)
            {
                TextBox tagNameTextBox = new TextBox();
                tagNameTextBox.Text = ele.TagName;
                this.MenuTableNewsTagList.AddControl(tagNameTextBox);

                Label codeLabel = new Label();
                codeLabel.Text = "++" + NewsLetterPrefix + "(" + ele.TagID + ")++<br />++"
                    + NewsLetterPrefix + "(" + ele.TagID + "," + MessageManager.GetValue(MessageKey.AdminD0180) + ")++<br />"
                    + "++" + DocumentPrefix + "(" + ele.TagID + ")++";
                this.MenuTableNewsTagList.AddControl(codeLabel);

                ValidatorButton updateButton = new ValidatorButton();
                updateButton.UserDatas["TagID"] = ele.TagID;
                updateButton.UserDatas["RowIndex"] = rowIndex.ToString();
                updateButton.Text = MessageManager.GetValue(MessageKey.AdminD0112);
                updateButton.Click += new EventHandler(updateButton_Click);
                this.MenuTableNewsTagList.AddControl(updateButton);

                ValidatorButton delButton = new ValidatorButton();
                delButton.UserDatas["TagID"] = ele.TagID;
                delButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                delButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                delButton.Click += new EventHandler(delButton_Click);
                this.MenuTableNewsTagList.AddControl(delButton);

                rowIndex++;
            }

            this.MenuTableNewsTagList.Flush();
        }

        void delButton_Click(object sender, EventArgs e)
        {
            GetNewsCountBizProcess countParam = new GetNewsCountBizProcess();
            countParam.TagID = ((ValidatorButton)sender).UserDatas["TagID"];

            GetNewsCountBizLogic countLogic = new GetNewsCountBizLogic();
            BizResult countResult = countLogic.Execute(countParam);

            if (Convert.ToInt32(countResult.ResultData) == 0)
            {
                DelTagBizProcess param = new DelTagBizProcess();
                param.TagID = ((ValidatorButton)sender).UserDatas["TagID"];

                DelTagBizLogic logic = new DelTagBizLogic();
                BizResult result = logic.Execute(param);

                if (result.Result == true)
                {
                    Response.Redirect(TransitionDefinition_OperationResult);
                }
            }
            else
            {

                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminN0006));
            }
        }

        void updateButton_Click(object sender, EventArgs e)
        {
            int editRowIndex = int.Parse(((ValidatorButton)sender).UserDatas["RowIndex"]);

            UpdateTagBizProcess param = new UpdateTagBizProcess();
            param.TagID = ((ValidatorButton)sender).UserDatas["TagID"];
            param.TagName = ((TextBox)this.MenuTableNewsTagList.GetCellControl(editRowIndex,0)).Text;

            UpdateTagBizLogic logic = new UpdateTagBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void CustomButtonAddTag_Click(object sender, EventArgs e)
        {
            InsertTagBizProcess param = new InsertTagBizProcess();
            param.TagName = this.CustomTextBoxTagName.Text;

            InsertTagBizLogic logic = new InsertTagBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

    }
}
