﻿using System;
using System.Collections.Generic;
using System.Web.UI.WebControls;

using ZXR.Core;
using ZXR.DataAccess;
using ZXR.Data;
using ZXR.Web;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.Page;
using CAUtility;

namespace WebApplication.Admin.PageInfoEdit
{

    partial class PageInfoAppendEdit
    {

        private string editTargetPageID_ = string.Empty;

        private string QueryString_TargetCulture = string.Empty;

        private string topPageID_ = string.Empty;

        private void InitInterface()
        {
            this.LabelContents.Text = MessageManager.GetValue(MessageKey.AdminD0025);
            this.LabelCulture.Text = MessageManager.GetValue(MessageKey.AdminD0009);
            this.LabelTitle.Text = MessageManager.GetValue(MessageKey.AdminD0024);
            this.DisplayLabelOrder.Text = MessageManager.GetValue(MessageKey.AdminD0196);
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0195);
            this.DisplayLabelBelongto.Text = MessageManager.GetValue(MessageKey.AdminD0090);
            this.DisplayLabelShowInMenu.Text = MessageManager.GetValue(MessageKey.AdminD0099);
            this.DisplayLabelOrderScr.Text = MessageManager.GetValue(MessageKey.AdminC0003);
            this.DisplayLabelKeyword.Text =MessageManager.GetValue(MessageKey.AdminD0046); 
            this.DisplayLabelLinkImage.Text =MessageManager.GetValue(MessageKey.AdminD0061); 
            this.DisplayLabelImageNotfiy.Text =MessageManager.GetValue(MessageKey.AdminC0002);
            this.CustomButtonDeleteLinkImage.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
            this.CustomButtonDeleteLinkImage.Text = MessageManager.GetValue(MessageKey.AdminD0124);
            this.LabelSeoHelp.Text = MessageManager.GetValue(MessageKey.AdminC0001);
            this.LabelAccess.Text = MessageManager.GetValue(MessageKey.AdminC0004);
        }

        private void InitPage()
        {
            ZxrTransaction transaction = new ZxrTransaction();

            GetSinglePageBizProcess param = new GetSinglePageBizProcess();
            param.ID = editTargetPageID_;
            BizLogic logic = new GetSinglePageBizLogic();
            logic.JoinTransaction(transaction);
            GetSinglePageBizResult singlePageInfo = (GetSinglePageBizResult)logic.Execute(param);

            GetPageAuthSettingBizProcess authParam = new GetPageAuthSettingBizProcess();
            authParam.PageId = Convert.ToInt32(editTargetPageID_);

            GetPageAuthSettingBizLogic authListLogic = new GetPageAuthSettingBizLogic();
            authListLogic.JoinTransaction(transaction);
            GetPageAuthSettingBizResult authresult = (GetPageAuthSettingBizResult)authListLogic.Execute(authParam);

            transaction.Commit();

            foreach (GetPageAuthSettingBizResultElement ele in authresult.DataList)
            {

                foreach (ListItem item in this.CheckBoxListReadUserGroup.Items)
                {
                    if (ele.GroupId == Convert.ToInt32(item.Value ))
                    {
                        item.Selected = true;
                        break;
                    }
                }
            }

            this.CustomTextBoxTitle.Text = singlePageInfo.DisplayText;
            this.CustomTextBoxOrder.Text = singlePageInfo.PageOrder;
            this.CustomDropDownListPageList.SelectedValue = singlePageInfo.TopPageId;
            this.CustomTextBoxKeyword.Text = singlePageInfo.MetaKeyword;
            this.ZxrEditorBox1.Text = StringUtility.StringDecode(singlePageInfo.Contents);

            if (!string.IsNullOrEmpty(singlePageInfo.LinkImage))
            {
                this.CustomButtonDeleteLinkImage.Enabled = true;
            }
            else
            {
                this.CustomButtonDeleteLinkImage.Enabled = false;
            }

            if (string.Equals(singlePageInfo.IsShowInMenu, "1"))
                this.RadioButtonShowInMenuYes.Checked = true;
            else
                this.RadioButtonShowInMenuNo.Checked = true;

            this.ImageViewLink.ImageUrl = singlePageInfo.LinkImage;
        }

        protected void InitPageListInfo()
        {
            GetPageListBizProcess param = new GetPageListBizProcess();
            param.Culture = QueryString_TargetCulture;

            param.Status = DataStatus.Normal.ToString();

            BizLogic logic = new GetPageListBizLogic();
            GetPageListBizResult pageList = (GetPageListBizResult)logic.Execute(param);

            List<TreeDataNode> tempList = new List<TreeDataNode>();

            foreach (GetPageListBizResultElement ele in pageList.DataList)
            {
                TreeDataNode node = new TreeDataNode();
                node.ID = Int32.Parse(ele.ID);
                node.ParentID = Int32.Parse(ele.TopPageId);
                node.Value = ele.DisplayText;
                node["PageId"] = ele.ID;
                node.SortIndex = Int32.Parse(ele.PageOrder);

                tempList.Add(node);
            }

            TreeData treeData = new TreeData();
            treeData.AddChildFromList(tempList);

            foreach (TreeDataNode node in treeData)
            {
                if (node.Keys.Count == 0)
                    continue;

                string temp = "";

                for (int i = 0; i <= node.Depth; i++)
                {
                    temp += "　　";
                }
                this.CustomDropDownListPageList.AddItem(temp + node.Value.ToString(), node["PageId"].ToString());
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

    }
}
