﻿using System;
using System.Web.UI.WebControls;

using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.Page;
using CAUtility.Logic.GroupInfo;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.PageInfoEdit
{

    public partial class PageInfoAppendEdit : SecurityPage
    {

        private string TransitionDefinition_OperationResult = "PageInfoManager.aspx";

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            TransitionDefinition_OperationResult = "PageInfoManager.aspx?TargetCulture=" + QueryString_TargetCulture;

            editTargetPageID_ = Request.QueryString["EditTarget"];
            topPageID_ = Request.QueryString["TopPageId"];

            InitInterface();

            if (!IsPostBack)
            {

                ListGroupInfoBizLogic logic = new ListGroupInfoBizLogic();
                ListGroupInfoBizResult result = (ListGroupInfoBizResult)logic.Execute(null);
                bool ss = result.DataList.Remove(new ListGroupInfoBizResultElement() { GroupID = CaSettings.AdminPageUserGroup });

                ListGroupInfoBizResult newList = new ListGroupInfoBizResult();

                foreach (ListGroupInfoBizResultElement item in result.DataList)
                {
                    if (item.GroupID == CaSettings.AdminPageUserGroup)
                        continue;

                    newList.DataList.Add(item);
                }

                this.CheckBoxListReadUserGroup.DataSource = newList.DataList;
                this.CheckBoxListReadUserGroup.DataBind();

                this.CustomDropDownListPageList.AddItem(MessageManager.GetValue(MessageKey.AdminD0190), "0");

                InitPageListInfo();

                if (!string.IsNullOrEmpty(editTargetPageID_))//編集する場合
                {

                    InitPage();
                }
                else //追加する場合
                {
                    this.CustomDropDownListPageList.SelectedValue = topPageID_;
                    this.CustomDropDownListPageList.Enabled = false;
                }
            }

            this.LabelCurrentCulture.Text = SupportCulture.ConvertCodeToText(QueryString_TargetCulture);
        }

        protected void ButtonAccess_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(editTargetPageID_))//追加
            {

                InsertNewPageBizProcess param = new InsertNewPageBizProcess();
                param.DisplayText = this.CustomTextBoxTitle.Text;
                param.PageOrder = this.CustomTextBoxOrder.Text;
                param.Contents = this.ZxrEditorBox1.Text;
                param.Culture = QueryString_TargetCulture;
                param.TopPageId = topPageID_;
                param.MetaKeyword = this.CustomTextBoxKeyword.Text;
                if (!string.IsNullOrEmpty(Request.Form["xImagePath"]))
                {
                    param.LinkImage = Request.Form["xImagePath"];
                }

                if (this.RadioButtonShowInMenuYes.Checked)
                    param.IsShowInMenu = "1";
                else
                    param.IsShowInMenu = "0";

                foreach (ListItem item in this.CheckBoxListReadUserGroup.Items)
                {
                    if (item.Selected)
                    {
                        param.AllowReadGroups.Add(Convert.ToInt32(item.Value));
                    }
                }

                InsertNewPageBizLogic logic = new InsertNewPageBizLogic();
                BizResult result = logic.Execute(param);

                int currentInsertedPageID = Convert.ToInt32(result.ResultData);

                if (result.Result)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }
            }
            else//更新
            {
                if (string.Equals(this.CustomDropDownListPageList.SelectedValue, editTargetPageID_))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0189));
                    return;
                }

                UpdatePageBizProcess param = new UpdatePageBizProcess();
                param.PageOrder = this.CustomTextBoxOrder.Text;
                param.ID = editTargetPageID_;
                param.Contents = this.ZxrEditorBox1.Text;
                param.DisplayText = this.CustomTextBoxTitle.Text;
                param.MetaKeyword = this.CustomTextBoxKeyword.Text;
                if (!string.IsNullOrEmpty(Request.Form["xImagePath"]))
                {
                    param.LinkImage = Request.Form["xImagePath"];
                }
                else
                {
                    param.LinkImage = "";
                }
                param.TopPageId = this.CustomDropDownListPageList.SelectedValue;

                if (this.RadioButtonShowInMenuYes.Checked)
                    param.IsShowInMenu = "1";
                else
                    param.IsShowInMenu = "0";

                foreach (ListItem item in this.CheckBoxListReadUserGroup.Items)
                {
                    if (item.Selected)
                    {
                        param.AllowReadGroups.Add(Convert.ToInt32(item.Value));
                    }
                }

                if (!string.Equals(param.ID, param.TopPageId))
                {
                    UpdatePageBizLogic logic = new UpdatePageBizLogic();
                    BizResult result = logic.Execute(param);

                    if (result.Result)
                    {
                        if (!string.IsNullOrEmpty(Request.Form["xImagePath"]))
                        {
                            param.LinkImage = Request.Form["xImagePath"];
                        }
                        WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                    }
                }
                else
                {
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
                }
            }
        }

        protected void CustomButtonDeleteLinkImage_Click(object sender, EventArgs e)
        {
            DeleteLinkImageBizProcess param = new DeleteLinkImageBizProcess();
            param.PageID = editTargetPageID_;

            DeleteLinkImageBizLogic logic = new DeleteLinkImageBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                this.ImageViewLink.ImageUrl = "";
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030));
            }
        }

    
    }
}
