﻿using System;
using System.Collections.Generic;

using ZXR.Core;
using ZXR.DataAccess;
using ZXR.Data;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.Page;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.PageInfoEdit
{

    public partial class PageInfoManager : SecurityPage
    {

        private string QueryString_TargetCulture = string.Empty;

        private const string TransitionDefinition_Postback = "PageInfoAppendEdit.aspx";

        private string TransitionDefinition_OperationResult = "PageInfoManager.aspx";

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            TransitionDefinition_OperationResult = "PageInfoManager.aspx?TargetCulture=" + QueryString_TargetCulture;

            InitPageInfo();

            InitInterface();
        }

        private void InitInterface()
        {
            this.ButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0027);
            this.LabelMessage.Text = MessageManager.GetValue(MessageKey.AdminD0132);
        }

        private void InitPageInfo()
        {
            GetPageListBizProcess param = new GetPageListBizProcess();
            param.Culture = QueryString_TargetCulture;

            BizLogic logic = new GetPageListBizLogic();
            GetPageListBizResult pageList = (GetPageListBizResult)logic.Execute(param);

            List<TreeDataNode> tempList = new List<TreeDataNode>();

            foreach (GetPageListBizResultElement ele in pageList.DataList)
            {
                TreeDataNode node = new TreeDataNode();
                node.ID = Int32.Parse(ele.ID);
                node.ParentID = Int32.Parse(ele.TopPageId);
                node.Value = ele.DisplayText;
                node["PageId"] = ele.ID;
                node["Status"] = ele.Status;
                node["IsSoweInMenu"] = ele.IsShowInMenu;
                node["Click"] = ele.ClickCount;
                node.SortIndex = Int32.Parse(ele.PageOrder);

                tempList.Add(node);
            }

            TreeData treeData = new TreeData();
            treeData.AddChildFromList(tempList);

            this.MenuTable1.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTable1.RowCount = treeData.Count + 1;
            this.MenuTable1.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;
            this.MenuTable1.TurnBackNumber = 7;
            this.MenuTable1.CssClass = "AdminTable";

            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0024));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.PageD0044));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));

            foreach (TreeDataNode node in treeData)
            {

                if (node.Keys.Count == 0)
                    continue;

                string temp = "";
                for (int i = 0; i <= node.Depth; i++)
                {
                    temp += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
                }

                Label displayLabel = new Label();
                if (string.Equals(node["Status"].ToString(), DataStatus.DummyDelete.ToString()))
                {
                    displayLabel.Text = temp + "<Del>" + node.Value.ToString() + "</Del>";
                }
                else if (Convert.ToBoolean(node["IsSoweInMenu"]) == true)
                {
                    displayLabel.Text = temp + "<U>" + node.Value.ToString() + "</U>";
                }
                else
                {
                    displayLabel.Text = temp + node.Value.ToString();
                }
                this.MenuTable1.AddControl(displayLabel);

                this.MenuTable1.AddContex(node["Click"].ToString());

                HyperLink viewLink = new HyperLink();
                viewLink.Enabled = !string.Equals(node["Status"].ToString(), DataStatus.DummyDelete.ToString());

                if (!string.Equals(QueryString_TargetCulture, CaSettings.PageDefaultCulture))
                    viewLink.NavigateUrl = "~/" + QueryString_TargetCulture + "/Page.aspx?PageID=" + node["PageId"].ToString();
                else
                    viewLink.NavigateUrl = "~/Page.aspx?PageID=" + node["PageId"].ToString();

                viewLink.Target = "_blank";
                viewLink.Text = MessageManager.GetValue(MessageKey.AdminD0115);
                this.MenuTable1.AddControl(viewLink);

                Button editButton = new Button();
                editButton.UserDatas["PageId"] = node["PageId"].ToString();
                editButton.Click += new EventHandler(editButton_Click);
                editButton.Text = MessageManager.GetValue(MessageKey.AdminD0008);
                this.MenuTable1.AddControl(editButton);

                Button deleteButton = new Button();
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.UserDatas["EditTarget"] = node["PageId"].ToString();
                deleteButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTable1.AddControl(deleteButton);

                Button addChildButton = new Button();
                addChildButton.UserDatas["TopPageId"] = node["PageId"].ToString();
                addChildButton.Text = MessageManager.GetValue(MessageKey.AdminD0091);
                addChildButton.Click += new EventHandler(addChildButton_Click);
                this.MenuTable1.AddControl(addChildButton);

                Button changeStatusButton = new Button();
                changeStatusButton.UserDatas["EditTarget"] = node["PageId"].ToString();
                string status = DataStatus.Normal.ToString();
                if (string.Equals(node["Status"], DataStatus.Normal.ToString()))
                {
                    status = DataStatus.DummyDelete.ToString();
                }
                changeStatusButton.UserDatas["Status"] = status;

                if (string.Equals(node["Status"].ToString(), DataStatus.DummyDelete.ToString()))
                    changeStatusButton.Text = MessageManager.GetValue(MessageKey.AdminD0194);
                else
                    changeStatusButton.Text = MessageManager.GetValue(MessageKey.AdminD0098);

                changeStatusButton.Click += new EventHandler(changeStatusButton_Click);
                this.MenuTable1.AddControl(changeStatusButton);
            }

            this.MenuTable1.Flush();
        }

        void addChildButton_Click(object sender, EventArgs e)
        {
            Response.Redirect(TransitionDefinition_Postback + "?TargetCulture=" + QueryString_TargetCulture + "&TopPageId=" + ((Button)sender).UserDatas["TopPageId"].ToString());
        }

        void editButton_Click(object sender, EventArgs e)
        {
            Response.Redirect(TransitionDefinition_Postback + "?Action=edit&EditTarget=" +
                ((Button)sender).UserDatas["PageId"].ToString() +
                "&TargetCulture=" + QueryString_TargetCulture);
        }

        private void changeStatusButton_Click(object sender, EventArgs e)
        {
            ChangePageStatusBizProcess param = new ChangePageStatusBizProcess();
            param.PageID = ((Button)sender).UserDatas["EditTarget"];
            param.Status = ((Button)sender).UserDatas["Status"];

            ChangePageStatusBizLogic logic = new ChangePageStatusBizLogic ();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        public void deleteButton_Click(object sender, EventArgs e)
        {

            DeletePageBizProcess param = new DeletePageBizProcess();
            param.ID = ((Button)sender).UserDatas["EditTarget"];

            DeletePageBizLogic logic = new DeletePageBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void ButtonAppend_Click(object sender, EventArgs e)
        {
            Response.Redirect(
                TransitionDefinition_Postback + "?TargetCulture=" + QueryString_TargetCulture + "&TopPageId=0"
                );
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

    }
}
