﻿using System;

using ZXR.Core;
using ZXR.Web.Controls;
using CAUtility.Pages;
using ZXR.BusinessLogic;

using CAUtility.Logic.ProductKinds;
using CAUtility;

namespace WebApplication.Admin.ProductInfo
{

    public partial class ClassificationAppend : SecurityPage
    {

        private string QueryString_TargetCulture = string.Empty;

        private string TransitionDefinition_OperationResult = string.Empty;

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            TransitionDefinition_OperationResult = "ClassificationManager.aspx?TargetCulture=" + QueryString_TargetCulture;

            InitInterface();

            if (Request.QueryString["Action"] != null && Request.QueryString["Cid"] != null)
            {
                if (Request.QueryString["Action"].Equals("edit"))
                {
                    if (!IsPostBack)
                    {
                        InitPage();
                    }
                }
                else if (Request.QueryString["Action"].Equals("append"))
                {
                    this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0036);
                }
            }
            else if (Request.QueryString["Action"] != null && Request.QueryString["Cid"] == null)
            {
                if (!IsPostBack)
                {
                    this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0036);
                }
            }
        }

        private void InitInterface()
        {
            this.LabelName.Text = MessageManager.GetValue(MessageKey.AdminD0006);
            this.LabelDetails.Text = MessageManager.GetValue(MessageKey.AdminD0007);
            this.DisplayLabelOrder.Text = MessageManager.GetValue(MessageKey.AdminD0071);
            this.DisplayLabelKeyword.Text =MessageManager.GetValue(MessageKey.AdminD0046); 
            this.DisplayLabelLinkImage.Text =MessageManager.GetValue(MessageKey.AdminD0061); 
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0008);
            this.DisplayLabelImageNotfiy.Text = MessageManager.GetValue(MessageKey.AdminC0002);
            this.CustomButtonDeleteLinkImage.Text = MessageManager.GetValue(MessageKey.AdminD0124);
            this.CustomButtonDeleteLinkImage.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
        }

        private void InitPage()
        {
            GetProductKindsDetailsBizProcess param = new GetProductKindsDetailsBizProcess();
            param.ID = Request.QueryString["Cid"];

            GetProductKindsDetailsBizLogic logic = new GetProductKindsDetailsBizLogic();
            GetProductKindsDetailsBizResult result = (GetProductKindsDetailsBizResult)logic.Execute(param);

            this.CustomTextBox1.Text = result.Name;
            this.CustomTextBox2.Text = result.Details;
            this.CustomTextBoxOrder.Text = result.KindOrder;
            this.CustomTextBoxKeyword.Text = result.MetaKeyword;
            this.ImageView1.ImageUrl = result.LinkImage;

            if (string.IsNullOrEmpty(result.LinkImage))
            {
                this.CustomButtonDeleteLinkImage.Enabled = false;
            }
            else
            {
                this.CustomButtonDeleteLinkImage.Enabled = true;
            }
        }

        protected void CustomButtonUpdate_Click(object sender, EventArgs e)
        {

            if (Request.QueryString["Action"].Equals("append") && Request.QueryString["Cid"] == null)
            {
                AddLargeClassification();
            }

            else if (Request.QueryString["Action"].Equals("edit") && Request.QueryString["Cid"] != null)
            {
                EditClassificationContent();
            }
        }
    

        private void AddLargeClassification()
        {
            InsertProductKindsBizProcess param = new InsertProductKindsBizProcess();
            param.KindName = this.CustomTextBox1.Text;
            param.Details = this.CustomTextBox2.Text;
            param.KindOrder = this.CustomTextBoxOrder.Text;
            param.Culture = QueryString_TargetCulture;
            param.MetaKeyword = this.CustomTextBoxKeyword.Text;
            if (!string.IsNullOrEmpty(Request.Form["xImagePath"]))
            {
                param.LinkImage = Request.Form["xImagePath"];
            }

            BizResult result = new InsertProductKindsBizLogic().Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        private void EditClassificationContent()
        {
            UpdateProductKindsBizProcess param = new UpdateProductKindsBizProcess();
            param.ID = Request.QueryString["Cid"];
            param.KindName = this.CustomTextBox1.Text;
            param.Details = this.CustomTextBox2.Text;
            param.KindOrder = this.CustomTextBoxOrder.Text;
            param.MetaKeyword = this.CustomTextBoxKeyword.Text;
            if (!string.IsNullOrEmpty(Request.Form["xImagePath"]))
            {
                param.LinkImage = Request.Form["xImagePath"];
            }
            else
            {
                param.LinkImage = "";
            }

            UpdateProductKindsBizLogic logic = new UpdateProductKindsBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void CustomButtonDeleteLinkImage_Click(object sender, EventArgs e)
        {
            DeleteLinkImageBizProcess param = new DeleteLinkImageBizProcess();
            param.ID = Request.QueryString["Cid"];

            DeleteLinkImageBizLogic logic = new DeleteLinkImageBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                this.ImageView1.ImageUrl = "";
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030));
            }
        }

        

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }
    }
}
