﻿using System;

using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.ProductKinds;
using CAUtility.Pages;
using CAUtility;

namespace WebApplication.Admin.ProductInfo
{

    public partial class ClassificationEdit : SecurityPage
    {

        private string TransitionDefinition_OperationResult = string.Empty;

        private string QueryString_TargetCulture = string.Empty;

        private const string ProductionPrefix = "Production";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();
            TransitionDefinition_OperationResult = "ClassificationManager.aspx?TargetCulture=" + QueryString_TargetCulture;

            this.ButtonLargeCAppend.PostBackUrl = "ClassificationEdit.aspx?Action=append&TargetCulture=" + QueryString_TargetCulture;

            ShowClassificationList();
        }

        private void InitInterface()
        {
            this.ButtonLargeCAppend.Text = MessageManager.GetValue(MessageKey.AdminD0010);
        }

        private void ShowClassificationList()
        {
            DisplayProductKindsListBizProcess param = new DisplayProductKindsListBizProcess();
            param.Culture = QueryString_TargetCulture;

            DisplayProductKindsListBizLogic fetch = new DisplayProductKindsListBizLogic();
            DisplayProductKindsListBizResult result = (DisplayProductKindsListBizResult)fetch.Execute(param);

            this.MenuTable1.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTable1.RowCount = result.DataList.Count + 1;
            this.MenuTable1.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;
            this.MenuTable1.TurnBackNumber = 4;
            this.MenuTable1.CssClass = "AdminTable";

            if (result.DataList.Count > 0)
            {
                this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0006));
                this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0179));
                this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            }

            foreach (DisplayProductKindsListBizResultElement xx in result.DataList)
            {
                Label nameColumn1 = new Label();
                nameColumn1.Text = xx.Name;
                this.MenuTable1.AddControl(nameColumn1);

                Label codeLabel = new Label();
                codeLabel.Text = "++" + ProductionPrefix + "(" + xx.ID + ")++";
                this.MenuTable1.AddControl(codeLabel);

                ValidatorButton editButton = new ValidatorButton();
                editButton.Text = MessageManager.GetValue(MessageKey.AdminD0008);
                editButton.UserDatas["KindID"] = xx.ID.ToString();
                editButton.Click += new EventHandler(editButton_Click);
                this.MenuTable1.AddControl(editButton);

                ValidatorButton deleteButton = new ValidatorButton();
                deleteButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                deleteButton.UserDatas["ID"] = xx.ID.ToString();
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTable1.AddControl(deleteButton);
            }

            this.MenuTable1.Flush();
        }

        void editButton_Click(object sender, EventArgs e)
        {
            Response.Redirect("ClassificationEdit.aspx?Action=edit&Cid=" + ((ValidatorButton)sender).UserDatas["KindID"] + "&TargetCulture=" + QueryString_TargetCulture);
        }

        void deleteButton_Click(object sender, EventArgs e)
        {
            DeleteProductKindsBizProcess param = new DeleteProductKindsBizProcess();
            param.ID = ((ValidatorButton)sender).UserDatas["ID"];

            DeleteProductKindsBizLogic logic = new DeleteProductKindsBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

    }
}
