﻿using System;
using System.Configuration;
using System.Web.UI.WebControls;

using ZXR.Core;
using ZXR.Web;
using CAUtility.Pages;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.ProductKinds;
using CAUtility.Logic.Products;
using CAUtility;

namespace WebApplication.Admin.ProductInfo
{

    public partial class ProductEdit : SecurityPage
    {

        private string TransitionDefinition_OperationResult = "ProductManager.aspx";

        private string TransitionDefinition_Kind = "ClassificationManager.aspx";

        private string QueryString_TargetCulture = string.Empty;

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            TransitionDefinition_OperationResult = "ProductManager.aspx?TargetCulture=" + QueryString_TargetCulture;

            InitInterface();

            if (!IsPostBack)
            {

                DisplayProductKindsListBizProcess kindParam = new DisplayProductKindsListBizProcess();
                kindParam.Culture = QueryString_TargetCulture;
                BizLogic kindLogic = new DisplayProductKindsListBizLogic();
                DisplayProductKindsListBizResult kindResult = (DisplayProductKindsListBizResult)kindLogic.Execute(kindParam);

                if (kindResult.DataList.Count == 0)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminE0020), TransitionDefinition_Kind + "?TargetCulture=" + QueryString_TargetCulture);
                    return;
                }

                foreach (DisplayProductKindsListBizResultElement ele in kindResult.DataList)
                {
                    ListItem item = new ListItem();
                    item.Text = ele.Name;
                    item.Value = ele.ID.ToString();
                    this.CustomDropDownListKind.Items.Add(item);
                }

                if (Request.QueryString["Pid"] != null && string.Equals("edit", Request.QueryString["Action"]))
                {

                    ShowProductDetails();
                }

                else if (!string.IsNullOrEmpty(Request.QueryString["Cid"]) && string.Equals("append", Request.QueryString["Action"]))
                {
                    this.CustomDropDownListKind.SelectedValue = Request.QueryString["Cid"];
                    this.CustomDropDownListKind.Enabled = false;
                    this.ImageView1.Visible = false;
                }
            }
        }

        private void InitInterface()
        {
            this.LabelDetails.Text = MessageManager.GetValue(MessageKey.AdminD0016);
            this.DisplayLabelSelectImage.Text = MessageManager.GetValue(MessageKey.AdminD0101);
            this.LabelImageShow.Text = MessageManager.GetValue(MessageKey.AdminD0017);
            this.LabelKindName.Text = MessageManager.GetValue(MessageKey.AdminD0006);
            this.LabelOutline.Text = MessageManager.GetValue(MessageKey.AdminD0018);
            this.LabelProductName.Text = MessageManager.GetValue(MessageKey.AdminD0019);
            this.DisplayLabelProductId.Text = MessageManager.GetValue(MessageKey.AdminD0038);
            this.DisplayLabelImageNotfiy.Text = MessageManager.GetValue(MessageKey.AdminD0068);
            this.DisplayLabelImageExisting.Text = MessageManager.GetValue(MessageKey.AdminD0069);
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0195);
            this.DisplayLabelOrder.Text = MessageManager.GetValue(MessageKey.AdminD0071);
            this.DisplayLabelKeyword.Text =MessageManager.GetValue(MessageKey.AdminD0046); 
        }

        private void ShowProductDetails()
        {
            GetProductDetailsBizProcess param = new GetProductDetailsBizProcess();
            param.ID = Request.QueryString["Pid"];

            GetProductDetailsBizLogic logic = new GetProductDetailsBizLogic();
            GetProductDetailsBizResult productDetails = (GetProductDetailsBizResult)logic.Execute(param);

            this.CustomTextBoxProductId.Text = productDetails.ProductID;
            this.CustomTextBoxProductName.Text = productDetails.Name;
            this.CustomTextBoxOrder.Text = productDetails.ProductOrder;
            this.CustomTextBoxProductOutline.Text = productDetails.OutLine;
            this.ZxrEditorBox1.Text = StringUtility.StringDecode(productDetails.Details);

            if( productDetails .Price != 0)
                this.CustomTextBoxPrice.Text = productDetails.Price.ToString();

            this.CustomTextBoxKeyword.Text = productDetails.MetaKeyword;
            this.CustomDropDownListKind.SelectedValue = productDetails.KindsID.ToString();
            this.TextBoxStockCount.Text = productDetails.StockCount.ToString();

            if (!string.IsNullOrEmpty(productDetails.ImagePath))
            {
                this.ImageView1.ImageUrl = productDetails.ImagePath;
                this.ImageView1.Visible = true;
                this.DisplayLabelImageExisting.Visible = false;
            }
            else
            {
                this.DisplayLabelImageExisting.Visible = true;
                this.ImageView1.Visible = false;
            }
        }

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {

            InsertUpdateProductBizProcess productDetails = new InsertUpdateProductBizProcess();

            productDetails.ProductID = this.CustomTextBoxProductId.Text;
            productDetails.Name = this.CustomTextBoxProductName.Text;
            productDetails.OutLine = this.CustomTextBoxProductOutline.Text;
            productDetails.ProductOrder = this.CustomTextBoxOrder.Text;
            productDetails.Details = this.ZxrEditorBox1.Text;
            if (!string.IsNullOrEmpty(this.CustomTextBoxPrice.Text))
                productDetails.Price = Decimal.Parse(this.CustomTextBoxPrice.Text);
            productDetails.KindsID = Int32.Parse(this.CustomDropDownListKind.SelectedValue);
            productDetails.RegistDatetime = DateTime.Now;

            if (!string.IsNullOrEmpty(this.TextBoxStockCount.Text))
                productDetails.StockCount = Int32.Parse(this.TextBoxStockCount.Text);

            if (!string.IsNullOrEmpty(Request.Form["xImagePath"]))
            {

                productDetails.ImagePath = Request.Form["xImagePath"];
            }

            if (Request.QueryString["Action"].Equals("edit"))
            {
                productDetails.ID = Int32.Parse(Request.QueryString["Pid"]);

                UpdateProductBizLogic logic = new UpdateProductBizLogic();
                BizResult result = logic.Execute(productDetails);

                if (result.Result)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }

                ShowProductDetails();
            }

            else if (Request.QueryString["Action"].Equals("append"))
            {
                InsertProductBizLogic logic = new InsertProductBizLogic();
                BizResult result = logic.Execute(productDetails);

                if (result.Result)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }
            }
            else
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }
    }
}
