﻿using System;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.Products;
using CAUtility.Logic.ProductKinds;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin
{
    public partial class ProductManager : SecurityPage
    {

        private string TransitionDefinition_OperationResult = string.Empty;

        private string QueryString_TargetCulture = string.Empty;

        private int QueryString_PageIndex = 1;

        private string QueryString_Cid = string.Empty;

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            TransitionDefinition_OperationResult = "ProductManager.aspx?TargetCulture=" + QueryString_TargetCulture;

            ShowClassificationNode();

            if (!string.IsNullOrEmpty(QueryString_Cid) && Request.QueryString["Action"] != null)
            {
                if (Request.QueryString["Action"].Equals("select"))
                {
                    this.ButtonAppend.PostBackUrl = "ProductEdit.aspx?Action=append&Cid=" + QueryString_Cid + "&TargetCulture=" + QueryString_TargetCulture;
                    this.ButtonAppend.Text = string.Format(MessageManager.GetValue(MessageKey.AdminD0020, System.Web.HttpUtility.UrlDecode(Request.QueryString["TagName"])));

                    ShowProductNode(QueryString_Cid);
                }
            }
            else
            {
                this.ButtonAppend.PostBackUrl = "ProductEdit.aspx?Action=append&TargetCulture=" + QueryString_TargetCulture;
            }
        }

        private void InitInterface()
        {
            this.ButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0052);
        }

        private void ShowProductNode(string kindsid)
        {
            DisplayProductListBizProcess param = new DisplayProductListBizProcess();
            param.KindsID = kindsid;
            param.PageIndex = QueryString_PageIndex;
            param.OnePageMaxItemsCount = CaSettings.ProductCountInPage;

            DisplayProductListBizLogic logic = new DisplayProductListBizLogic();
            DisplayProductListBizResult result = (DisplayProductListBizResult)logic.Execute(param);

            this.PageDivider1.OnePageMaxItemCount = CaSettings.ProductCountInPage;
            this.PageDivider1.DispalyPageCount = CaSettings.AdminTablePageDividerDisplayCount;
            this.PageDivider1.ItemCount = result.TotalProductCount;

            this.ZxrGridView1.DataSource = result.DataList;
            this.ZxrGridView1.DataBind();
        }

        private void ShowClassificationNode()
        {
            DisplayProductKindsListBizProcess param = new DisplayProductKindsListBizProcess();
            param.Culture = QueryString_TargetCulture;

            DisplayProductKindsListBizLogic logic = new DisplayProductKindsListBizLogic();
            DisplayProductKindsListBizResult result = (DisplayProductKindsListBizResult)logic.Execute(param);

            foreach (DisplayProductKindsListBizResultElement xx in result.DataList)
            {
                this.LabelKindsList.Text += "<a href=ProductManager.aspx?Action=select&Cid=" + xx.ID + "&TagName=" + System.Web.HttpUtility.UrlEncode(xx.Name) + "&TargetCulture=" + QueryString_TargetCulture + ">" + xx.Name + "</a>&nbsp;&nbsp;&nbsp;";
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }

            QueryString_Cid = Request.QueryString["Cid"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Page"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_PageIndex = Convert.ToInt32(Request.QueryString["Page"]);
                QueryString_PageIndex = QueryString_PageIndex == 0 ? 1 : QueryString_PageIndex;
            }
        }

        protected void ZxrGridView1_RowDeleting(object sender, System.Web.UI.WebControls.GridViewDeleteEventArgs e)
        {
            DeleteProductBizProcess param = new DeleteProductBizProcess();
            param.ID = this.ZxrGridView1.Rows[e.RowIndex].Cells[0].Text;

            DeleteProductBizLogic logic = new DeleteProductBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void ZxrGridView1_SelectedIndexChanging(object sender, System.Web.UI.WebControls.GridViewSelectEventArgs e)
        {
            Response.Redirect("ProductEdit.aspx?Action=edit&Pid=" + this.ZxrGridView1.Rows[e.NewSelectedIndex].Cells[0].Text + "&TargetCulture=" + QueryString_TargetCulture);
        }
    }
}
