﻿using System;

using ZXR.BusinessLogic;
using ZXR.Core;
using ZXR.Web.Controls;

using CAUtility.Logic.Products;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.ProductInfo
{

    public partial class ProductSettings : SecurityPage
    {

        private string TransitionDefinition_OperationResult = "FunctionPage.aspx";

        private string QueryString_TargetCulture = string.Empty;

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            TransitionDefinition_OperationResult = "FunctionPage.aspx?TargetCulture=" + QueryString_TargetCulture;

            if (!IsPostBack)
            {
                InitPage();
            }
        }

        private void InitInterface()
        {
            this.ButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0072);
            this.LabelColumnCount.Text = MessageManager.GetValue(MessageKey.AdminD0147);
            this.LabelIsShowProduct.Text = MessageManager.GetValue(MessageKey.AdminD0146);
            this.LabelIsSupportShopping.Text = MessageManager.GetValue(MessageKey.AdminD0145);
            this.LabelProductCountInPage.Text = MessageManager.GetValue(MessageKey.AdminD0148);
        }

        private void InitPage()
        {
            this.TextBoxColumnCount.Text = CaSettings.ProductColumnCount.ToString();
            this.TextBoxProductCountInPage.Text = CaSettings.ProductCountInPage.ToString();

            if (CaSettings.EnableProductInfo)
                this.RadioButtonIsShowProductYes.Checked = true;
            else
                this.RadioButtonIsShowProductNo.Checked = true;

            if (CaSettings.IsShoppingMode)
                this.RadioButtonShoppingYes.Checked = true;
            else
                this.RadioButtonShoppingNo.Checked = true;
        }

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {
            ProductSettingBizProcess param = new ProductSettingBizProcess();
            param.ProductColumnCount = this.TextBoxColumnCount.Text;
            param.IsShoppingMode = this.RadioButtonShoppingYes.Checked;
            param.EnableProductInfo = this.RadioButtonIsShowProductYes.Checked;
            param.ProductCountInPage = this.TextBoxProductCountInPage.Text;

            ProductSettingBizLogic logic = new ProductSettingBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }
    }
}
