﻿using System;

using ZXR.Core;
using ZXR.UI;
using ZXR.DataAccess;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;

using CAUtility.Logic.QuestionnaireManager.QuestionItem;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Questionnaire
{

    public partial class QuestionItemEdit : SecurityPage
    {

        private const string TransitionDefinition_OperationResult = "QuestionManager.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(CaSession.QuestionID))
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0016)) { ErrorType = ErrorType.OperationError };
            InitPage();
        }

        private void InitInterface()
        {
            this.CustomButtonEdit.Text = MessageManager.GetValue(MessageKey.AdminD0036);
            this.DisplayLabelTitle.Text = MessageManager.GetValue(MessageKey.AdminD0111);
        }

        private void InitPage()
        {
            ListQuestionItemBizProcess param = new ListQuestionItemBizProcess();
            param.QuestionID = CaSession.QuestionID;

            ListQuestionItemBizLogic logic = new ListQuestionItemBizLogic();
            ListQuestionItemBizResult result = (ListQuestionItemBizResult)logic.Execute(param);

            this.MenuTableList.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTableList.RowCount = result.DataList.Count + 1;
            this.MenuTableList.TurnBackNumber = 5;
            this.MenuTableList.CssClass = "AdminTable";

            if (result.DataList.Count > 0)
            {
                this.MenuTableList.AddContex("No.");
                this.MenuTableList.AddContex(MessageManager.GetValue(MessageKey.AdminD0125));
                this.MenuTableList.AddContex(MessageManager.GetValue(MessageKey.AdminD0071));
                this.MenuTableList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            }

            int rowIndex = 1;
            foreach (ListQuestionItemBizResultElement ele in result.DataList)
            {
                Label questionItemIDLable = new Label();
                questionItemIDLable.Text = ele.ID;
                this.MenuTableList.AddControl(questionItemIDLable);

                Label qContentLable = new Label();
                qContentLable.Text = ele.ItemContents;
                this.MenuTableList.AddControl(qContentLable);

                ValidatorTextBox itemOrder = new ValidatorTextBox();
                itemOrder.Width = new System.Web.UI.WebControls.Unit(50);
                itemOrder.ValidateMode = ControlValidateMode.Figure;
                itemOrder.IMEMode = ZxrTextBoxBase.ImeMode.Disabled;
                itemOrder.Text = ele.ItemOrder;
                this.MenuTableList.AddControl(itemOrder);

                ValidatorButton itemOrderChangeButton = new ValidatorButton();
                itemOrderChangeButton.UserDatas["ItemID"] = ele.ID;
                itemOrderChangeButton.UserDatas["Order"] = rowIndex.ToString();
                itemOrderChangeButton.Click += new EventHandler(itemOrderChangeButton_Click);
                itemOrderChangeButton.Text = MessageManager.GetValue(MessageKey.AdminD0112);
                this.MenuTableList.AddControl(itemOrderChangeButton);

                ValidatorButton deleteButton = new ValidatorButton();
                deleteButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.UserDatas["ItemID"] = ele.ID;
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTableList.AddControl(deleteButton);

                rowIndex++;
            }

            this.MenuTableList.Flush();
        }

        void itemOrderChangeButton_Click(object sender, EventArgs e)
        {
            int editRowIndex = int.Parse(((ValidatorButton)sender).UserDatas["Order"]);

            UpdateItemBizProcess param = new UpdateItemBizProcess();
            param.ID = ((ValidatorButton)sender).UserDatas["ItemID"];
            param.ItemOrder = ((ValidatorTextBox)this.MenuTableList.Rows[editRowIndex].Cells[2].Controls[0]).Text;

            UpdateItemBizLogic logic = new UpdateItemBizLogic();
            BizResult result = logic.Execute(param);
            if (result.Result == true)
            {
                Response.Redirect("~/Admin/Questionnaire/QuestionItemEdit.aspx");
            }
        }

        void deleteButton_Click(object sender, EventArgs e)
        {
            DeleteItemBizProcess param = new DeleteItemBizProcess();
            param.ID = ((ValidatorButton)sender).UserDatas["ItemID"];

            DeleteItemBizLogic logic = new DeleteItemBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                Response.Redirect("~/Admin/Questionnaire/QuestionItemEdit.aspx");
            }
        }

        protected void CustomButtonEdit_Click(object sender, EventArgs e)
        {
            string[] questionItems = StringUtility.SpiltString(this.CustomTextBoxQuestionItem.Text, "\n");

            ZxrTransaction insertTransaction = new ZxrTransaction();
            for (int i = 0 ; i < questionItems.Length; i++)
            {
                InsertQuestionItemBizProcess param = new InsertQuestionItemBizProcess();
                param.QuestionID = CaSession.QuestionID;
                param.ItemContents = questionItems[i];
                param.ItemOrder = (i + 1).ToString();

                InsertQuestionItemBizLogic logic = new InsertQuestionItemBizLogic();
                logic.JoinTransaction(insertTransaction);
                BizResult result = logic.Execute(param);
            }
            insertTransaction.Commit();

            Response.Redirect("~/Admin/Questionnaire/QuestionItemEdit.aspx");
        }

    }
}
