﻿using System;

using ZXR.Core;
using ZXR.UI;
using ZXR.DataAccess;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;

using CAUtility.Logic.QuestionnaireManager.Question;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Questionnaire
{

    public partial class QuestionManager : SecurityPage
    {

        private const string TransitionDefinition_OperationResult = "QuestionManager.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(CaSession.QuestionnaireID))
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0016)) { ErrorType = ErrorType.OperationError };

            InitPage();
        }

        private void InitInterface()
        {
            this.CustomButtonEdit.Text = MessageManager.GetValue(MessageKey.AdminD0105);
            this.DisplayLabelQuestionTitle.Text = MessageManager.GetValue(MessageKey.AdminD0108);
            this.DisplayLabelQuestionType.Text = MessageManager.GetValue(MessageKey.AdminD0109);
            this.DisplayLabelOrder.Text = MessageManager.GetValue(MessageKey.AdminD0110);
            this.LabelInputRows.Text = MessageManager.GetValue(MessageKey.AdminD0133);
        }

        private void InitPage()
        {
            this.LabelInputRows.Visible = false;
            this.TextBoxInputRows.Visible = false;

            if (!IsPostBack)
            {
                this.CustomDropDownListType.AddItem(MessageManager.GetValue(MessageKey.AdminD0126), "0");
                this.CustomDropDownListType.AddItem(MessageManager.GetValue(MessageKey.AdminD0127), "1");
                this.CustomDropDownListType.AddItem(MessageManager.GetValue(MessageKey.AdminD0128), "2");
            }

            ListQuestionBizProcess param = new ListQuestionBizProcess();
            param.QuestionnaireID = CaSession.QuestionnaireID;

            ListQuestionBizLogic logic = new ListQuestionBizLogic();
            ListQuestionBizResult result = (ListQuestionBizResult)logic.Execute(param);

            this.MenuTableQuestionList.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTableQuestionList.RowCount = result.DataList.Count + 1;
            this.MenuTableQuestionList.TurnBackNumber = 8;
            this.MenuTableQuestionList.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;
            this.MenuTableQuestionList.CssClass = "AdminTable";

            if (result.DataList.Count > 0)
            {
                this.MenuTableQuestionList.AddContex("No.");
                this.MenuTableQuestionList.AddContex(MessageManager.GetValue(MessageKey.AdminD0121));
                this.MenuTableQuestionList.AddContex(MessageManager.GetValue(MessageKey.AdminD0109));
                this.MenuTableQuestionList.AddContex("行数");
                this.MenuTableQuestionList.AddContex(MessageManager.GetValue(MessageKey.AdminD0071));
                this.MenuTableQuestionList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableQuestionList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableQuestionList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            }

            int rowIndex = 1;
            foreach (ListQuestionBizResultElement ele in result.DataList)
            {
                Label questionIDLable = new Label();
                questionIDLable.Text = ele.ID;
                this.MenuTableQuestionList.AddControl(questionIDLable);

                Label questionContentLable = new Label();
                questionContentLable.Text = ele.Contents;
                this.MenuTableQuestionList.AddControl(questionContentLable);

                DropDownList typeList = new DropDownList();
                typeList.AddItem(MessageManager.GetValue(MessageKey.AdminD0126), "0");
                typeList.AddItem(MessageManager.GetValue(MessageKey.AdminD0127), "1");
                typeList.AddItem(MessageManager.GetValue(MessageKey.AdminD0128), "2");
                typeList.SelectedValue = ele.QuestionType;
                this.MenuTableQuestionList.AddControl(typeList);

                ValidatorTextBox inputBoxRows = new ValidatorTextBox();
                inputBoxRows.Width = new System.Web.UI.WebControls.Unit(30);
                inputBoxRows.IMEMode = ZxrTextBoxBase.ImeMode.Disabled;
                inputBoxRows.ValidateMode = ControlValidateMode.Figure;
                if (string.Equals(ele.QuestionType, "2"))
                {
                    inputBoxRows.Text = ele.TextInputRows;
                    inputBoxRows.Enabled = true;
                }
                else
                {
                    inputBoxRows.Enabled = false;
                }
                this.MenuTableQuestionList.AddControl(inputBoxRows);

                ValidatorTextBox questionOrder = new ValidatorTextBox();
                questionOrder.Width = new System.Web.UI.WebControls.Unit(50);
                questionOrder.ValidateMode = ControlValidateMode.Figure;
                questionOrder.IMEMode = ZxrTextBoxBase.ImeMode.Disabled;
                questionOrder.Text = ele.QuestionOrder;
                this.MenuTableQuestionList.AddControl(questionOrder);

                ValidatorButton itemOrderChangeButton = new ValidatorButton();
                itemOrderChangeButton.UserDatas["QuestionID"] = ele.ID;
                itemOrderChangeButton.UserDatas["Order"] = rowIndex.ToString();
                itemOrderChangeButton.Click += new EventHandler(itemOrderChangeButton_Click);
                itemOrderChangeButton.Text = MessageManager.GetValue(MessageKey.AdminD0112);
                this.MenuTableQuestionList.AddControl(itemOrderChangeButton);

                Button itemAppendButton = new Button();
                itemAppendButton.UserDatas["QuestionID"] = ele.ID;
                itemAppendButton.Click += new EventHandler(itemAppendButton_Click);
                itemAppendButton.Text = MessageManager.GetValue(MessageKey.AdminD0123);
                itemAppendButton.Enabled = !string.Equals(ele.QuestionType, "2");
                this.MenuTableQuestionList.AddControl(itemAppendButton);

                Button deleteButton = new Button();
                deleteButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.UserDatas["QuestionID"] = ele.ID;
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTableQuestionList.AddControl(deleteButton);

                rowIndex++;
            }

            this.MenuTableQuestionList.Flush();
        }

        void deleteButton_Click(object sender, EventArgs e)
        {
            ZxrTransaction delTransaction = new ZxrTransaction();

            DeleteQuestionBizProcess param = new DeleteQuestionBizProcess();
            param.ID = ((Button)sender).UserDatas["QuestionID"];

            DeleteQuestionBizLogic logic = new DeleteQuestionBizLogic();
            logic.JoinTransaction(delTransaction);
            BizResult result = logic.Execute(param);

            DeleteItemsBizProcess itemsParam = new DeleteItemsBizProcess();
            itemsParam.QuestionID = ((Button)sender).UserDatas["QuestionID"];

            DeleteItemsBizLogic itemsLogic = new DeleteItemsBizLogic();
            itemsLogic.JoinTransaction(delTransaction);
            BizResult itemsResult = itemsLogic.Execute(itemsParam);

            delTransaction.Commit();
            Response.Redirect("~/Admin/Questionnaire/QuestionManager.aspx");
        }

        void itemOrderChangeButton_Click(object sender, EventArgs e)
        {
            int editRowIndex = int.Parse(((ValidatorButton)sender).UserDatas["Order"]);

            UpdateQuestionBizProcess param = new UpdateQuestionBizProcess();
            param.ID = ((ValidatorButton)sender).UserDatas["QuestionID"];
            param.QuestionType = ((DropDownList)this.MenuTableQuestionList.Rows[editRowIndex].Cells[2].Controls[0]).SelectedValue;
            param.TextInputRows = ((ValidatorTextBox)this.MenuTableQuestionList.Rows[editRowIndex].Cells[3].Controls[0]).Text;
            param.Order = ((ValidatorTextBox)this.MenuTableQuestionList.Rows[editRowIndex].Cells[4].Controls[0]).Text;

            UpdateQuestionBizLogic logic = new UpdateQuestionBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result == true)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        void itemAppendButton_Click(object sender, EventArgs e)
        {
            CaSession.QuestionID = ((Button)sender).UserDatas["QuestionID"];
            Response.Redirect("~/Admin/Questionnaire/QuestionItemEdit.aspx");
        }

        protected void CustomButtonEdit_Click(object sender, EventArgs e)
        {
            InsertQuestionBizProcess insertParam = new InsertQuestionBizProcess();
            insertParam.QuestionType = this.CustomDropDownListType.SelectedValue;
            insertParam.QuestionOrder = this.CustomTextBoxOrder.Text;
            insertParam.QuestionnaireID = CaSession.QuestionnaireID;
            insertParam.Contents = this.CustomTextBoxContents.Text;
            insertParam.TextInputRows = this.TextBoxInputRows.Text;

            InsertQuestionBizLogic insertLogic = new InsertQuestionBizLogic();
            BizResult insertResult = insertLogic.Execute(insertParam);

            if (insertResult.Result == true)
            {
                if (!string.Equals(this.CustomDropDownListType.SelectedValue, "2"))
                {
                    GetCurrentInsertedBizLogic getCurrentIndex = new GetCurrentInsertedBizLogic();
                    BizResult result = getCurrentIndex.Execute(null);

                    CaSession.QuestionID = result.ResultData.ToString();
                    Response.Redirect("~/Admin/Questionnaire/QuestionItemEdit.aspx");
                }
                else
                {
                    Response.Redirect("~/Admin/Questionnaire/QuestionManager.aspx");
                }
            }
        }

        protected void CustomDropDownListType_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (string.Equals(this.CustomDropDownListType.SelectedValue, "2"))
            {
                this.LabelInputRows.Visible = true;
                this.TextBoxInputRows.Visible = true;
            }
        }
    }

}
