﻿using System;

using ZXR.Core;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;

using CAUtility.Logic.QuestionnaireManager.Questionnaire;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Questionnaire
{

    public partial class QuestionnaireManager : SecurityPage
    {
        private const string FormPrefix = "Form";
        private const string QuestionnairePrefix = "Questionnaire";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            InitPage();
        }

        private void InitInterface()
        {
            this.CustomButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0104);
            this.DisplayLabelTitle.Text = MessageManager.GetValue(MessageKey.AdminD0107);
        }

        private void InitPage()
        {
            ListQuestionnaireBizLogic logic = new ListQuestionnaireBizLogic();
            ListQuestionnaireBizResult result = (ListQuestionnaireBizResult)logic.Execute(null);

            this.MenuTableQuestionnaireList.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTableQuestionnaireList.RowCount = result.DataList.Count + 1;
            this.MenuTableQuestionnaireList.TurnBackNumber = 5;
            this.MenuTableQuestionnaireList.CssClass = "AdminTable";

            if (result.DataList.Count > 0)
            {
                this.MenuTableQuestionnaireList.AddContex(MessageManager.GetValue(MessageKey.AdminD0119));
                this.MenuTableQuestionnaireList.AddContex(MessageManager.GetValue(MessageKey.AdminD0179));
                this.MenuTableQuestionnaireList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableQuestionnaireList.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableQuestionnaireList.AddContex(MessageManager.GetValue(MessageKey.AdminD0130));
            }

            foreach (ListQuestionnaireBizResultElement ele in result.DataList)
            {
                Label questionnaireTitleLable = new Label();
                questionnaireTitleLable.Text = ele.Title;
                this.MenuTableQuestionnaireList.AddControl(questionnaireTitleLable);

                Label codeLabel = new Label();
                codeLabel.Text = "++" + FormPrefix + "(" + ele.ID + ")++<br />++" + QuestionnairePrefix + "(" + ele.ID + ")++";
                this.MenuTableQuestionnaireList.AddControl(codeLabel);

                ValidatorButton updateButton = new ValidatorButton();
                updateButton.UserDatas["QuestionnaireID"] = ele.ID;
                updateButton.Click += new EventHandler(updateButton_Click);
                updateButton.Text = MessageManager.GetValue(MessageKey.AdminD0008);
                updateButton.ValidationGroup = "Admin";
                this.MenuTableQuestionnaireList.AddControl(updateButton);

                ValidatorButton deleteButton = new ValidatorButton();
                deleteButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.UserDatas["QuestionnaireID"] = ele.ID;
                deleteButton.Click += new EventHandler(deleteButton_Click);
                deleteButton.ValidationGroup = "Admin";
                this.MenuTableQuestionnaireList.AddControl(deleteButton);

                ValidatorButton sisButton = new ValidatorButton();
                sisButton.Text = MessageManager.GetValue(MessageKey.AdminD0114);
                sisButton.UserDatas["QuestionnaireID"] = ele.ID;
                sisButton.ValidationGroup = "Admin";
                sisButton.Click += new EventHandler(sisButton_Click);
                this.MenuTableQuestionnaireList.AddControl(sisButton);
            }

            this.MenuTableQuestionnaireList.Flush();
        }

        void sisButton_Click(object sender, EventArgs e)
        {
            CaSession.QuestionnaireID = ((ValidatorButton)sender).UserDatas["QuestionnaireID"];
            Response.Redirect("~/Admin/Questionnaire/ResponseList.aspx");
        }

        void deleteButton_Click(object sender, EventArgs e)
        {
            GetQuestionCounterBizProcess param = new GetQuestionCounterBizProcess();
            param.QuestionnaireID = ((ValidatorButton)sender).UserDatas["QuestionnaireID"];

            GetQuestionCounterBizLogic logic = new GetQuestionCounterBizLogic();
            BizResult result = logic.Execute(param);

            if (Convert.ToInt32(result.ResultData) == 0)
            {
                DeleteQuestionnaireBizProcess delParam = new DeleteQuestionnaireBizProcess();
                delParam.ID = ((ValidatorButton)sender).UserDatas["QuestionnaireID"];

                DeleteQuestionnaireBizLogic delLogic = new DeleteQuestionnaireBizLogic();
                BizResult delResult = delLogic.Execute(delParam);

                if (delResult.Result == true)
                {
                    Response.Redirect("~/Admin/Questionnaire/QuestionnaireManager.aspx");
                }
            }
            else
            {

                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminN0007));
            }
        }

        void updateButton_Click(object sender, EventArgs e)
        {
            CaSession.QuestionnaireID = ((ValidatorButton)sender).UserDatas["QuestionnaireID"];
            Response.Redirect("~/Admin/Questionnaire/QuestionManager.aspx");
        }

        protected void CustomButtonAppend_Click(object sender, EventArgs e)
        {
            InsertQuestionnaireBizProcess insertParam = new InsertQuestionnaireBizProcess();
            insertParam.QuestionnaireTitle = this.CustomTextBoxTitle.Text;

            InsertQuestionnaireBizLogic logic = new InsertQuestionnaireBizLogic();
            BizResult insertResult = logic.Execute(insertParam);

            if (insertResult.Result == true)
            {
                GetCurrentInsertedBizLogic getCurrentIndex = new GetCurrentInsertedBizLogic();
                BizResult result = getCurrentIndex.Execute(null);

                CaSession.QuestionnaireID = result.ResultData.ToString();
                Response.Redirect("~/Admin/Questionnaire/QuestionManager.aspx");
            }
        }

    }
}
