﻿using System;
using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.ReservationItem;

using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Reservation
{
    public partial class ItemEdit : SecurityPage
    {

        private const string TransitionDefinition_OperationResult = "ItemManager.aspx";

        private const string ItemUnit = "ItemUnit";

        private int QueryString_ItemId = 0;

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            if (!IsPostBack && QueryString_ItemId != 0)
            {

                ShowReservationDetails();
            }
            ReservationUnitCheck();
        }

        private void InitInterface()
        {
            this.LabelDetails.Text = MessageManager.GetValue(MessageKey.AdminD0016);
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0195);
            this.LabelDisplayDayUnit.Text = MessageManager.GetValue(MessageKey.AdminD0187);
            this.LabelIntervalTimeDis.Text = MessageManager.GetValue(MessageKey.AdminC0005);
            this.LabelDisableDateDetails.Text = MessageManager.GetValue(MessageKey.AdminC0006);
        }

        protected void RadioButtonUnitTime_CheckedChanged(object sender, EventArgs e)
        {
            ReservationUnitCheck();
        }

        private void ReservationUnitCheck()
        {
            if (IsPostBack ? this.RadioButtonUnitDay.Checked : Convert.ToInt32(this.ViewState[ItemUnit]) == -1 )//終日予約
            {
                this.RadioButtonUnitDay.Checked = true;
                this.HidenInfoPanel1.Visible = false;
                this.HidenInfoPanel2.Visible = false;

                this.RangeFigureValidator1.Enabled = false;
                this.RequiredFieldValidator1.Enabled = false;

                this.RequiredFieldValidator3.Enabled = false;
                this.RequiredFieldValidator4.Enabled = false;
            }
            else if (IsPostBack ? this.RadioButtonUnitRangeDate.Checked : Convert.ToInt32(this.ViewState[ItemUnit]) == -2)//連続日
            {
                this.RadioButtonUnitRangeDate.Checked = true;
                this.HidenInfoPanel1.Visible = false;
                this.HidenInfoPanel2.Visible = true;

                this.RequiredFieldValidator1.Enabled = true;
                this.RequiredFieldValidator3.Enabled = false;
                this.RequiredFieldValidator4.Enabled = false;

                this.LabelReservationLength.Text = MessageManager.GetValue(MessageKey.AdminD0188);
                this.LabelUnitDetails.Text = MessageManager.GetValue(MessageKey.AdminD0187);
            }
            else if (IsPostBack ? this.RadioButtonUnitEveryTime.Checked  : Convert.ToInt32(this.ViewState[ItemUnit]) == 0)//任意な時間
            {
                this.RadioButtonUnitEveryTime.Checked = true;
                this.HidenInfoPanel1.Visible = true;
                this.HidenInfoPanel2.Visible = false;

                this.RangeFigureValidator1.Enabled = false;
                this.RequiredFieldValidator1.Enabled = false;
                this.RequiredFieldValidator3.Enabled = true;
                this.RequiredFieldValidator4.Enabled = true;
            }
            else if (IsPostBack ? this.RadioButtonUnitTime.Checked  : Convert.ToInt32(this.ViewState[ItemUnit]) == 1)//時間予約
            {
                this.RadioButtonUnitTime.Checked = true;
                this.HidenInfoPanel1.Visible = true;
                this.HidenInfoPanel2.Visible = true;

                this.RequiredFieldValidator1.Enabled = true;
                this.RequiredFieldValidator3.Enabled = true;
                this.RequiredFieldValidator4.Enabled = true;

                this.LabelReservationLength.Text = MessageManager.GetValue(MessageKey.AdminD0185);
                this.LabelUnitDetails.Text = MessageManager.GetValue(MessageKey.AdminD0186);
            }
        }

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {

            UpdateItemBizProcess productDetails = new UpdateItemBizProcess();

            productDetails.CanMailNotify = "1";

            productDetails.CanRepetition = "1";

            productDetails.HolidayList = this.TimeCycle1.SelectedValue == null ? "" : this.TimeCycle1.SelectedValue.ToString();

            if (!string.IsNullOrEmpty(this.TextBoxUnit.Text))
            {
                productDetails.DatetimeLength = this.TextBoxUnit.Text;
            }
            else
            {
                productDetails.DatetimeLength = "0";
            }

            if (this.RadioButtonUnitDay.Checked)//終日予約
            {
                productDetails.Unit = "-1";
                productDetails.ReservationBeginTime = DateTime.MinValue.ToString("");
                productDetails.ReservationEndTime = DateTime.MaxValue.ToString("");
            }
            else if (this.RadioButtonUnitRangeDate.Checked)//連続日
            {
                productDetails.Unit = "-2";
                productDetails.ReservationBeginTime = DateTime.MinValue.ToString("");
                productDetails.ReservationEndTime = DateTime.MaxValue.ToString("");

                this.RequiredFieldValidator3.Enabled = false;
                this.RequiredFieldValidator4.Enabled = false;
            }
            else if (this.RadioButtonUnitEveryTime.Checked) //任意な時間
            {
                productDetails.Unit = "0";
                productDetails.ReservationBeginTime = this.TextBoxTimeBegin.Text;
                productDetails.ReservationEndTime = this.TextBoxTimeEnd.Text;
                productDetails.DatetimeLength = "5";
            }
            else //時間予約
            {
                productDetails.Unit = "1";
                productDetails.ReservationBeginTime = this.TextBoxTimeBegin.Text;
                productDetails.ReservationEndTime = this.TextBoxTimeEnd.Text;
            }

            productDetails.Name = this.CustomTextBoxProductName.Text;
            productDetails.Order = "1";
            productDetails.IntervalTime = this.CustomTextBoxIntervalTime.Text;
            productDetails.ItemDetail = this.ZxrEditorBox1.Text;
            productDetails.DisplayDateCount = this.TextBoxDispalyDayCount.Text;

            productDetails.SimultaneousNumber = this.CustomTextBoxSimultaneousNumber.Text;
            productDetails.Permission = "0";

            if (QueryString_ItemId != 0)
            {
                productDetails.ID = QueryString_ItemId.ToString();

                UpdateItemBizLogic logic = new UpdateItemBizLogic();
                BizResult result = logic.Execute(productDetails);

                if (result.Result)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }

                ShowReservationDetails();
            }

            else
            {
                InsertItemBizLogic logic = new InsertItemBizLogic();
                BizResult result = logic.Execute(productDetails);

                if (result.Result)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }
            }
        }

        private void ShowReservationDetails()
        {
            GetItemDetailBizProcess param = new GetItemDetailBizProcess();
            param.ID = QueryString_ItemId.ToString();

            GetItemDetailBizLogic logic = new GetItemDetailBizLogic();
            GetItemDetailBizResult reservationDetails = (GetItemDetailBizResult)logic.Execute(param);

            this.ViewState[ItemUnit] = reservationDetails.Unit;

            this.CustomTextBoxProductName.Text = reservationDetails.Name;
            this.CustomTextBoxIntervalTime.Text = reservationDetails.IntervalTime;

            if (!string.IsNullOrEmpty(reservationDetails.HolidayList))
            {
                this.TimeCycle1.SelectedValue = CycleDatetime.Parse(reservationDetails.HolidayList);
            }

            this.ZxrEditorBox1.Text = StringUtility.StringDecode(reservationDetails.ItemDetail);
            this.TextBoxUnit.Text = reservationDetails.DatetimeLength;
            this.TextBoxTimeBegin.Text = DateTime.Parse(reservationDetails.ReservationBeginTime).ToString("HH:mm");
            this.TextBoxTimeEnd.Text = DateTime.Parse(reservationDetails.ReservationEndTime).ToString("HH:mm");

            this.CustomTextBoxSimultaneousNumber.Text = reservationDetails.SimultaneousNumber;

            if (string.IsNullOrEmpty(reservationDetails.DisplayDateCount))
            {
                this.TextBoxDispalyDayCount.Text = "7";
            }
            else
            {
                this.TextBoxDispalyDayCount.Text = reservationDetails.DisplayDateCount;
            }

            if (string.Equals(reservationDetails.Unit, "-2"))
                this.RadioButtonUnitRangeDate.Checked = true;
            else if (string.Equals(reservationDetails.Unit, "-1"))
                this.RadioButtonUnitDay.Checked = true;
            else if (string.Equals(reservationDetails.Unit, "0"))
                this.RadioButtonUnitEveryTime.Checked = true;
            else
                this.RadioButtonUnitTime.Checked = true;
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ReservationId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ItemId = Convert.ToInt32(Request.QueryString["ReservationId"]);
        }
    }
}
