﻿using System;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.ReservationItem;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Reservation
{
    public partial class ItemManager : SecurityPage 
    {
        private const string ReservationPrefix = "Reservation";

        private const string TransitionDefinition_OperationResult = "ItemManager.aspx";

        private int QueryString_KindId = 0;

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();
            initItemList();
        }

        private void InitInterface()
        {
            this.ButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0184);
        }

        private void initItemList()
        {
            ReservationItemListBizLogic logic = new ReservationItemListBizLogic();
            ReservationItemListBizResult result = (ReservationItemListBizResult)logic.Execute(null);

            this.MenuTableProduct.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTableProduct.RowCount = result.DataList.Count + 1;
            this.MenuTableProduct.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;
            this.MenuTableProduct.TurnBackNumber = 4;
            this.MenuTableProduct.CssClass = "AdminTable";

            if (result.DataList.Count > 0)
            {
                this.MenuTableProduct.AddContex(MessageManager.GetValue(MessageKey.AdminD0181));
                this.MenuTableProduct.AddContex(MessageManager.GetValue(MessageKey.AdminD0179));
                this.MenuTableProduct.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
                this.MenuTableProduct.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            }

            foreach (ReservationItemListBizResultElement xx in result.DataList)
            {
                Label productName = new Label();
                productName.Text = xx.Name;
                this.MenuTableProduct.AddControl(productName);

                Label codeLabel = new Label();
                codeLabel.Text = "++" + ReservationPrefix + "(" + xx.ID + ")++";
                this.MenuTableProduct.AddControl(codeLabel);

                ValidatorButton editButton = new ValidatorButton();
                editButton.Text = "編集";
                editButton.UserDatas["ReservationId"] = xx.ID.ToString();
                editButton.Click += new EventHandler(editButton_Click);
                this.MenuTableProduct.AddControl(editButton);

                ValidatorButton deleteButton = new ValidatorButton();
                deleteButton.Text = "削除";
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.UserDatas["ReservationId"] = xx.ID.ToString();
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTableProduct.AddControl(deleteButton);
            }

            this.MenuTableProduct.Flush();
        }

        void editButton_Click(object sender, EventArgs e)
        {
            Response.Redirect("ItemEdit.aspx?ReservationId=" + ((ValidatorButton)sender).UserDatas["ReservationId"]);
        }

        void deleteButton_Click(object sender, EventArgs e)
        {
            DeleteItemBizProcess param = new DeleteItemBizProcess();
            param.ID = ((ValidatorButton)sender).UserDatas["ReservationId"];

            DeleteItemBizLogic logic = new DeleteItemBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["KindId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_KindId = Convert.ToInt32(Request.QueryString["KindId"]);
        }

        protected void ButtonAppend_Click(object sender, EventArgs e)
        {
            Response.Redirect("ItemEdit.aspx?Action=append&KindId=" + QueryString_KindId);
        }

    }
}
