﻿using System;
using System.Text.RegularExpressions;
using System.Globalization;

using ZXR.Core;
using ZXR.Log;
using ZXR.Web.Controls;

using ZXR.BusinessLogic;
using CAUtility.Logic.Settings;
using CAUtility.Pages;
using CAUtility;
using CAUtility.Logic.Common;

namespace WebApplication.Admin.Settings
{

    public partial class HighlevelSetting : SecurityPage
    {
        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();

            this.SelectCulturePageCulture.ArrayListDataSource = SupportCulture.LanguageList;
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                InitPage();
            }
        }

        private void InitInterface()
        {
            this.DisplayLabelNotify.Text = MessageManager.GetValue(MessageKey.AdminD0043);
            this.DisplayLabelDbDetails.Text = MessageManager.GetValue(MessageKey.AdminD0044);
            this.DisplayLabelDbAddress.Text = MessageManager.GetValue(MessageKey.AdminD0045);
            this.DisplayLabelDbPassword.Text = MessageManager.GetValue(MessageKey.AdminD0047);
            this.DisplayLabelAdminDetails.Text = MessageManager.GetValue(MessageKey.AdminD0049);
            this.DisplayLabelAdminCulture.Text = MessageManager.GetValue(MessageKey.AdminD0050);
            this.DisplayLabelPageDetails.Text = MessageManager.GetValue(MessageKey.AdminD0053);
            this.DisplayLabelPageDefaultCulture.Text = MessageManager.GetValue(MessageKey.AdminD0057);
            this.DisplayLabelBackup.Text = MessageManager.GetValue(MessageKey.AdminD0066);
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0008);
            this.LabelDataCacheCount.Text = MessageManager.GetValue(MessageKey.AdminD0054);
            this.LabelDataCacheTime.Text = MessageManager.GetValue(MessageKey.AdminD0051);
            this.LabelTrace.Text = MessageManager.GetValue(MessageKey.AdminD0058);
            this.LabelCoreSetting.Text = MessageManager.GetValue(MessageKey.AdminD0040);
            this.LabelDBPwDes.Text = MessageManager.GetValue(MessageKey.AdminC0013);

            this.DropDownListNewCulture.DataSource = CultureInfo.GetCultures(CultureTypes.SpecificCultures);
            this.DropDownListNewCulture.DataBind();
        }

        private void InitPage()
        {
            string filePath = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory, SettingManager.GetSettingValue("MessageDirectory"));

            string[] files = System.IO.Directory.GetFiles(filePath, "Admin.*.xml");

            foreach (string fileName in files)
            {
                Regex regex = new Regex(@"(.*)([\.])([a-z]{2}-[A-Z]{2})([\.]xml)");
                Match match = regex.Match(fileName);
                if (match.Success)
                {
                    string culture = regex.Replace(fileName, "$3");
                    this.DropDownListAdminCulture.AddItem(new System.Globalization.CultureInfo(culture).NativeName, culture);
                }
            }

            this.DropDownListAdminCulture.SelectedValue = CaSettings.AdminCulture;
            this.CustomTextBoxDbAddress.Text = SettingManager.GetSettingValue("AccessDbPath");

            this.SelectCulturePageCulture.SelectedValue = CaSettings.PageDefaultCulture;
            this.CustomTextBoxBackupPath.Text = CaSettings.BackupPath;
            this.TextBoxDataCacheCount.Text = CoreSettings.DataCacheCount.ToString();
            this.TextBoxDataCacheTime.Text = CoreSettings.DataCacheTime.ToString();

            if (CoreSettings.IsLogTrace == true)
            {
                this.RadioButtonCoreTraceOn.Checked = true;
            }
            else
            {
                this.RadioButtonCoreTraceOff.Checked = true;
            }
        }

        protected void CustomButton1_Click(object sender, EventArgs e)
        {
            HighLevelSettingBizProcess param = new HighLevelSettingBizProcess();
            param.AdminCulture = this.DropDownListAdminCulture.SelectedValue;
            param.AccessDbPath = this.CustomTextBoxDbAddress.Text;
            param.AccessDbPw = this.CustomTextBoxDbPassword.Text;
            param.Culture = this.SelectCulturePageCulture.SelectedValue;
            param.BackupPath = this.CustomTextBoxBackupPath.Text;
            param.DataCacheTime = Convert.ToInt32(this.TextBoxDataCacheTime.Text);
            param.DataCacheCount = Convert.ToInt32(this.TextBoxDataCacheCount.Text);
            param.IsLogTrace = this.RadioButtonCoreTraceOn.Checked;

            HighLevelSettingBizLogic logic = new HighLevelSettingBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                Logger.Info(MessageManager.GetValue(MessageKey.AdminL0001));
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030));
            }
        }

        protected void ButtonCreateNewCulture_Click(object sender, EventArgs e)
        {
            CreateNewCultureBizProcess newCultureParam = new CreateNewCultureBizProcess();
            newCultureParam.Culture = this.DropDownListNewCulture.SelectedValue;

            CreateNewCultureBizLogic logic = new CreateNewCultureBizLogic();
            BizResult result = logic.Execute(newCultureParam);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030));
            }
        }

    }
}
