﻿using System;
using System.Collections.Generic;

using ZXR.Core;
using ZXR.BusinessLogic;
using ZXR.Web;
using ZXR.Web.Controls;

using CAUtility.Logic.Sales;
using CAUtility.Logic.UserShoppingInfo;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Shopping
{
    public partial class OrderDetails : SecurityPage
    {

        private string QueryString_SalesId = string.Empty;

        private string userId_ = string.Empty;

        private const string TransitionDefinition_OperationResult = "OrderListManager.aspx";

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            if (!IsPostBack)
            {
                initOrderMaster();
                initOrderDetails();
                initUserInfo();
            }
        }

        private void initOrderMaster()
        {
            GetOneOrderMasterBizProcess param = new GetOneOrderMasterBizProcess();
            param.SalesID = QueryString_SalesId;

            GetOneOrderMasterBizLogic logic = new GetOneOrderMasterBizLogic();
            GetOneOrderMasterBizResult result = (GetOneOrderMasterBizResult)logic.Execute(param);

            this.LabelArrivalTime.Text = result.ArrivalTime;
            this.LabelRemark.Text = result.Remarks;
            this.LabelJyusyo.Text = result.Address;
            this.LabelYubin.Text = result.Zipcode;
            this.LabelTotal.Text = result.MonetaryAmount;
            this.LabelPurchase.Text = result.PurchaseDate.ToString();

            userId_ = result.UserID;
        }

        private void initOrderDetails()
        {
            GetOneOrderDetailsBizProcess param = new GetOneOrderDetailsBizProcess();
            param.SalesID = QueryString_SalesId;

            GetOneOrderDetailsBizLogic logic = new GetOneOrderDetailsBizLogic();
            GetOneOrderDetailsBizResult result = (GetOneOrderDetailsBizResult)logic.Execute(param);

            this.MenuTableOrderList.RowCount = result.DataList.Count + 1;
            this.MenuTableOrderList.TurnBackNumber = 5;
            this.MenuTableOrderList.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;

            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0003));
            this.MenuTableOrderList.AddContex("商品番号");
            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0004));
            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0005));
            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0009));

            foreach (GetOneOrderDetailsBizResultElement ele in result.DataList)
            {
                Label titleLable = new Label();
                titleLable.Text = ele.ProductName;
                this.MenuTableOrderList.AddControl(titleLable);

                Label productNumberLable = new Label();
                productNumberLable.Text = ele.ProductNumber;
                this.MenuTableOrderList.AddControl(productNumberLable);

                Label priceLable = new Label();
                priceLable.Text = ele.ProductPrice.ToString ();
                this.MenuTableOrderList.AddControl(priceLable);

                Label countLabel = new Label();
                countLabel.Text = ele.Amount.ToString ();
                this.MenuTableOrderList.AddControl(countLabel);

                Label subTotalLabel = new Label();
                subTotalLabel.Text = ele.Subtotal.ToString ();
                this.MenuTableOrderList.AddControl(subTotalLabel);

            }

            this.MenuTableOrderList.Flush();
        }

        private void initUserInfo()
        {
            GetUserDetailsBizProcess param = new GetUserDetailsBizProcess();
            param.UserID = userId_;

            GetUserDetailsBizLogic logic = new GetUserDetailsBizLogic();
            GetUserDetailsBizResult result = (GetUserDetailsBizResult)logic.Execute(param);

            this.LabelUserName.Text = result.Simei;
            this.LabelFurigana.Text = result.Furigana;
            this.LabelPCMail.Text = result.PCMail;
            this.LabelHomePhone.Text = result.HomePhone;

            if (string.IsNullOrEmpty(result.MobileMail))
                this.LabelMobileMail.Text = "ユーザーが記入提出していません。";
            else
                this.LabelMobileMail.Text = result.MobileMail;

            if (string.IsNullOrEmpty(result.Mobile))
                this.LabelMobile.Text = "ユーザーが記入していません。";
            else
                this.LabelMobile.Text = result.Mobile;
        }

        private void initQueryString()
        {
            if (string.IsNullOrEmpty (Request.QueryString["SalesId"]))
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_SalesId = Request.QueryString["SalesId"];
        }

        protected void ButtonChangeStatus_Click(object sender, EventArgs e)
        {
            ProcessOrderBizProcess param = new ProcessOrderBizProcess();
            param.SalesID = QueryString_SalesId;
            param.Status = this.DropDownListStatus.SelectedValue;

            ProcessOrderBizLogic logic = new ProcessOrderBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }
    }
}
