﻿using System;

using ZXR.Core;
using ZXR.Data;
using ZXR.Web.Controls;

using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.SideArea
{
    public partial class SideAreaEditor : SecurityPage
    {
        private const string SITE_CONTEXT_FILE_PATH = "~/App_Data/ContentsSetting.xml";

        private string QueryString_TargetCulture = string.Empty;

        private const string TransitionDefinition_OperationResult = "Default.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            if (!IsPostBack)
            {
                if (CaContext.Current.SideArea.ContainsKey(QueryString_TargetCulture))
                    this.ZxrEditorBox1.Text = CaContext.Current.SideArea[QueryString_TargetCulture];
            }
        }

        private void InitInterface()
        {
            this.LabelDesc.Text = MessageManager.GetValue(MessageKey.AdminD0183);
            this.ZxrButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0195);
        }

        protected void ZxrButtonUpdate_Click(object sender, EventArgs e)
        {
            XMLKeyOfValueData xk = new XMLKeyOfValueData(
                    System.Web.HttpContext.Current.Server.MapPath(SITE_CONTEXT_FILE_PATH)
                   );

            if (xk.SetValue(ContentsSettingArgs.SIDE + QueryString_TargetCulture, this.ZxrEditorBox1.Text))
            {
                CaContext.Current.SideArea[QueryString_TargetCulture] = this.ZxrEditorBox1.Text;

                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["TargetCulture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_TargetCulture = Request.QueryString["TargetCulture"];

                if (SupportCulture.IsSupport(QueryString_TargetCulture) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }
    }
}