﻿using System;
using System.Collections.Generic;

using ZXR.Core;
using ZXR.Data;
using ZXR.DataAccess;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;

using CAUtility.Logic.GroupInfo;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.UserManager
{
    public partial class GroupManagement : SecurityPage
    {

        private const string TransitionDefinition_Postback = "GroupEdit.aspx";

        private const string TransitionDefinition_OperationResult = "GroupManagement.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {

            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            ListGroupInfoBizLogic logic = new ListGroupInfoBizLogic();
            ListGroupInfoBizResult result = (ListGroupInfoBizResult)logic.Execute(null);

            this.MenuTable1.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTable1.TurnBackNumber = 3;
            this.MenuTable1.RowCount = result.DataList.Count + 1;
            this.MenuTable1.HorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;

            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0155));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            this.MenuTable1.AddContex(MessageManager.GetValue(MessageKey.AdminD0073));
            this.MenuTable1.CssClass = "AdminTable";

            foreach (ListGroupInfoBizResultElement node in result.DataList)
            {
                Label groupNameLabel = new Label();
                groupNameLabel.Text = node.GroupName.ToString();
                this.MenuTable1.AddControl(groupNameLabel);

                Button editButton = new Button();
                editButton.UserDatas["GroupID"] = node.GroupID.ToString();
                editButton.Click += new EventHandler(editButton_Click);
                editButton.Text = MessageManager.GetValue(MessageKey.AdminD0008);
                this.MenuTable1.AddControl(editButton);

                Button deleteButton = new Button();
                deleteButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                deleteButton.UserDatas["GroupID"] = node.GroupID.ToString();
                deleteButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTable1.AddControl(deleteButton);
            }

            this.MenuTable1.Flush();
        }

        void editButton_Click(object sender, EventArgs e)
        {
            Response.Redirect(TransitionDefinition_Postback + "?GroupId=" + ((Button)sender).UserDatas["GroupID"].ToString());
        }

        public void deleteButton_Click(object sender, EventArgs e)
        {
            ZxrTransaction transaction = new ZxrTransaction();

            DeleteGroupBizProcess param = new DeleteGroupBizProcess();
            param.GroupId = Convert.ToInt32(((Button)sender).UserDatas["GroupID"]);

            DeleteGroupBizLogic logic = new DeleteGroupBizLogic();
            logic.JoinTransaction(transaction);
            logic.Execute(param);
            transaction.Commit();

            WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
        }

        private void InitInterface()
        {
            this.ButtonAppend.Text = MessageManager.GetValue(MessageKey.AdminD0154);
        }

        protected void Append_Click(object sender, EventArgs e)
        {
            Response.Redirect(TransitionDefinition_Postback);
        }

    }
}
