﻿using System;

using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.DataAccess;

using CAUtility.Logic.UserInfo;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Admin.Settings
{
    public partial class UserManagement : SecurityPage
    {

        private int QueryString_PageIndex = 1;

        private const string TransitionDefinition_OperationResult = "UserManagement.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {

            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            UserListBizProcess param = new UserListBizProcess();
            param.PageIndex = QueryString_PageIndex;
            param.OnePageMaxItemsCount = CaSettings.AdminTableMaxDataCount;

            UserListBizLogic logic = new UserListBizLogic();
            UserListBizResult result = (UserListBizResult)logic.Execute(param);

            this.PageDivider1.ItemCount = result.TotalUserCount;
            this.PageDivider1.DispalyPageCount = CaSettings.AdminTablePageDividerDisplayCount;
            this.PageDivider1.OnePageMaxItemCount = CaSettings.AdminTableMaxDataCount;
            this.PageDivider1.Visible = true;

            this.ZxrGridView1.DataSource = result.DataList;
            this.ZxrGridView1.DataBind();
        }

        private void InitInterface()
        {
            this.CustomHyperLinkUserAppend.Text = MessageManager.GetValue(MessageKey.UserLoginS0016);
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Page"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_PageIndex = Convert.ToInt32(Request.QueryString["Page"]);
                QueryString_PageIndex = QueryString_PageIndex == 0 ? 1 : QueryString_PageIndex;
            }
        }

        protected void ZxrGridView1_RowDeleting(object sender, System.Web.UI.WebControls.GridViewDeleteEventArgs e)
        {
            ZxrTransaction transaction = new ZxrTransaction();
            DeleteUserBizProcess param = new DeleteUserBizProcess();
            param.UserName = this.ZxrGridView1.Rows[e.RowIndex].Cells[0].Text; ;

            DeleteUserBizLogic delLogic = new DeleteUserBizLogic();
            delLogic.JoinTransaction(transaction);
            delLogic.Execute(param);

            transaction.Commit();
            WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
        }
    }
}
