﻿using System;

using ZXR.BusinessLogic;
using ZXR.Core;
using ZXR.Web.Controls;

using CAUtility.Logic.UserInfo;
using CAUtility;
using CAUtility.Pages;
using CAUtility.Logic.GroupInfo;

namespace WebApplication.Admin.UserManager
{
    public partial class UserSettings : SecurityPage
    {

        private const string TransitionDefinition_OperationResult = "Default.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();

            ListGroupInfoBizLogic logic = new ListGroupInfoBizLogic();
            ListGroupInfoBizResult result = (ListGroupInfoBizResult)logic.Execute(null);
            this.DropDownListGroupInfoAdminPage.ViewText = "未設定";
            this.DropDownListGroupInfoNewRegist.ViewText = "未設定";
            foreach (ListGroupInfoBizResultElement node in result.DataList)
            {
                this.DropDownListGroupInfoAdminPage.AddItem(node.GroupName, node.GroupID.ToString());
                this.DropDownListGroupInfoNewRegist.AddItem(node.GroupName, node.GroupID.ToString());
            }

            this.CheckBoxListInternalUserGroup.DataSource = result.DataList;
            this.CheckBoxListInternalUserGroup.DataBind();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                InitPage();
            }
        }

        private void InitInterface()
        {
            this.LabelPassworkExpire.Text = MessageManager.GetValue(MessageKey.AdminD0143);
            this.LabelPasswordDes.Text = MessageManager.GetValue(MessageKey.AdminC0009);
            this.LabelAdminPage.Text = MessageManager.GetValue(MessageKey.AdminD0176);
            this.LabelInternal.Text = MessageManager.GetValue(MessageKey.AdminD0177);
            this.LabelNewRegist.Text = MessageManager.GetValue(MessageKey.AdminD0175);
            this.ButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0072);
            this.LabelVerifyImage.Text = MessageManager.GetValue(MessageKey.AdminD0192);
            this.LabelNickName.Text = MessageManager.GetValue(MessageKey.AdminD0193);
            this.LabelNickNameDes.Text = MessageManager.GetValue(MessageKey.AdminC0008);
        }

        private void InitPage()
        {
            this.TextBoxPasswordExpire.Text = CaSettings.UserPasswordExpires.ToString();

            this.DropDownListGroupInfoNewRegist.SelectedValue = CaSettings.NewRegistUserGroup.ToString();
            this.DropDownListGroupInfoAdminPage.SelectedValue = CaSettings.AdminPageUserGroup.ToString();

            foreach (System.Web.UI.WebControls.ListItem item in this.CheckBoxListInternalUserGroup.Items)
            {

                if (CaSettings.InternalPageUserGroup.Contains(item.Value))
                {
                    item.Selected = true;
                }
            }

            if (CaSettings.IsUserUseVerifyImage)
                this.RadioButtonYes.Checked = true;
            else
                this.RadioButtonNo.Checked = true;

            foreach (string str in CaSettings.ForbidsNickName)
            {
                this.TextBoxNickName.Text += str + ";";
            }

            if (!string.IsNullOrEmpty(this.TextBoxNickName.Text))
                this.TextBoxNickName.Text = this.TextBoxNickName.Text.Substring(0, this.TextBoxNickName.Text.Length - 1);
        }

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {
            UserSettingBizProcess param = new UserSettingBizProcess();
            param.UserPasswordExpires = Convert.ToInt32(this.TextBoxPasswordExpire.Text);
            param.AdminPageUserGroup = Convert.ToInt32(this.DropDownListGroupInfoAdminPage.SelectedValue);
            param.IsUserUseVerifyImage = this.RadioButtonYes.Checked;
            param.ForbidsNickName = this.TextBoxNickName.Text;

            foreach (System.Web.UI.WebControls.ListItem item in this.CheckBoxListInternalUserGroup.Items)
            {
                if (item.Selected)
                {
                    param.InternalPageUserGroup += item.Value + ";";
                }
            }

            param.NewRegistUserGroup = Convert.ToInt32(this.DropDownListGroupInfoNewRegist.SelectedValue);

            UserSettingBizLogic logic = new UserSettingBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }
    }
}
