﻿using System;

using ZXR.Core;
using ZXR.Security;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;
using CAUtility.Pages;

using CAUtility.Logic.UserInfo;
using CAUtility.Logic.GroupInfo;
using CAUtility;

namespace WebApplication.Admin.Settings
{
    public partial class UserUpdate : SecurityPage
    {

        private const string TransitionDefinition_OperationResult = "UserManagement.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();

            ListGroupInfoBizLogic logic = new ListGroupInfoBizLogic();
            ListGroupInfoBizResult result = (ListGroupInfoBizResult)logic.Execute(null);
            this.DropDownListGroupInfo.ViewText = "未設定";
            foreach (ListGroupInfoBizResultElement node in result.DataList)
            {
                this.DropDownListGroupInfo.AddItem(node.GroupName, node.GroupID.ToString());
            }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!string.IsNullOrEmpty(Request.QueryString["uid"]) )
            {
                if (!IsPostBack)
                {
                    SingleUserInfoBizProcess param = new SingleUserInfoBizProcess();
                    param.UserName = Request.QueryString["uid"].ToString();

                    SingleUserInfoBizLogic logic = new SingleUserInfoBizLogic();
                    SingleUserInfoBizResult result = (SingleUserInfoBizResult)logic.Execute(param);

                    if (result.Result == true)
                    {
                        this.DropDownListGroupInfo.SelectedValue = result.UserGroup.ToString();
                        this.TextBoxFriendlyName.Text = result.FriendlyName;
                    }
                }
            }
            else
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

        private void InitInterface()
        {
            this.DisplayLabelUsername.Text = Request.QueryString["uid"].ToString();
            this.DisplayLabelPassword.Text = MessageManager.GetValue(MessageKey.AdminD0003);
            this.DisplayLabelUserNameTitle.Text = MessageManager.GetValue(MessageKey.AdminD0002);
            this.DisplayLabelLevelTitle.Text = MessageManager.GetValue(MessageKey.UserLoginS0007);
            this.LabelFriendlyName.Text = MessageManager.GetValue(MessageKey.UserLoginS0041);
            this.CustomButtonUpdate.Text = MessageManager.GetValue(MessageKey.AdminD0008);
        }

        protected void CustomButtonUpdate_Click(object sender, EventArgs e)
        {
            if (string.Equals(this.CustomTextBoxPasswordChange.Text, this.CustomTextBoxPasswordConfirm.Text))
            {
                UpdateUserInfoBizProcess param = new UpdateUserInfoBizProcess();
                param.UserName = Request.QueryString["uid"].ToString();

                if (!string.IsNullOrEmpty(this.CustomTextBoxPasswordChange.Text))
                {
                    param.Password = Md5Cryptogram.Md5Hash(this.CustomTextBoxPasswordChange.Text);
                }

                param.UserGroup = Convert.ToInt32(this.DropDownListGroupInfo.SelectedValue);
                param.FriendlyName = this.TextBoxFriendlyName.Text;

                UpdateUserInfoBizLogic logic = new UpdateUserInfoBizLogic();
                BizResult result = logic.Execute(param);

                if (result.Result == true)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
                }
            }
            else
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminE0011));
            }
        }

    }
}
