﻿using System;
using System.Web;
using System.Reflection;

using ZXR.Web;
using ZXR.Log;
using ZXR.Core;

using CAUtility;
using CAUtility.Utility;

namespace WebApplication
{
    public class Global : System.Web.HttpApplication
    {

        private const string PLUGIN_INTERFACE_NAME = "CAUtility.Plugin.IContentInlinePlugin";

        private const string PLUGIN_MANAGEMENT_INTERFACE_NAME = "CAUtility.Plugin.IPluginManagerPage";

        protected void Application_Start(object sender, EventArgs e)
        {
            try
            {
                ZXR.Web.WebInitialization.Init();

                CaInitialization.InitApp();

                CaInitialization.InitPlugin();

                CaInitialization.InitUtilityContext();
            }
            catch (Exception ex)
            {
                ErrorOperation(ex);
            }
        }

        protected void Session_Start(object sender, EventArgs e)
        {
            SupportCulture.Init();

            if (!System.IO.Directory.Exists(System.Web.HttpContext.Current.Request.MapPath("~/Plugin")))
                return;

            foreach (string pluginFile in ZXR.IO.DirectoryIO.GetFilesInDirectory(System.Web.HttpContext.Current.Request.MapPath("~/Plugin")))
            {
                try
                {
                    Assembly assembly = Assembly.Load(System.IO.File.ReadAllBytes(pluginFile));
                    Type[] ts = assembly.GetTypes();
                    foreach (Type t in ts)
                    {
                        if (t.GetInterfaces().Length == 0)
                            continue;

                        foreach (Type fInterface in t.GetInterfaces())
                        {
                            if (string.Equals(fInterface.FullName, PLUGIN_INTERFACE_NAME))
                            {
                                bool hasExist = false;
                                foreach (Type tt in CaContext.Current.PluginList)
                                {
                                    if (string.Equals(tt.Name, t.Name))
                                    {
                                        hasExist = true;
                                        break;
                                    }
                                }

                                if (hasExist == false)
                                    CaContext.Current.PluginList.Add(t);
                            }
                            else if (string.Equals(fInterface.FullName, PLUGIN_MANAGEMENT_INTERFACE_NAME))
                            {
                                bool hasExist = false;
                                foreach (Type tt in CaContext.Current.PluginManagementList)
                                {
                                    if (string.Equals(tt.Name, t.Name))
                                    {
                                        hasExist = true;
                                        break;
                                    }
                                }

                                if (hasExist == false)
                                    CaContext.Current.PluginManagementList.Add(t);
                            }
                        }
                    }
                }
                catch (BadImageFormatException)
                {

                }
            }
        }

        protected void Application_PreSendRequestContent(object sender, EventArgs e)
        {

        }

        protected void Application_BeginRequest(object sender, EventArgs e)
        {
            if (!CaSettings.IsSiteOpen
                && HttpContext.Current.Request.Url.AbsoluteUri.IndexOf("Admin", StringComparison.CurrentCultureIgnoreCase) == -1
                && HttpContext.Current.Request.Url.AbsoluteUri.IndexOf("aspx", StringComparison.CurrentCultureIgnoreCase) > 0)
            {
                if (SupportCulture.IsSupport(System.Threading.Thread.CurrentThread.CurrentUICulture.Name))
                {
                    MessageManager.CultureTarget = System.Threading.Thread.CurrentThread.CurrentUICulture;
                }
                else
                {
                    MessageManager.CultureTarget = new System.Globalization.CultureInfo(CaSettings.AdminCulture);
                }

                Response.Write(MessageManager.GetValue(MessageKey.PageD0041));
                Response.End();
            }
            else
            {
                HttpApplication application = sender as HttpApplication;
                HttpContext context = application.Context;

                UrlUtility.UrlSecurityCheck(context.Request.Url.ToString());
            }
        }

        protected void Application_AuthenticateRequest(object sender, EventArgs e)
        {

        }

        protected void Application_Error(object sender, EventArgs e)
        {
            Exception ex = Server.GetLastError();

            ErrorOperation(ex);
        }

        private void ErrorOperation(Exception ex)
        {
            Exception exception = null;
            if (ex is System.Web.HttpUnhandledException)
                exception = ex.InnerException;
            else
                exception = ex;

            if (exception is ZxrException)
            {
                ZxrException error = exception as ZxrException;
                if (error.ErrorType == ErrorType.Generic)
                {
                    Logger.Error(error.Message, exception);
                    Response.Redirect("~/Common/ErrorPage/SystemError.aspx");
                }
                else if (error.ErrorType == ErrorType.AccessDenied)
                {
                    Logger.Info("[403Error]" + error.Message);
                    Response.Redirect("~/Common/ErrorPage/403.aspx?culture=" + SupportCulture.GetCultureFromUrl());
                }
                else
                {
                    string message = string.Empty;
                    if (!string.IsNullOrEmpty(ClientInfoContext.Current.UserPrincipal.UserName))
                    {
                        message = "User:[" + ClientInfoContext.Current.UserPrincipal.UserName + "]";
                    }
                    message += error.Message;
                    message += "Access URL:[" + Request.Url.ToString() + "]";
                    Logger.Info(message);

                    Response.Redirect("~/Common/ErrorPage/OperationError.aspx?culture=" + error.Culture + "&" +
                        "message=" + StringUtility.StringEncode(error.Message));
                }
            }
            else if (exception is System.Web.HttpException)
            {
                System.Web.HttpException error = exception as System.Web.HttpException;
                Logger.Error(exception.Message, exception);

                if (error.GetHttpCode() == 404)
                {
                    if (HttpContext.Current.Request.Url.LocalPath.EndsWith("aspx", StringComparison.OrdinalIgnoreCase)
                        || HttpContext.Current.Request.Url.LocalPath.EndsWith("htm", StringComparison.OrdinalIgnoreCase)
                        || HttpContext.Current.Request.Url.LocalPath.EndsWith("html", StringComparison.OrdinalIgnoreCase))
                        Response.Redirect("~/Common/ErrorPage/404.aspx?culture=" + SupportCulture.GetCultureFromUrl());
                }
                else
                {
                    Response.Redirect("~/Common/ErrorPage/OperationError.aspx?culture=" + SupportCulture.GetCultureFromUrl() + "&" +
                             "message=" + StringUtility.StringEncode(error.GetHttpCode().ToString() + " ERROR!"));
                }

#if !DEBUG
                string title = "CAシステムにHttpExceptionエラーが発生";
                string content = SettingManager.GetSettingValue("CompanyName") + "のCAシステムに致命なエラーが発生しました。\r\n";
                content += "エラーメッセージ：" + error.Message + "\r\n";
                content += "HTTP エラーコード：" + error.GetHttpCode() + "\r\n";
                content += "問題あるResource：" + System.Web.HttpContext.Current.Request.Url.ToString() + "\r\n";
                content += error.StackTrace + "\r\n";

                SendErrorMail(title, content);
#endif
            }
            else
            {
                Response.Redirect("~/Common/ErrorPage/SystemError.aspx");
                Logger.Error(exception.Message, exception);

#if !DEBUG
                string title = "CAシステムに予想されないエラーが発生";
                string content = CaContext.Current.CompanyName + "のCAシステムに致命なエラーが発生しました。\r\n";
                content += "Access URL:[" + Request.Url.ToString() + "]\r\n";
                content += exception.Message + "\r\n";
                content += exception.StackTrace + "\r\n";

                SendErrorMail(title, content);
#endif
                
            }
        }

        protected void Session_End(object sender, EventArgs e)
        {

        }

        protected void Application_End(object sender, EventArgs e)
        {

        }

        private void SendErrorMail(string title, string content)
        {
            MailUtil mail = new MailUtil();
            mail.SendErrorMail(title, content);
        }

    }
}