﻿using System;
using System.Text;

using ZXR.Web;
using ZXR.Core;
using CAUtility.Logic.GroupInfo;
using CAUtility;

namespace WebApplication.Internal.Schedule
{
    public partial class Default : CAUtility.Pages.InternalPage
    {

        private const string LinkFormat = "<a href=\"ScheduleDetail.aspx?ID={0}\">{1}～{2}&nbsp;&nbsp;{3}</a></br>";

        private const int DisplayDays = 7;

        private string QueryString_GroupId = string.Empty;

        private string QueryString_Year = string.Empty;

        private string QueryString_Month = string.Empty;

        private string QueryString_Day = string.Empty;

        protected void Page_Init(object sender, EventArgs e)
        {
            initGroupList();
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            initScheduleTable();
        }

        private void InitInterface()
        {
            this.HyperLinkRigist.Text = MessageManager.GetValue(MessageKey.ScheduleD0001);

            this.ImageCanClickHelp.OnClientClick = "window.open('../Help/Schedule."+ WebSession.UICulture +".htm', '', 'width=500,height=400,location=0'); return false;";
            this.ImageCanClickHelp.ImageUrl = "../../App_Themes/Default/Images/System/Help.png";
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["GroupID"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_GroupId = Request.QueryString["GroupID"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Year"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Year = Request.QueryString["Year"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Month"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Month = Request.QueryString["Month"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Day"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Day = Request.QueryString["Day"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Page"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_PageIndex = Convert.ToInt32(Request.QueryString["Page"]);
                QueryString_PageIndex = QueryString_PageIndex == 0 ? 1 : QueryString_PageIndex;
            }
        }

        private void initGroupList()
        {
            ListGroupInfoBizLogic logic = new ListGroupInfoBizLogic();
            ListGroupInfoBizResult result = (ListGroupInfoBizResult)logic.Execute(null);

            StringBuilder sb = new StringBuilder();
            sb.Append("<h1>");
            sb.Append(MessageManager.GetValue(MessageKey.ScheduleD0006));
            sb.Append ("</h1>");
            sb.Append("<ul id=\"GroupItem\"><li><a href=\"Default.aspx\">");
            sb.Append(MessageManager.GetValue(MessageKey.ScheduleD0029));
            sb.Append("</a></li>\r\n");
            sb.Append("<li><a href=\"Default.aspx?GroupID=-1\">");
            sb.Append(MessageManager.GetValue(MessageKey.ScheduleD0007));
            sb.Append("</a></li>\r\n");
            foreach (ListGroupInfoBizResultElement ele in result.DataList)
            {
                if (!CaSettings.InternalPageUserGroup.Contains(ele.GroupID.ToString()))
                    continue;

                sb.Append("<li><a href=\"Default.aspx?GroupID=");
                sb.Append(ele.GroupID);
                sb.Append("\">");
                sb.Append(ele.GroupName);
                sb.Append("</a></li>\r\n");
            }
            sb.Append("</ul>");

            this.LabelGroupList.Text = sb.ToString();
        }

        private void initScheduleTable()
        {
            DateTime dt = DateTime.Now.Date;
            if (!string.IsNullOrEmpty(QueryString_Day)
            && !string.IsNullOrEmpty(QueryString_Month)
            && !string.IsNullOrEmpty(QueryString_Year))
            {
                dt = new DateTime(
                    Convert.ToInt32(QueryString_Year),
                    Convert.ToInt32(QueryString_Month),
                    Convert.ToInt32(QueryString_Day));
            }

            if (!string.IsNullOrEmpty(QueryString_GroupId))//グループのスケジュールを表示
            {
                if (string.Equals(QueryString_GroupId, "-1"))
                {
                    initAllMemberSchedule(dt);
                }
                else
                {
                    initSpecifiedGroupSchedule(dt);
                }
            }
            else//ユーザーだけのスケジュールを表示
            {
                initSelfSchedule(dt);
            }
        }

    }
}
