﻿using System;
using System.Collections.Generic;
using System.Web.UI.WebControls;

using ZXR.Web;
using ZXR.Web.Controls;
using ZXR.Core;
using ZXR.BusinessLogic;
using ZXR.DataAccess;

using CAUtility.Logic.GroupInfo;
using CAUtility.Logic.Schedule;
using CAUtility.Logic.ScheduleJoinMember;
using CAUtility;

namespace WebApplication.Internal.Schedule
{
    public partial class Edit : CAUtility.Pages.InternalPage
    {

        private const string TransitionDefinition_OperationResult = "./Default.aspx";

        private const string OwnerUserViewName = "{0}OwnerUser";

        private int QueryString_Mode = 0;

        private string QueryString_GroupId = string.Empty;

        private string QueryString_ScheduleId = string.Empty;

        private string QueryString_UserName = string.Empty;

        private string QueryString_Year = string.Empty;

        private string QueryString_Month = string.Empty;

        private string QueryString_Day = string.Empty;

        private string ownerUserName_ = string.Empty;

        public string OwnerUserName
        {
            get
            {
                object obj = this.ViewState[string.Format(OwnerUserViewName, this.ID)];
                return obj == null ? this.ownerUserName_ : obj.ToString();
            }
            set
            {
                this.ownerUserName_ = value;
                this.ViewState[string.Format(OwnerUserViewName, this.ID)] = this.ownerUserName_;
            }
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            initInterface();

            initGroupList();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            if (!IsPostBack)
            {

                if (!string.IsNullOrEmpty(QueryString_UserName))
                    this.ListboxJoinMember.AddItem(QueryString_UserName, QueryString_UserName, false);

                if (!string.Equals(QueryString_UserName, ClientInfoContext.Current.UserPrincipal.UserName))
                    this.ListboxJoinMember.AddItem(ClientInfoContext.Current.UserPrincipal.UserName, ClientInfoContext.Current.UserPrincipal.UserName, false);
            }
            else
            {
                if (!string.IsNullOrEmpty(this.Request.Form[this.ListboxJoinMember.ClientID.Replace("_", "$")]))
                {
                    foreach (string item in this.Request.Form[this.ListboxJoinMember.ClientID.Replace("_", "$")].Split(','))
                        this.ListboxJoinMember.AddItem(item, item, false);
                }
            }

            foreach (ListItem li in this.ListboxJoinMember.Items)
                li.Selected = true;

            if (!string.IsNullOrEmpty(QueryString_Day)
                && !string.IsNullOrEmpty(QueryString_Month)
                && !string.IsNullOrEmpty(QueryString_Year))
            {
                this.PopupCalendarStartDate.SelectedDate = new DateTime(
                    Convert.ToInt32(QueryString_Year),
                    Convert.ToInt32(QueryString_Month),
                    Convert.ToInt32(QueryString_Day));

                if (QueryString_Mode == 2 || QueryString_Mode == 1)
                    this.PopupCalendarEndDate.SelectedDate = new DateTime(
                        Convert.ToInt32(QueryString_Year),
                        Convert.ToInt32(QueryString_Month),
                        Convert.ToInt32(QueryString_Day));
            }

            if (!string.IsNullOrEmpty(QueryString_ScheduleId))
            {
                if ( !IsPostBack )
                    initSchedule();

                this.ButtonRegist.Text = MessageManager.GetValue(MessageKey.ScheduleD0027);
                this.Panel1.Visible = false;
            }

            ScheduleModeChange(QueryString_Mode);
        }

        private void initInterface()
        {
            this.TimeCycle1.Visible = false;
            this.PopupCalendarEndDate.Visible = false;

            this.PopupCalendarStartDate.Visible = true;
            this.TimeSelectEndTime.Visible = true;
            this.TimeSelectStartTime.Visible = true;

            this.LinkButtonNormal.Text = MessageManager.GetValue(MessageKey.ScheduleD0009);
            this.LinkButtonRepeat.Text = MessageManager.GetValue(MessageKey.ScheduleD0002);
            this.LinkButtonContinuous.Text = MessageManager.GetValue(MessageKey.ScheduleD0003);

            this.LabelTitle.Text = MessageManager.GetValue(MessageKey.ScheduleD0010);
            this.LabelDescription.Text = MessageManager.GetValue(MessageKey.ScheduleD0011);
            this.LabelDate.Text = MessageManager.GetValue(MessageKey.ScheduleD0012);
            this.LabelTime.Text = MessageManager.GetValue(MessageKey.ScheduleD0013);
            this.LabelJoinMember.Text = MessageManager.GetValue(MessageKey.ScheduleD0014);
            this.LabelParticipant.Text = MessageManager.GetValue(MessageKey.ScheduleD0014);
            this.LabelGroup.Text = MessageManager.GetValue(MessageKey.ScheduleD0015);
            this.CheckBoxAfter.Text = MessageManager.GetValue(MessageKey.ScheduleD0018);
            this.ButtonRegist.Text = MessageManager.GetValue(MessageKey.ScheduleD0017);
            this.ButtonCancel.Text = MessageManager.GetValue(MessageKey.ScheduleD0030);
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["GroupID"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_GroupId = Request.QueryString["GroupID"];

            if (string.IsNullOrEmpty(QueryString_GroupId))
            {
                QueryString_GroupId = "0";
            }

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["SID"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ScheduleId = Request.QueryString["SID"];

            QueryString_UserName = Request.QueryString["UserName"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Mode"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Mode = Convert.ToInt32(Request.QueryString["Mode"]);

            if (!string.IsNullOrEmpty(QueryString_UserName) && !string.Equals(QueryString_GroupId, "0"))
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Year"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Year = Request.QueryString["Year"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Month"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Month = Request.QueryString["Month"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Day"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Day = Request.QueryString["Day"];
        }

        private void initSchedule()
        {
            {//スケジュールの詳細情報を取得する
                ScheduleDetailBizProcess param = new ScheduleDetailBizProcess();
                param.ID = Convert.ToInt32(QueryString_ScheduleId);

                ScheduleDetailBizLogic logic = new ScheduleDetailBizLogic();
                ScheduleDetailBizResult result = (ScheduleDetailBizResult)logic.Execute(param);

                this.TextBoxDescription.Text = result.Description;
                this.TextBoxTitle.Text = result.Title;

                this.PopupCalendarStartDate.SelectedDate = result.StartTime.Date;
                this.PopupCalendarEndDate.SelectedDate = result.EndTime.Date;
                this.TimeSelectStartTime.SelectedTime = result.StartTime;
                this.TimeSelectEndTime.SelectedTime = result.EndTime;
                this.OwnerUserName = result.AuthorID;

                ScheduleModeChange(result.Type);

                if (result.Type == 1)
                {
                    this.TimeCycle1.SelectedValue = CycleDatetime.Parse(result.RepeatString);
                }
            }

            {//スケジュールに参加するメンバーを取得する
                ListScheduleJoinMemberBizProcess param = new ListScheduleJoinMemberBizProcess();
                param.ScheduleID = Convert.ToInt32(QueryString_ScheduleId);

                ListScheduleJoinMemberBizLogic logic = new ListScheduleJoinMemberBizLogic();
                ListScheduleJoinMemberBizResult result = (ListScheduleJoinMemberBizResult)logic.Execute(param);

                foreach (ListScheduleJoinMemberBizResultElement ele in result.DataList)
                {

                    this.LabelJoinMemberList.Text += ele.FriendlyName + "<br />";
                }

            }
        }

        private void initGroupList()
        {
            ListGroupInfoBizLogic logic = new ListGroupInfoBizLogic();
            ListGroupInfoBizResult result = (ListGroupInfoBizResult)logic.Execute(null);

            this.DropDownListGroup.ViewText = MessageManager.GetValue(MessageKey.ScheduleD0016);
            this.DropDownListGroup.AddItem(MessageManager.GetValue(MessageKey.ScheduleD0007), "0");
            foreach (ListGroupInfoBizResultElement ele in result.DataList)
            {
                if (!CaSettings.InternalPageUserGroup.Contains(ele.GroupID.ToString()))
                    continue;

                this.DropDownListGroup.AddItem(ele.GroupName, ele.GroupID.ToString());
            }
        }

        protected void ButtonRegist_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(QueryString_ScheduleId) && string.IsNullOrEmpty ( this.Request.Form[this.ListboxJoinMember.ClientID.Replace("_", "$")]))
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.ScheduleD0028));
                return;
            }

            ZxrTransaction transaction = new ZxrTransaction();

            if (string.IsNullOrEmpty(QueryString_ScheduleId))//新規登録
            {
                int currentRegestedScheduleId = 0;
                {
                    DateTime dt = DateTime.Now;

                    InsertScheduleBizProcess param = new InsertScheduleBizProcess();
                    if (QueryString_Mode == 2)
                    {
                        param.StartTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString());
                        param.EndTime = DateTime.Parse(this.PopupCalendarEndDate.GetDateString());
                    }
                    else if (QueryString_Mode == 1)
                    {
                        param.StartTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString() + " " + this.TimeSelectStartTime.GetaTimeString());
                        param.EndTime = DateTime.Parse(this.PopupCalendarEndDate.GetDateString() + " " + this.TimeSelectEndTime.GetaTimeString());
                    }
                    else
                    {
                        param.StartTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString() + " " + this.TimeSelectStartTime.GetaTimeString());
                        param.EndTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString() + " " + this.TimeSelectEndTime.GetaTimeString());
                    }

                    if ((param.EndTime - param.StartTime).Ticks < 0)
                    {
                        WebMessageBox.Show(MessageKey.ScheduleE0002);
                        return;
                    }

                    param.Title = this.TextBoxTitle.Text;
                    param.Description = this.TextBoxDescription.Text;
                    param.RegistedTime = dt;
                    param.AuthorID = ClientInfoContext.Current.UserPrincipal.UserName;
                    param.GroupId = Convert.ToInt32(QueryString_GroupId);
                    param.Type = QueryString_Mode;
                    if (QueryString_Mode == 1)
                    {
                        param.RepeatString = this.TimeCycle1.SelectedValue.ToString();
                    }

                    InsertScheduleBizLogic logic = new InsertScheduleBizLogic();
                    logic.JoinTransaction(transaction);
                    logic.Execute(param);

                    GetCurrentRegistedBizProcess currentParam = new GetCurrentRegistedBizProcess();
                    currentParam.UserName = ClientInfoContext.Current.UserPrincipal.UserName;
                    currentParam.RegistedTime = dt;

                    GetCurrentRegistedBizLogic currentLogic = new GetCurrentRegistedBizLogic();
                    currentLogic.JoinTransaction(transaction);
                    BizResult currentResult = currentLogic.Execute(currentParam);

                    currentRegestedScheduleId = Convert.ToInt32(currentResult.ResultData);
                }

                {
                    foreach (string item in this.Request.Form[this.ListboxJoinMember.ClientID.Replace("_", "$")].Split(','))
                    {
                        JoinScheduleBizProcess param = new JoinScheduleBizProcess();
                        param.UserName = item;
                        param.ID = currentRegestedScheduleId;

                        JoinScheduleBizLogic logic = new JoinScheduleBizLogic();
                        logic.JoinTransaction(transaction);
                        logic.Execute(param);
                    }
                }
            }
            else//編集
            {
                if (!string.Equals(this.OwnerUserName, ClientInfoContext.Current.UserPrincipal.UserName))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.ScheduleE0001));
                    return;
                }

                UpdateScheduleBizProcess param = new UpdateScheduleBizProcess();
                param.Description = this.TextBoxDescription.Text;
                param.Title = this.TextBoxTitle.Text;
                if (QueryString_Mode == 2)
                {
                    param.StartTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString());
                    param.EndTime = DateTime.Parse(this.PopupCalendarEndDate.GetDateString());
                }
                else if (QueryString_Mode == 1)
                {
                    param.StartTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString() + " " + this.TimeSelectStartTime.GetaTimeString());
                    param.EndTime = DateTime.Parse(this.PopupCalendarEndDate.GetDateString() + " " + this.TimeSelectEndTime.GetaTimeString());
                }
                else
                {
                    param.StartTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString() + " " + this.TimeSelectStartTime.GetaTimeString());
                    param.EndTime = DateTime.Parse(this.PopupCalendarStartDate.GetDateString() + " " + this.TimeSelectEndTime.GetaTimeString());
                }

                if ((param.EndTime - param.StartTime).Ticks < 0)
                {
                    WebMessageBox.Show("「終了」は「開始」より遅く指定されています。");
                    return;
                }

                param.ID = QueryString_ScheduleId;
                param.Type = QueryString_Mode;
                if (QueryString_Mode == 1)
                {
                    param.RepeatString = this.TimeCycle1.SelectedValue.ToString();
                }

                UpdateScheduleBizLogic logic = new UpdateScheduleBizLogic();
                logic.JoinTransaction(transaction);
                logic.Execute(param);
            }

            transaction.Commit();

            WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
        }

        protected void DropDownListGroup_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.ListboxGroupMember.Items.Clear();

            int groupid = Convert.ToInt32(this.DropDownListGroup.SelectedValue);

            if (groupid > 0)
            {
                ListGroupUsersBizProcess param = new ListGroupUsersBizProcess();
                param.GroupList = new List<string>() { groupid.ToString() };

                ListGroupUsersBizLogic logic = new ListGroupUsersBizLogic();
                ListGroupUsersBizResult result = (ListGroupUsersBizResult)logic.Execute(param);

                foreach (ListGroupUsersBizResultElement ele in result.DataList)
                {
                    this.ListboxGroupMember.AddItem(ele.UserName, ele.UserName);
                }
            }
            else if (groupid == 0)
            {
                ListGroupUsersBizProcess param = new ListGroupUsersBizProcess();
                param.GroupList = CaSettings.InternalPageUserGroup;

                ListGroupUsersBizLogic logic = new ListGroupUsersBizLogic();
                ListGroupUsersBizResult result = (ListGroupUsersBizResult)logic.Execute(param);

                foreach (ListGroupUsersBizResultElement ele in result.DataList)
                {
                    this.ListboxGroupMember.AddItem(ele.UserName, ele.UserName);
                }
            }
        }

        protected void LinkButtonNormal_Click(object sender, EventArgs e)
        {
            Response.Redirect(UrlUtility.SetQuerystring("Mode", "0"));
        }

        protected void LinkButtonRepeat_Click(object sender, EventArgs e)
        {
            Response.Redirect(UrlUtility.SetQuerystring("Mode", "1"));
        }

        protected void LinkButtonContinuous_Click(object sender, EventArgs e)
        {
            Response.Redirect(UrlUtility.SetQuerystring("Mode", "2"));
        }

        private void ScheduleModeChange(int typeID)
        {
            if (typeID == 0)
            {
                this.TimeCycle1.Visible = false;
                this.TimeSelectEndTime.Visible = true;
                this.TimeSelectStartTime.Visible = true;

                this.PopupCalendarEndDate.Visible = false;
                this.PopupCalendarStartDate.Visible = true;
                this.CheckBoxAfter.Visible = false;
                this.LabelRange1.Visible = false;
                this.LabelRange2.Visible = true;
                this.LabelTime.Visible = true;

                this.LinkButtonNormal.BackColor = System.Drawing.Color.White;
                this.LinkButtonRepeat.BackColor = System.Drawing.Color.Gray;
                this.LinkButtonContinuous.BackColor = System.Drawing.Color.Gray;
            }
            else if (typeID == 1)
            {
                this.TimeCycle1.Visible = true;
                this.TimeSelectEndTime.Visible = true;
                this.TimeSelectStartTime.Visible = true;

                this.PopupCalendarEndDate.Visible = true;
                this.PopupCalendarStartDate.Visible = true;
                this.CheckBoxAfter.Visible = true;
                this.LabelRange1.Visible = true;
                this.LabelRange2.Visible = true;
                this.LabelTime.Visible = true;

                this.LinkButtonNormal.BackColor = System.Drawing.Color.Gray;
                this.LinkButtonRepeat.BackColor = System.Drawing.Color.White;
                this.LinkButtonContinuous.BackColor = System.Drawing.Color.Gray;
            }
            else if (typeID == 2)
            {
                this.TimeCycle1.Visible = false;
                this.TimeSelectEndTime.Visible = false;
                this.TimeSelectStartTime.Visible = false;

                this.PopupCalendarEndDate.Visible = true;
                this.PopupCalendarStartDate.Visible = true;
                this.CheckBoxAfter.Visible = false;
                this.LabelRange1.Visible = true;
                this.LabelRange2.Visible = false;
                this.LabelTime.Visible = false;

                this.LinkButtonNormal.BackColor = System.Drawing.Color.Gray;
                this.LinkButtonRepeat.BackColor = System.Drawing.Color.Gray;
                this.LinkButtonContinuous.BackColor = System.Drawing.Color.White;
            }
        }

        protected void ButtonCancel_Click(object sender, EventArgs e)
        {
            Response.Redirect("Default.aspx");
        }

    }
}
