﻿using System;

using ZXR.Web.Controls;
using ZXR.Core;
using ZXR.BusinessLogic;
using ZXR.DataAccess;

using CAUtility.Logic.Schedule;
using CAUtility.Logic.ScheduleJoinMember;
using CAUtility;

namespace WebApplication.Internal.Schedule
{
    public partial class ScheduleDetail : CAUtility.Pages.InternalPage
    {

        private const string TransitionDefinition_OperationResult = "./Default.aspx";

        private string QueryString_ScheduleId = string.Empty;

        protected void Page_Init(object sender, EventArgs e)
        {
            initInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();
            initScheduleDetail();
        }

        private void initInterface()
        {
            this.LabelTitleDes.Text = MessageManager.GetValue(MessageKey.ScheduleD0010);
            this.LabelDescriptionDes.Text = MessageManager.GetValue(MessageKey.ScheduleD0011);
            this.LabelJoinMemberDes.Text = MessageManager.GetValue(MessageKey.ScheduleD0014);
            this.LabelHistoryDes.Text = MessageManager.GetValue(MessageKey.ScheduleD0019);
            this.LabelTimeDes.Text = MessageManager.GetValue(MessageKey.ScheduleD0025);
            this.LabelStatusDes.Text = MessageManager.GetValue(MessageKey.ScheduleD0026);

            this.ButtonQuite.Text = MessageManager.GetValue(MessageKey.ScheduleD0020);
            this.ButtonJoin.Text = MessageManager.GetValue(MessageKey.ScheduleD0021);
            this.ButtonUpdate.Text = MessageManager.GetValue(MessageKey.ScheduleD0022);
            this.ButtonCancel.Text = MessageManager.GetValue(MessageKey.ScheduleD0023);
            this.ButtonRevival.Text = MessageManager.GetValue(MessageKey.ScheduleD0024);
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ID"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ScheduleId = Request.QueryString["ID"];
        }

        public void initScheduleDetail()
        {
            ZxrTransaction transacation = new ZxrTransaction();

            ScheduleDetailBizProcess detailparam = new ScheduleDetailBizProcess();
            detailparam.ID = Convert.ToInt32(QueryString_ScheduleId);

            ScheduleDetailBizLogic detailslogic = new ScheduleDetailBizLogic();
            detailslogic.JoinTransaction(transacation);
            ScheduleDetailBizResult detailresult = (ScheduleDetailBizResult)detailslogic.Execute(detailparam);

            this.LabelTitle.Text = detailresult.Title;
            this.LabelDescription.Text = detailresult.Description;
            this.LabelAuthor.Text = string.IsNullOrEmpty(detailresult.FriendlyName) ? detailresult.AuthorID : detailresult.FriendlyName;
            if (detailresult.LastUpdateTime.CompareTo(DateTime.MinValue) == 1)
                this.LabelHistory.Text = detailresult.LastUpdateTime.ToString("yyyy/MM/dd HH:mm:ss");
            this.ButtonUpdate.UserDatas["Mode"] = detailresult.Type.ToString();

            if (detailresult.Type == 0)
            {
                this.LabelTime.Text = detailresult.StartTime.ToString("yyyy年MM月dd日 HH:mm:ss");
            }
            else if (detailresult.Type == 1)
            {
                this.LabelTime.Text = ZXR.Web.CycleDate.ToFriendlyString(CycleDatetime.Parse(detailresult.RepeatString));
            }
            else
            {
                this.LabelTime.Text = detailresult.StartTime.ToString("yyyy年MM月dd日") + "～" + detailresult.EndTime.ToString("yyyy年MM月dd日");
            }

            if (string.Equals(detailresult.Status, DataStatus.Cancel.ToString()))
            {
                this.LabelStatus.Text = "キャンセルされました";
            }
            else if (string.Equals(detailresult.Status, DataStatus.Cancel.ToString()))
            {
                this.LabelStatus.Text = "変更されました";
            }
            else
            {
                this.LabelStatus.Text = "正常";
            }

            if (string.Equals(detailresult.AuthorID, ClientInfoContext.Current.UserPrincipal.UserName))
            {
                this.ButtonCancel.Visible = true;
                this.ButtonUpdate.Visible = true;

                if (string.Equals(detailresult.Status, DataStatus.Cancel.ToString()))
                {
                    this.ButtonCancel.Visible = false;
                    this.ButtonRevival.Visible = true;
                }
                else
                {
                    this.ButtonCancel.Visible = true;
                    this.ButtonRevival.Visible = false;
                }
            }
            else
            {
                this.ButtonUpdate.Visible = false;
                this.ButtonCancel.Visible = false;
                this.ButtonRevival.Visible = false;
            }

            {//参加者のリストを取得する
                ListScheduleJoinMemberBizProcess param = new ListScheduleJoinMemberBizProcess();
                param.ScheduleID = Convert.ToInt32(QueryString_ScheduleId);

                ListScheduleJoinMemberBizLogic logic = new ListScheduleJoinMemberBizLogic();
                logic.JoinTransaction(transacation);
                ListScheduleJoinMemberBizResult result = (ListScheduleJoinMemberBizResult)logic.Execute(param);

                bool isInList = false;
                foreach (ListScheduleJoinMemberBizResultElement ele in result.DataList)
                {
                    this.LabelJoinMember.Text += (string.IsNullOrEmpty(ele.FriendlyName) ? ele.UserName : ele.FriendlyName) + "<br />";
                    if (string.Equals(ele.UserName, ClientInfoContext.Current.UserPrincipal.UserName))
                    {
                        isInList = true;
                    }
                }

                if (isInList && !string.Equals (detailresult.Status, DataStatus.Cancel.ToString() ) )
                {
                    this.ButtonQuite.Visible = true;
                    this.ButtonJoin.Visible = false;
                }
                else if (!isInList && !string.Equals(detailresult.Status, DataStatus.Cancel.ToString()))
                {
                    this.ButtonQuite.Visible = false;
                    this.ButtonJoin.Visible = true;
                }
                else
                {
                    this.ButtonQuite.Visible = false;
                    this.ButtonJoin.Visible = false;
                }
            }

            transacation.Commit();
        }

        protected void ButtonJoin_Click(object sender, EventArgs e)
        {
            JoinScheduleBizProcess param = new JoinScheduleBizProcess();
            param.ID = Convert.ToInt32(QueryString_ScheduleId);
            param.UserName = ClientInfoContext.Current.UserPrincipal.UserName;

            JoinScheduleBizLogic logic = new JoinScheduleBizLogic();
            BizResult result =  logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void ButtonQuite_Click(object sender, EventArgs e)
        {
            DeleteJoinedMemberBizProcess param = new DeleteJoinedMemberBizProcess();
            param.UesrName = ClientInfoContext.Current.UserPrincipal.UserName;
            param.ID = Convert.ToInt32(QueryString_ScheduleId);

            DeleteJoinedMemberBizLogic logic = new DeleteJoinedMemberBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {
            Response.Redirect("Edit.aspx?SID=" + QueryString_ScheduleId + "&Mode=" + ((ZXR.Web.Controls.Button)sender).UserDatas["Mode"]);
        }

        protected void ButtonCancel_Click(object sender, EventArgs e)
        {
            DeleteScheduleBizProcess param = new DeleteScheduleBizProcess();
            param.ID = QueryString_ScheduleId;

            DeleteScheduleBizLogic logic = new DeleteScheduleBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void ButtonRevival_Click(object sender, EventArgs e)
        {
            RevivalScheduleBizProcess param = new RevivalScheduleBizProcess();
            param.ID = QueryString_ScheduleId;

            RevivalScheduleBizLogic logic = new RevivalScheduleBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_OperationResult);
            }
        }

        protected void ButtonReturn_Click(object sender, EventArgs e)
        {
            Response.Redirect("Default.aspx");
        }

 
    }
}
