﻿using System;
using System.Text;
using System.Collections.Generic;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Controls;
using ZXR.DataAccess;
using ZXR.BusinessLogic;

using CAUtility.Logic.Products;
using CAUtility.Logic.UserShoppingInfo;
using CAUtility.Logic.Sales;
using CAUtility;
using CAUtility.Utility;
using CAUtility.Pages;

namespace WebApplication.Contents
{
    public partial class Checkout : NormalMemberPage
    {

        private const string ShoppingCartCookieName = "ShoppingCart";

        private const string OrderInfoCookieName = "OrderInfo";

        protected void Page_Init(object sender, EventArgs e)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Product.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink1);

            InitInterface();

            Page.ClientScript.RegisterStartupScript(this.GetType(), this.UniqueID, "javascript:window.history.forward(1);", true);

            CookieManager customInfoCookie = new CookieManager(OrderInfoCookieName);
            this.LabelArrivalTime.Text = customInfoCookie.GetValue("ArrivalTime");
            this.LabelRemark.Text = customInfoCookie.GetValue("Remarks");

            this.LabelYubin.Text = CaSession.ZipCode;
            this.LabelJyusyo.Text = CaSession.Jyusyo;
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            InitPage();
        }

        private void InitInterface()
        {
            this.LabelTotalDes.Text = MessageManager.GetValue(MessageKey.ShoppingD0006);
            this.ButtonSubmit.Text = MessageManager.GetValue(MessageKey.ShoppingD0014);
        }

        private void InitPage()
        {
            CookieManager shooppingCookie = new CookieManager(ShoppingCartCookieName);

            Dictionary<string, string> cartList = shooppingCookie.GetAllValue();

            this.MenuTableOrderList.RowCount = cartList.Count + 1;
            this.MenuTableOrderList.TurnBackNumber = 4;
            this.MenuTableOrderList.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;

            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0003));
            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0004));
            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0005));
            this.MenuTableOrderList.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0009));

            decimal total = 0.0M;
            foreach (string productid in cartList.Keys)
            {
                GetProductDetailsBizProcess param = new GetProductDetailsBizProcess();
                param.ID = productid;

                GetProductDetailsBizLogic logic = new GetProductDetailsBizLogic();
                GetProductDetailsBizResult result = (GetProductDetailsBizResult)logic.Execute(param);

                Label titleLable = new Label();
                titleLable.Text = result.Name;
                this.MenuTableOrderList.AddControl(titleLable);

                Label priceLable = new Label();
                priceLable.Text = result.Price.ToString();
                this.MenuTableOrderList.AddControl(priceLable);

                Label countLabel = new Label();
                countLabel.Text = cartList[productid];
                this.MenuTableOrderList.AddControl(countLabel);

                Label subTotalLabel = new Label();
                decimal subTotal = result.Price * Int32.Parse(countLabel.Text);
                subTotalLabel.Text = subTotal.ToString();
                this.MenuTableOrderList.AddControl(subTotalLabel);

                total += subTotal;
            }

            this.MenuTableOrderList.Flush();

            this.LabelTotal.Text =  total.ToString();
            CaSession.ShoppingMonetaryAmount = total;
        }

        protected void CustomButtonSubmit_Click(object sender, EventArgs e)
        {
            ZxrTransaction transaction = new ZxrTransaction();

            CookieManager customInfoCookie = new CookieManager(OrderInfoCookieName);

            GetUserDetailsBizProcess userParam = new GetUserDetailsBizProcess();
            userParam.UserID = ClientInfoContext.Current.UserPrincipal.UserName;

            GetUserDetailsBizLogic userLogic = new GetUserDetailsBizLogic();
            GetUserDetailsBizResult userResult = (GetUserDetailsBizResult)userLogic.Execute(userParam);

            StringBuilder mailContents = new StringBuilder();
            mailContents.Append("氏名：" + userResult.Simei);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("フリガナ：" + userResult.Furigana);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("電話番号：" + userResult.HomePhone);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("PCメール：" + userResult.PCMail);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("携帯番号：" + userResult.Mobile);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("携帯メール：" + userResult.MobileMail);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("ユーザーID：" + ClientInfoContext.Current.UserPrincipal.UserName);
            mailContents.Append(System.Environment.NewLine);

            InsertOrdersSalesBizProcess orderParam = new InsertOrdersSalesBizProcess();

            orderParam.Address = CaSession.Jyusyo;
            orderParam.Zipcode = CaSession.ZipCode;
            orderParam.UserID = ClientInfoContext.Current.UserPrincipal.UserName;
            orderParam.ArrivalTime = customInfoCookie.GetValue("ArrivalTime");
            orderParam.PurchaseDate = DateTime.Now;
            orderParam.Remarks = customInfoCookie.GetValue("Remarks");
            orderParam.MonetaryAmount = CaSession.ShoppingMonetaryAmount.ToString();

            mailContents.Append("新しい注文があります");
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("注文受付時間：" + orderParam.PurchaseDate.ToString());
            mailContents.Append(System.Environment.NewLine);

            mailContents.Append("郵便：" + CaSession.ZipCode);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("アドレス：" + CaSession.Jyusyo);
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append("希望到着時間帯：" + orderParam.ArrivalTime);
            mailContents.Append(System.Environment.NewLine);

            CookieManager shooppingCookie = new CookieManager(ShoppingCartCookieName);

            Dictionary<string, string> cartList = shooppingCookie.GetAllValue();
            int index = 1;

            mailContents.Append("注文リスト：");
            mailContents.Append(System.Environment.NewLine);
            mailContents.Append(System.Environment.NewLine);
            foreach (string productid in cartList.Keys)
            {
                int count = Convert.ToInt32(cartList[productid]);

                GetProductDetailsBizProcess param = new GetProductDetailsBizProcess();
                param.ID = productid;

                GetProductDetailsBizLogic logic = new GetProductDetailsBizLogic();
                GetProductDetailsBizResult result = (GetProductDetailsBizResult)logic.Execute(param);

                if (count > result.StockCount)
                {
                    WebMessageBox.Show("商品：" + result.Name + "の在庫数が足りません");
                    return;
                }
                else if (count <= 0)
                {
                    WebMessageBox.Show("商品：" + result.Name + "の注文が正しくありません");
                    return;
                }

                UpdateStockCountBizProcess stockParam = new UpdateStockCountBizProcess();
                stockParam.ID = productid;
                stockParam.StockDecrease = count;

                UpdateStockCountBizLogic stockLogic = new UpdateStockCountBizLogic();
                stockLogic.JoinTransaction(transaction);
                stockLogic.Execute(stockParam);

                InsertOrdersDetailsBizProcessElement detailsParam = new InsertOrdersDetailsBizProcessElement();
                detailsParam.ProductID = productid;
                detailsParam.Amount = count;
                detailsParam.Subtotal = result.Price * count;

                mailContents.Append("注文" + index.ToString() + ":");
                mailContents.Append(System.Environment.NewLine);
                mailContents.Append("商品番号 : " + result.ProductID);
                mailContents.Append(System.Environment.NewLine);
                mailContents.Append("商品名 : " + result.Name);
                mailContents.Append(System.Environment.NewLine);
                mailContents.Append("値段 : " + result.Price);
                mailContents.Append(System.Environment.NewLine);
                mailContents.Append("注文個数 : " + detailsParam.Amount);
                mailContents.Append(System.Environment.NewLine);
                mailContents.Append("--------------------------");
                mailContents.Append(System.Environment.NewLine);

                orderParam.Add(detailsParam);
                index++;
            }

            InsertOrdersBizLogic inserLogic = new InsertOrdersBizLogic();
            inserLogic.JoinTransaction(transaction);
            BizResult orderResult = inserLogic.Execute(orderParam);
            transaction.Commit();

            if (orderResult.Result)
            {
                CookieManager.CookieDiscard(ShoppingCartCookieName);
                CookieManager.CookieDiscard(OrderInfoCookieName);

                MailUtil mail = new MailUtil();
                mail.SendMail(
                    "【注文】" + ClientInfoContext.Current.UserPrincipal.UserName + "さんの注文",
                        mailContents.ToString());

                Response.Redirect("UserOperateResult.aspx?Result=true&MessageId=" + MessageKey.PageD0058);
            }
        }

    }
}
