﻿using System;

using ZXR.Core;
using ZXR.IO;
using CAUtility.Pages;
using CAUtility;
using CAUtility.Logic.Common;

namespace WebApplication.Contents
{
    public partial class ContentsMasterPage : MasterPage
    {

        public string TopPageID { get; set; }

        protected void Page_Init(object sender, EventArgs e)
        {

            this.Page.Title = CaContext.Current.CompanyName;

            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "default.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            Page.Header.Controls.Add(myHtmlLink1);

            System.Web.UI.HtmlControls.HtmlLink myHtmlLink2 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink2.Href = CaSettings.SkinDirectory + "PageMenu.css";
            myHtmlLink2.Attributes.Add("rel", "stylesheet");
            myHtmlLink2.Attributes.Add("type", "text/css");
            Page.Header.Controls.Add(myHtmlLink2);

            System.Web.UI.HtmlControls.HtmlLink myHtmlLink3 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink3.Href = CaSettings.SkinDirectory + "UserLogin.css";
            myHtmlLink3.Attributes.Add("rel", "stylesheet");
            myHtmlLink3.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink3);

            System.Web.UI.HtmlControls.HtmlLink myHtmlLink4 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink4.Href = CaSettings.SkinDirectory + "ContentPage.css";
            myHtmlLink4.Attributes.Add("rel", "stylesheet");
            myHtmlLink4.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink4);

            CAUtility.Menu.PageInfoMenu.Init();

            string culture = SupportCulture.GetCultureFromUrl();
            if (string.IsNullOrEmpty(culture))
                MessageManager.CultureTarget = new System.Globalization.CultureInfo(CaSettings.PageDefaultCulture);
            else
                MessageManager.CultureTarget = new System.Globalization.CultureInfo(culture);

            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {

                this.DisplayLabelCultureMenu.Text = CultureMenuInit();

            }

            if (ClientInfoContext.Current != null
                && ClientInfoContext.Current.UserPrincipal != null
                && ClientInfoContext.Current.UserPrincipal.IsLogined == true
                && ClientInfoContext.Current.UserPrincipal.UserLevel > 7)
            {
                this.PanelAdmin.Visible = true;
                this.CustomHyperLinkEdit.Text = "[Edit]";
                this.CustomHyperLinkEdit.NavigateUrl =
                    "~/Admin/PageInfoEdit/PageInfoAppendEdit.aspx?Action=edit&EditTarget=" + Request.QueryString["PageID"] + "&TargetCulture=" + SupportCulture.GetCultureFromUrl();

                this.CustomHyperLinkAddChild.Text = "[Add Child Page]";
                this.CustomHyperLinkAddChild.NavigateUrl =
                    "~/Admin/PageInfoEdit/PageInfoAppendEdit.aspx?TargetCulture=" + SupportCulture.GetCultureFromUrl() + "&TopPageId=" + Request.QueryString["PageID"];
            }
            else
            {
                this.PanelAdmin.Visible = false;
            }

            this.LabelNavi.Text = CAUtility.Menu.PageInfoMenu.Navigation(
                Convert.ToInt32(System.Web.HttpContext.Current.Request.QueryString["PageID"])
               );

            string culture = SupportCulture.GetCultureFromUrl();
            if (ClientInfoContext.Current.UserPrincipal.IsLogined)
            {
                this.PanelUnlogin.Visible = false;
                this.PanelLogined.Visible = true;
                this.LabelWelcomeMsg.Text = MessageManager.GetValue(MessageKey.UserLoginS0042, ClientInfoContext.Current.UserPrincipal.FriendlyName);

                this.HyperLinkProfile.NavigateUrl = "MemberPage.aspx";
            }
            else
            {
                this.HyperLinkRegist.NavigateUrl = "UserRegist.aspx";
                this.HyperLinkLogin.NavigateUrl = "UserLogin.aspx";
                this.PanelLogined.Visible = false;
                this.PanelUnlogin.Visible = CaSettings.AllowRegist;
            }

            InitPageFooter();
        }

        private void InitInterface()
        {
            this.HyperLinkLogin.Text = MessageManager.GetValue(MessageKey.UserLoginS0003);
            this.HyperLinkRegist.Text = MessageManager.GetValue(MessageKey.UserLoginS0004);
            this.LinkButtonLogout.Text = MessageManager.GetValue(MessageKey.UserLoginS0006);
            this.HyperLinkProfile.Text = MessageManager.GetValue(MessageKey.UserLoginS0051);
        }

        private void InitPageFooter()
        {
            string culture = SupportCulture.GetCultureFromUrl();
            culture = string.IsNullOrEmpty(culture) ? CaSettings.PageDefaultCulture : culture;
            if (CaContext.Current.PageFooter.ContainsKey(culture))
                this.LabelFooter.Text = CaContext.Current.PageFooter[culture];
        }

        protected void LinkButtonLogout_Click(object sender, EventArgs e)
        {
            Session.Abandon();
            Response.Redirect("~/");
        }

        private string CultureMenuInit()
        {
            string result = string.Empty;

            ListSupportCultureBizLogic logic = new ListSupportCultureBizLogic();
            ListSupportCultureBizResult Result = (ListSupportCultureBizResult)logic.Execute(null);

            if (Result.DataList.Count == 1)
            {
                return result;
            }

            result = "<ul>\r\n";
            foreach (ListSupportCultureBizResultElement ele in Result.DataList)
            {
                result += "<li>\r\n";
                if (string.Equals(ele.Culture, CaSettings.PageDefaultCulture))
                    result += "<a href=\"" + CAUtility.Utility.UrlPathUtil.RootPath + "\">";
                else
                    result += "<a href=\"" + CAUtility.Utility.UrlPathUtil.RootPath + ele.Culture + "/\">";

                string imagePath = CAUtility.Utility.UrlPathUtil.RootPath + "App_Themes/Default/Images/" + ele.Culture + ".png";

                if (System.IO.File.Exists(Server.MapPath(imagePath)))
                    result += "<img width=\"17\" src=\"" + imagePath + "\"/>";

                result += SupportCulture.ConvertCodeToText(ele.Culture) + "</a>";
            }
            result += "</ul>\r\n";

            return result;
        }
    }
}