﻿using System;

using ZXR.Core;
using ZXR.Log;
using ZXR.BusinessLogic;
using ZXR.DataAccess;

using CAUtility.Logic.UserShoppingInfo;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Contents
{

    public partial class EditProfile : NormalMemberPage
    {

        private const string TransitionDefinition_OperationResult = "UserOperateResult.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {

            if (ClientInfoContext.Current.UserPrincipal.IsLogined == false )
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0007)) { ErrorType = ErrorType.OperationError };

            if (!IsPostBack)
            {
                InitInterface();

                initPage();
            }
        }

        private void InitInterface()
        {
        }

        private void initPage()
        {
            GetUserDetailsBizProcess param = new GetUserDetailsBizProcess();
            param.UserID = ClientInfoContext.Current.UserPrincipal.UserName;

            GetUserDetailsBizLogic logic = new GetUserDetailsBizLogic();
            GetUserDetailsBizResult result = (GetUserDetailsBizResult)logic.Execute(param);

            this.TextBoxCompany.Text = result.Company;
            this.TextBoxFax.Text = result.Fax;
            this.TextBoxHomePhone.Text = result.HomePhone;
            this.TextBoxJyusyo.Text = result.Address;
            this.TextBoxMobileEmail.Text = result.MobileMail;
            this.TextBoxMobilePhone.Text = result.Mobile;
            this.TextBoxOfficialPosition.Text = result.OfficialPosition;
            this.TextBoxPcEmail.Text = result.PCMail;
            this.TextBoxSecretAnswer.Text = result.SecretAnswer;
            this.TextBoxYubin.Text = result.ZipCode;
            this.TextBoxPcEmail.Text = result.PCMail;
            this.DropDownListSecretQuestion.SelectedValue = result.SecretQuestion.ToString();

            if (string.Equals(result.LoginType, "1"))
            {
                this.RadioButtonRegisterNameJitaku.Checked = true;
            }
            else if (string.Equals(result.LoginType, "2"))
            {
                this.RadioButtonRegisterNameKinnmu.Checked = true;
            }
            else
            {
                this.RadioButtonRegisterNameOther.Checked = true;
                this.TextBoxRegisterNameOther.Text = result.LoginType;
            }
        }

        protected void CustomButtonUpdate_Click(object sender, EventArgs e)
        {
            ZxrTransaction transaction = new ZxrTransaction();

            UpdateUserDetailsBizProcess userDetailsParam = new UpdateUserDetailsBizProcess();
            userDetailsParam.UserID = ClientInfoContext.Current.UserPrincipal.UserName;
            userDetailsParam.Address = this.TextBoxJyusyo.Text;
            userDetailsParam.CompanyName = this.TextBoxCompany.Text;
            userDetailsParam.Fax = this.TextBoxFax.Text;
            userDetailsParam.HomePhone = this.TextBoxHomePhone.Text;
            userDetailsParam.Mobile = this.TextBoxMobilePhone.Text;
            userDetailsParam.MobileMail = this.TextBoxMobileEmail.Text;
            userDetailsParam.OfficialPosition = this.TextBoxOfficialPosition.Text;
            userDetailsParam.PcMail = this.TextBoxPcEmail.Text;
            userDetailsParam.SecretAnswer = this.TextBoxSecretAnswer.Text;
            userDetailsParam.SecretQuestion = Convert.ToInt32(this.DropDownListSecretQuestion.SelectedValue);
            userDetailsParam.ZipCode = this.TextBoxYubin.Text;

            if (this.RadioButtonRegisterNameJitaku.Checked)
            {
                userDetailsParam.LoginType = "1";
            }
            else if (this.RadioButtonRegisterNameKinnmu.Checked)
            {
                userDetailsParam.LoginType = "2";
            }
            else
            {
                userDetailsParam.LoginType = this.TextBoxRegisterNameOther.Text;
            }

            UpdateUserDetailsBizLogic userDetailsLogic = new UpdateUserDetailsBizLogic();
            userDetailsLogic.JoinTransaction(transaction);
            BizResult result = userDetailsLogic.Execute(userDetailsParam);
            transaction.Commit();

            if (result.Result)
            {
                Logger.Info("ユーザー：" + ClientInfoContext.Current.UserPrincipal.UserName + "個人情報を編集した");
                
                Response.Redirect(TransitionDefinition_OperationResult + "?Result=true&MessageId="
                   + MessageKey.UserLoginS0044);
            }
        }
    }
}
