﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;

using CAUtility;
using CAUtility.Pages;

using ZXR.Core;
using ZXR.IO;
using ZXR.BusinessLogic;
using ZXR.Web.Controls;

using CAUtility.Logic.PostThread;

namespace WebApplication.Contents
{
    public partial class ForumThread : PluginFunctionPage
    {

        private const string TransitionDefinition_OperationResult = "Default.aspx";

        private int QueryString_ForumId = 0;

        private int QueryString_ThreadId = 0;

        private int QueryString_PageId = 0;

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ForumId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ForumId = Convert.ToInt32(Request.QueryString["ForumId"]);

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ThreadId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ThreadId = Convert.ToInt32(Request.QueryString["ThreadId"]);

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["PageId"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_PageId = Convert.ToInt32(Request.QueryString["PageId"]);
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Forum.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink1);

            initInterface();
            initQueryString();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            this.HyperLinkPostThread.NavigateUrl = "PushlishThread.aspx?Action=Reply&PageId="+ QueryString_PageId +"&ForumId=" + QueryString_ForumId + "&ParentId=" + QueryString_ThreadId;

            initPage();
        }

        private void initPage()
        {
            OneThreadBizProcess param = new OneThreadBizProcess();
            param.ThreadId = QueryString_ThreadId;

            OneThreadBizLogic logic = new OneThreadBizLogic();
            OneThreadBizResult result = (OneThreadBizResult)logic.Execute(param);

            this.MenuTable.InitTable(MenuTableDisplayType.RowDisplay);
            if (ClientInfoContext.Current.UserPrincipal.UserGroup == CaSettings.AdminPageUserGroup)
                this.MenuTable.RowCount = result.DataList.Count * 2 + 1;
            else
                this.MenuTable.RowCount = result.DataList.Count + 1;

            this.MenuTable.TurnBackNumber = 1;
            this.MenuTable.Width = new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage);
            this.MenuTable.CssClass = "AdminTable";

            string framePath = System.Web.HttpContext.Current.Server.MapPath("~/bin/BuiltinPlugin/Template/OneThread.html");
            string oneThreadForm = FileIO.ReadWholeFile(framePath);

            int index = 1;
            foreach (OneThreadBizResultElement ele in result.DataList)
            {
                if (ClientInfoContext.Current.UserPrincipal.UserGroup == CaSettings.AdminPageUserGroup)
                {
                    Button delButton = new Button();
                    delButton.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
                    delButton.Text = MessageManager.GetValue(MessageKey.AdminD0031);
                    delButton.Click += new EventHandler(delButton_Click);
                    delButton.UserDatas["ID"] = ele.ID.ToString();
                    delButton.UserDatas["IsParent"] = (ele.ParentThreadId == 0).ToString();
                    this.MenuTable.AddControl(delButton);
                }

                Label tagIdLabel = new Label();

                if (index == 1)
                {
                    if (string.Equals(this.ViewState["DisplayType"], "Forum"))
                    {
                        string forumParentFramePath = System.Web.HttpContext.Current.Server.MapPath("~/bin/BuiltinPlugin/Template/ForumParentThread.html");
                        string forumParent = FileIO.ReadWholeFile(forumParentFramePath);

                        tagIdLabel.Text = string.Format(forumParent,
                            (string.IsNullOrEmpty(ele.UserName) ? "[" + MessageManager.GetValue(MessageKey.PageD0053) + "]" : "[" + MessageManager.GetValue(MessageKey.PageD0054) + "]") + ele.UserNickName,
                            ele.PostTitle + "<hr />",
                            ele.PostDatetime,
                            ele.PostContent,
                            MessageManager.GetValue(MessageKey.PageD0048),
                            MessageManager.GetValue(MessageKey.PageD0049),
                            QueryString_PageId,
                            QueryString_ForumId,
                            QueryString_ThreadId,
                            MessageManager.GetValue(MessageKey.PageD0047)
                            );
                    }
                    else
                    {
                        string blogFramePath = System.Web.HttpContext.Current.Server.MapPath("~/bin/BuiltinPlugin/Template/BlogParentThread.html");
                        string blogParent = FileIO.ReadWholeFile(blogFramePath);

                        tagIdLabel.Text = string.Format(blogParent,
                            (string.IsNullOrEmpty(ele.UserName) ? "[" + MessageManager.GetValue(MessageKey.PageD0053) + "]" : "[" + MessageManager.GetValue(MessageKey.PageD0054) + "]") + ele.UserNickName,
                            ele.PostTitle,
                            ele.PostDatetime,
                            ele.PostContent,
                            MessageManager.GetValue(MessageKey.PageD0048),
                            MessageManager.GetValue(MessageKey.PageD0049),
                            QueryString_PageId,
                            QueryString_ForumId,
                            QueryString_ThreadId,
                            MessageManager.GetValue(MessageKey.PageD0047)
                            );
                    }
                }
                else
                {
                    tagIdLabel.Text = string.Format(oneThreadForm,
                           (string.IsNullOrEmpty(ele.UserName) ? "[" + MessageManager.GetValue(MessageKey.PageD0053) + "]" : "[" + MessageManager.GetValue(MessageKey.PageD0054) + "]") + ele.UserNickName,
                           "",
                           ele.PostDatetime,
                           ele.PostContent,
                           MessageManager.GetValue(MessageKey.PageD0048),
                           MessageManager.GetValue(MessageKey.PageD0049));
                }
                this.MenuTable.AddControl(tagIdLabel);

                index++;
            }
            this.MenuTable.Flush();
        }

        protected void delButton_Click(object sender, EventArgs e)
        {
            DeletePostThreadBizProcess param = new DeletePostThreadBizProcess();
            param.ID = (sender as Button).UserDatas["ID"];

            DeletePostThreadBizLogic logic = new DeletePostThreadBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030),
                    Convert.ToBoolean( (sender as Button).UserDatas["IsParent"] ) ? "Page.aspx?PageId=" + QueryString_PageId : System.Web.HttpContext.Current.Request.Url.ToString());
            }
        }

        private void initInterface()
        {
            this.HyperLinkPostThread.Text = MessageManager.GetValue(MessageKey.PageD0047);
        }

        public override bool AuthValidate(List<string> hostPagePluginList)
        {
            foreach (string str in hostPagePluginList)
            {
                Regex regex = new Regex(@"^(Forum\()(\s*" + QueryString_ForumId + @"\s*|\s*" + QueryString_ForumId + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match = regex.Match(str);
                if (match.Success)
                {
                    this.ViewState["DisplayType"] = "Forum";
                    return true;
                }

                Regex regex2 = new Regex(@"^(Blog\()(\s*" + QueryString_ForumId + @"\s*|\s*" + QueryString_ForumId + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match2 = regex2.Match(str);
                if (match2.Success)
                {
                    this.ViewState["DisplayType"] = "Blog";
                    return true;
                }
            }

            return false;
        }
    }
}