﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;

using ZXR.Core;
using ZXR.Web;
using CAUtility.Pages;
using ZXR.BusinessLogic;

using CAUtility.Logic.Page;
using CAUtility;

namespace WebApplication.Contents
{

    public partial class Page : NormalPage
    {

        private const string PageContentsViewName = "{0}PageContents";

        private string currentPageTopPage_ = string.Empty;

        private string QueryString_PageId = string.Empty;

        private int QueryString_PageIndex = 1;

        private string pageContents_ = string.Empty;

        public string PageContents
        {
            get
            {
                object obj = this.ViewState[string.Format(PageContentsViewName, this.ID)];
                return obj == null ? this.pageContents_ : Convert.ToString(obj);
            }
            set
            {
                this.pageContents_ = value;
                this.ViewState[string.Format(PageContentsViewName, this.ID)] = this.pageContents_;
            }
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            initQueryString();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            InitPage();
        }

        private void InitPage()
        {
            GetSinglePageBizProcess param = new GetSinglePageBizProcess();
            param.ID = QueryString_PageId;

            BizLogic logic = new GetSinglePageBizLogic();
            GetSinglePageBizResult pageInfo_ = (GetSinglePageBizResult)logic.Execute(param);

            if (pageInfo_ == null || !string.Equals(pageInfo_.Status, ZXR.DataAccess.DataStatus.Normal.ToString()))
            {
                string culture = SupportCulture.GetCultureFromUrl();
                MessageManager.CultureTarget = new System.Globalization.CultureInfo(culture);

                this.PlaceHolderMainContent.Controls.Add(new System.Web.UI.LiteralControl(MessageManager.GetValue(MessageKey.PageD0035)));

                return;
            }

            currentPageTopPage_ = pageInfo_.TopPageId;

            if (!string.IsNullOrEmpty(pageInfo_.MetaKeyword))
            {
                ZxrHttpMeta.AddMeta("keywords", pageInfo_.MetaKeyword);
            }

            string dividePage = @"\+\+[-]{4,}\+\+";
            string disText = StringUtility.StringDecode(pageInfo_.Contents);

            string[] disPages = Regex.Split(disText, dividePage);

            System.Collections.Generic.List<System.Web.UI.Control> result = new System.Collections.Generic.List<System.Web.UI.Control>();

            if (disPages.Length > 0 && QueryString_PageIndex <= disPages.Length)
            {
                this.PageDivider1.Visible = true;
                this.PageDivider1.ItemCount = disPages.Length;
                this.PageDivider1.DispalyPageCount = 5;

                pagePluginConvertor(disPages[QueryString_PageIndex <= 0 ? 1 : QueryString_PageIndex - 1]);
            }
            else if (disPages.Length > 0 && QueryString_PageIndex > disPages.Length)
            {
                pagePluginConvertor(disPages[0]);
            }
            else
            {
                this.PageDivider1.Visible = false;
                pagePluginConvertor(disText);
            }

            CAUtility.Plugin.ContentConvertor pluginContent = new CAUtility.Plugin.ContentConvertor();
            string pageCulture = string.IsNullOrEmpty(CAUtility.SupportCulture.GetCultureFromUrl()) ? CAUtility.CaSettings.PageDefaultCulture : CAUtility.SupportCulture.GetCultureFromUrl();
            foreach (System.Web.UI.Control control in pluginContent.DynamicSideMenu(CAUtility.CaContext.Current.SideArea[pageCulture]))
                this.PlaceHolderSideMenu.Controls.Add(control);
        }

        private void pagePluginConvertor(string input)
        {
            CAUtility.Plugin.ContentConvertor pluginContent = new CAUtility.Plugin.ContentConvertor();
            List<System.Web.UI.Control> pluginControls = pluginContent.DynamicControl(input);
            if (pluginControls != null)
            {
                foreach (System.Web.UI.Control control in pluginControls)
                {
                    this.PlaceHolderMainContent.Controls.Add(control);
                }
            }
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["PageID"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_PageId = Request.QueryString["PageID"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Page"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_PageIndex = Convert.ToInt32(Request.QueryString["Page"]);
                QueryString_PageIndex = QueryString_PageIndex == 0 ? 1 : QueryString_PageIndex;
            }
        }

    }
}
