﻿using System;
using System.Web;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Controls;

using CAUtility.Logic.Products;
using CAUtility.Logic.ProductKinds;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Contents
{

    public partial class ProductList : NormalPage
    {

        private const string ShoppingCartCookieName = "ShoppingCart";

        private string QueryString_ProductKindID = string.Empty;

        private int QueryString_CurrentPageIndex = 0;

        private string TransitionDefinition_Postback = "ShoppingCart.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Product.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink1);

            initQueryString();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            InitPage();

            ShowProductNode();
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ProductKID"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ProductKindID = Request.QueryString["ProductKID"];

            if (!string.IsNullOrEmpty(Request.QueryString["Page"]))
            {
                if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Page"]) == false)
                    throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
                else
                    QueryString_CurrentPageIndex = Convert.ToInt32(Request.QueryString["Page"]);
            }
            else
            {
                QueryString_CurrentPageIndex = 1;
            }
        }

        private void InitPage()
        {

            GetProductKindsDetailsBizProcess param = new GetProductKindsDetailsBizProcess();
            param.ID = QueryString_ProductKindID;

            GetProductKindsDetailsBizLogic logic = new GetProductKindsDetailsBizLogic();
            GetProductKindsDetailsBizResult result = (GetProductKindsDetailsBizResult)logic.Execute(param);

            if (!string.IsNullOrEmpty(result.MetaKeyword))
            {
                ZxrHttpMeta.AddMeta("keywords", result.MetaKeyword);
            }

            CAUtility.Plugin.ContentConvertor pluginContent = new CAUtility.Plugin.ContentConvertor();
            string pageCulture = string.IsNullOrEmpty(CAUtility.SupportCulture.GetCultureFromUrl()) ? CAUtility.CaSettings.PageDefaultCulture : CAUtility.SupportCulture.GetCultureFromUrl();

            foreach (System.Web.UI.Control control in pluginContent.DynamicSideMenu(CAUtility.CaContext.Current.SideArea[pageCulture]))
                this.PlaceHolderSideMenu.Controls.Add(control);
        }

        private void ShowProductNode()
        {
            DisplayProductListBizProcess param = new DisplayProductListBizProcess();
            param.KindsID = QueryString_ProductKindID;
            param.PageIndex = QueryString_CurrentPageIndex;
            param.OnePageMaxItemsCount = CaSettings.ProductCountInPage;

            DisplayProductListBizLogic logic = new DisplayProductListBizLogic();
            DisplayProductListBizResult result = (DisplayProductListBizResult)logic.Execute(param);

            this.PageDivider2.OnePageMaxItemCount = CaSettings.ProductCountInPage;
            this.PageDivider2.ItemCount = result.TotalProductCount;

            this.MenuTableProductList.InitTable(MenuTableDisplayType.RowDisplay);
            this.MenuTableProductList.TurnBackNumber = CaSettings.ProductColumnCount;
            this.MenuTableProductList.Width = 600;
            this.MenuTableProductList.RowCount = result.DataList.Count / CaSettings.ProductColumnCount + 1;
            this.MenuTableProductList.CssClass = "ProductListTable";
            this.MenuTableProductList.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;

            foreach (DisplayProductListBizResultElement xx in result.DataList)
            {

                HidenInfoPanel productInfoPanel = new HidenInfoPanel();

                ImageCanClick image = new ImageCanClick();
                image.DefaultWidth = 120;
                image.Width = 120;
                image.ImageUrl = xx.ImagePath;
                image.PostBackUrl = "ProductDetail.aspx?ProductID=" + xx.ID + "&PageID=" + QueryString_CurrentPageIndex;
                productInfoPanel.Controls.Add(image);

                Label outlineLabel = new Label();
                outlineLabel.Text = "<br />" + xx.Name;
                productInfoPanel.Controls.Add(outlineLabel);

                if (CaSettings.IsShoppingMode)
                {
                    if (xx.StockCount > 0)
                    {
                        Label priceLabel = new Label();
                        priceLabel.Text = "<br />" + MessageManager.GetValue(MessageKey.ShoppingD0004) + "：" + xx.Price.ToString() + "<br />";
                        productInfoPanel.Controls.Add(priceLabel);

                        Label stockCountLable = new Label();
                        stockCountLable.Text = MessageManager.GetValue(MessageKey.ShoppingD0010) + "：" + xx.StockCount.ToString() + "<br />";
                        productInfoPanel.Controls.Add(stockCountLable);

                        Label buyCountLabel = new Label();
                        buyCountLabel.Text = MessageManager.GetValue(MessageKey.ShoppingD0005) + "：";
                        productInfoPanel.Controls.Add(buyCountLabel);

                        ValidatorTextBox countTextBox = new ValidatorTextBox();

                        countTextBox.ID = "CountTextBox" + xx.ID;
                        countTextBox.Text = "1";
                        countTextBox.Width = new System.Web.UI.WebControls.Unit(20);
                        productInfoPanel.Controls.Add(countTextBox);

                        ValidatorButton buyButton = new ValidatorButton();
                        buyButton.ID = "BusButton" + xx.ID;
                        buyButton.Text = MessageManager.GetValue(MessageKey.ShoppingD0007);
                        buyButton.UserDatas["ProductID"] = xx.ID.ToString();
                        buyButton.Click += new EventHandler(buyButton_Click);
                        productInfoPanel.Controls.Add(buyButton);
                    }
                    else
                    {
                        Label stockCountLable = new Label();
                        stockCountLable.Text = "<br />" + "売り切れ";
                        stockCountLable.ForeColor = System.Drawing.Color.Red;
                        productInfoPanel.Controls.Add(stockCountLable);
                    }
                }
                this.MenuTableProductList.AddControl(productInfoPanel);
            }
            this.MenuTableProductList.Flush();
        }

        void buyButton_Click(object sender, EventArgs e)
        {

            if (ClientInfoContext.Current == null
                || ClientInfoContext.Current.UserPrincipal == null
                || ClientInfoContext.Current.UserPrincipal.IsLogined == false)
            {
                throw new ZxrException("[ProductList.aspx]"){ ErrorType = ErrorType.AccessDenied };
            }

            string productId = ((ValidatorButton)sender).UserDatas["ProductID"];
            ValidatorTextBox textbox = this.MenuTableProductList.FindControl("CountTextBox" + productId) as ValidatorTextBox;

            if (textbox == null)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };

            CookieManager shoppingCookie = new CookieManager(ShoppingCartCookieName);

            string existAmountString = shoppingCookie.GetValue(productId);

            try
            {
                GetProductDetailsBizProcess param = new GetProductDetailsBizProcess();
                param.ID = productId;

                GetProductDetailsBizLogic logic = new GetProductDetailsBizLogic();
                GetProductDetailsBizResult result = (GetProductDetailsBizResult)logic.Execute(param);

                if (System.Convert.ToInt32(textbox.Text) > result.StockCount || System.Convert.ToInt32(textbox.Text) <= 0)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.ShoppingE0002));
                    return;
                }
            }
            catch
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.ShoppingE0003));
                return;
            }

            if (!string.IsNullOrEmpty(existAmountString))
            {
                shoppingCookie.SetValue(productId, (System.Convert.ToInt32(textbox.Text) + System.Convert.ToInt32(existAmountString)).ToString());
            }
            else
            {
                shoppingCookie.SetValue(productId, textbox.Text);
            }

            HttpContext.Current.Response.Redirect(TransitionDefinition_Postback + "?PageId=" + QueryString_CurrentPageIndex);
        }
    }
}
