﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;

using CAUtility;
using CAUtility.Pages;

using ZXR.Core;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.PostThread;

namespace WebApplication.Contents
{
    public partial class PushlishThread : PluginFunctionPage
    {

        private const string TransitionDefinition_AfterReplyUpdate = "ForumThread.aspx";

        private const string TransitionDefinition_AfterInsert = "Page.aspx";

        private int QueryString_ForumId = 0;

        private int QueryString_ParentThreadId = 0;

        private int QueryString_ThreadId = 0;

        private string QueryString_Action = string.Empty;

        private int QueryString_PageId = 0;

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ForumId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ForumId = Convert.ToInt32(Request.QueryString["ForumId"]);

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ParentId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ParentThreadId = Convert.ToInt32(Request.QueryString["ParentId"]);

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ThreadId"], true) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ThreadId = Convert.ToInt32(Request.QueryString["ThreadId"]);

            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["Action"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Action = Request.QueryString["Action"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["PageId"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_PageId = Convert.ToInt32(Request.QueryString["PageId"]);
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Forum.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink1);

            initQueryString();
            initInterface();
        }

        private void initInterface()
        {
            this.LabelUserName.Text = MessageManager.GetValue(MessageKey.PageD0050);
            this.LabelTitle.Text = MessageManager.GetValue(MessageKey.PageD0051);
            this.LabelContent.Text = MessageManager.GetValue(MessageKey.PageD0052);
            this.ButtonCancel.Text = MessageManager.GetValue(MessageKey.PageD0065);
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initPage();
        }

        private void initPage()
        {
            if (string.Equals(QueryString_Action, "Update"))
            {
                this.ButtonInsert.Visible = false;
                this.ButtonUpdate.Visible = true;
                this.TextBoxTitle.Visible = true;

                SingleThreadBizProcess param = new SingleThreadBizProcess();
                param.ID = QueryString_ThreadId;

                SingleThreadBizLogic logic = new SingleThreadBizLogic();
                SingleThreadBizResult result = (SingleThreadBizResult)logic.Execute(param);

                this.TextBoxContent.Text = result.PostContent;
                this.TextBoxTitle.Text = result.PostTitle;

                this.TextBoxUserName.Visible = false;
                this.LabelUserName.Visible = false;
                this.RequiredFieldValidator3.Enabled = false;
                this.RangeStringValidator3.Enabled = false;
            }
            else if (string.Equals(QueryString_Action, "Insert"))
            {
                this.ButtonInsert.Visible = true;
                this.ButtonUpdate.Visible = false;
                this.TextBoxTitle.Visible = true;
                this.TextBoxUserName.Visible = true;
                this.RequiredFieldValidator1.Enabled = true;
                this.RangeStringValidator1.Enabled = true;
            }
            else if (string.Equals(QueryString_Action, "Reply"))
            {
                this.ButtonInsert.Visible = true;
                this.ButtonUpdate.Visible = false;
                this.TextBoxTitle.Visible = false;
                this.LabelTitle.Visible = false;

                this.RequiredFieldValidator1.Enabled = false;
                this.RangeStringValidator1.Enabled = false;
            }
            else
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }

            if (ClientInfoContext.Current.UserPrincipal.IsLogined)
            {
                this.LabelUserName.Visible = false;
                this.TextBoxUserName.Visible = false;
                this.RequiredFieldValidator3.Enabled = false;
                this.RangeStringValidator3.Enabled = false;
            }
            else
            {
                this.LabelUserName.Visible = true;
                this.TextBoxUserName.Visible = true;
                this.RequiredFieldValidator3.Enabled = true;
                this.RangeStringValidator3.Enabled = true;
            }

            this.VerifyCodeTextBox1.Enabled = CaSettings.IsBBsUseVerifyImage;
        }

        protected void ButtonInsert_Click(object sender, EventArgs e)
        {
            foreach (string str in CaSettings.ForbidsNickName)
            {
                Regex regex = new Regex(str, RegexOptions.IgnoreCase);
                Match match = regex.Match(this.TextBoxUserName.Text);
                if (match.Success)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0062, this.TextBoxUserName.Text));
                    return;
                }
            }

            if (string.Equals(QueryString_Action, "Insert") || string.Equals(QueryString_Action, "Reply"))
            {
                InsertPostThreadBizProcess param = new InsertPostThreadBizProcess();
                param.Action = QueryString_Action;
                param.ForumId = QueryString_ForumId;
                param.ParentThreadId = QueryString_ParentThreadId;
                param.PostContent = this.TextBoxContent.Text;
                param.PostDatetime = DateTime.Now;
                param.PostTitle = this.TextBoxTitle.Text;

                if (ClientInfoContext.Current.UserPrincipal.IsLogined)
                {
                    param.UserName = ClientInfoContext.Current.UserPrincipal.UserName;
                    param.UserNickName = ClientInfoContext.Current.UserPrincipal.FriendlyName;
                }
                else
                {
                    param.UserName = string.Empty;
                    param.UserNickName = this.TextBoxUserName.Text;
                }

                InsertPostThreadBizLogic logic = new InsertPostThreadBizLogic();
                BizResult result = logic.Execute(param);

                if (result.Result)
                {
                    if (string.Equals(QueryString_Action, "Insert"))
                        WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_AfterInsert + "?PageId=" + QueryString_PageId);
                    else if (string.Equals(QueryString_Action, "Reply"))
                        WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_AfterReplyUpdate + "?ForumId=" + QueryString_ForumId + "&ThreadId=" + QueryString_ParentThreadId + "&PageId=" + QueryString_PageId);
                    else
                        throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
                }
            }
            else
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {
            if (string.Equals(QueryString_Action, "Update"))
            {
                UpdatePostThreadBizProcess param = new UpdatePostThreadBizProcess();
                param.ID = QueryString_ThreadId;
                param.PostContent = this.TextBoxContent.Text;
                param.PostTitle = this.TextBoxTitle.Text;

                UpdatePostThreadBizLogic logic = new UpdatePostThreadBizLogic();
                BizResult result = logic.Execute(param);

                if (result.Result)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminD0030), TransitionDefinition_AfterReplyUpdate + "?ForumId=" + QueryString_ForumId +"&ThreadId="+ QueryString_ParentThreadId + "&PageId=" + QueryString_PageId);
                }
            }
            else
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }
        }

        public override bool AuthValidate(List<string> hostPagePluginList)
        {
            foreach (string str in hostPagePluginList)
            {
                Regex regex = new Regex(@"^(Forum\()(\s*" + QueryString_ForumId + @"\s*|\s*" + QueryString_ForumId + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match = regex.Match(str);
                if (match.Success)
                    return true;

                Regex regex2 = new Regex(@"^(Blog\()(\s*" + QueryString_ForumId + @"\s*|\s*" + QueryString_ForumId + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match2 = regex2.Match(str);
                if (match2.Success)
                    return true;
            }

            return false;
        }

        protected void ButtonCancel_Click(object sender, EventArgs e)
        {
            Response.Redirect("Page.aspx?PageId=" + QueryString_PageId);
        }
    }
}