﻿using System;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections.Generic;

using ZXR.Core;
using ZXR.Net;
using CAUtility.Pages;
using ZXR.Web.Controls;
using ZXR.BusinessLogic;

using CAUtility.Logic.ReservationItem;
using CAUtility.Logic.ReservationData;
using CAUtility;
using CAUtility.Utility;

namespace WebApplication.Contents
{

    public partial class Reservation : PluginFunctionPage
    {

        private const string SimultaneousNumber = "SimultaneousNumber";

        private const string ItemUnit = "ItemUnit";

        private const string HolidayList = "HolidayList";

        private const string DatetimeLength = "DatetimeLength";

        private string QueryString_ReservationItemID = string.Empty;

        protected void Page_Init(object sender, EventArgs e)
        {
            initQueryString();
            InitInterface();

            InitPage();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            initQueryString();

            CAUtility.Plugin.ContentConvertor pluginContent = new CAUtility.Plugin.ContentConvertor();
            string pageCulture = string.IsNullOrEmpty(CAUtility.SupportCulture.GetCultureFromUrl()) ? CAUtility.CaSettings.PageDefaultCulture : CAUtility.SupportCulture.GetCultureFromUrl();
            foreach (System.Web.UI.Control control in pluginContent.DynamicSideMenu(CAUtility.CaContext.Current.SideArea[pageCulture]))
                this.PlaceHolderSideMenu.Controls.Add(control);

            this.VerifyCodeTextBox1.Enabled = CaSettings.IsReservationUseVerifyImage;
        }

        private void InitInterface()
        {
            this.ButtonReservation.Text = MessageManager.GetValue(MessageKey.PageD0007);
            this.LabelBeginDatatime.Text = MessageManager.GetValue(MessageKey.PageD0005);
            this.LabelEndDatatime.Text = MessageManager.GetValue(MessageKey.PageD0006);
            this.LabelDate.Text = MessageManager.GetValue(MessageKey.PageD0004);
            this.LabelUserName.Text = MessageManager.GetValue(MessageKey.PageD0003);
            this.LabelUserMailDis.Text = MessageManager.GetValue(MessageKey.PageD0019);
            this.LabelUserPhoneDis.Text = MessageManager.GetValue(MessageKey.PageD0020);
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["Rid"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_ReservationItemID = Request.QueryString["Rid"];
        }

        #region 予約時間帯の初期化

        private void InitPage()
        {
            DisplayReservationBizProcess param = new DisplayReservationBizProcess();
            param.ItemId = QueryString_ReservationItemID;

            DisplayReservationBizLogic logic = new DisplayReservationBizLogic();
            DisplayReservationBizResult result = (DisplayReservationBizResult)logic.Execute(param);

            this.ViewState[SimultaneousNumber] = result.SimultaneousNumber;
            this.ViewState[ItemUnit] = result.Unit;
            this.ViewState[HolidayList] = result.HolidayList;
            this.ViewState[DatetimeLength] = result.DatetimeLength;

            this.LabelReservationItemName.Text = result.ItemName;
            this.LabelItemDetail.Text = result.ItemDetails;

            if (result.Unit == -1) //終日
            {
                this.DropDownListDate.DataSource = result.DateList;
                this.DropDownListDate.DataTextField = "Date";
                this.DropDownListDate.DataValueField = "DateValue";
                this.DropDownListDate.DataBind();

                this.LabelDate.Visible = true;
                this.DropDownListDate.Visible = true;

                this.LabelBeginDatatime.Visible = false;
                this.DropDownListBeginTime.Visible = false;

                this.LabelEndDatatime.Visible = false;
                this.DropDownListEndTime.Visible = false;
            }
            else if (result.Unit == -2) //連続日
            {

                this.DropDownListBeginTime.DataSource = result.BeginTimeList;
                this.DropDownListBeginTime.DataTextField = "Start";
                this.DropDownListBeginTime.DataValueField = "StartValue";
                this.DropDownListBeginTime.DataBind();

                this.DropDownListEndTime.DataSource = result.EndTimeList;
                this.DropDownListEndTime.DataTextField = "End";
                this.DropDownListEndTime.DataValueField = "EndValue";
                this.DropDownListEndTime.DataBind();
                    
                this.LabelDate.Visible = false;
                this.DropDownListDate.Visible = false;

                this.LabelBeginDatatime.Visible = true;
                this.DropDownListBeginTime.Visible = true;

                this.LabelEndDatatime.Visible = true;
                this.DropDownListEndTime.Visible = true;
            }
            else if (result.Unit == 0)//任意の時間
            {
                this.DropDownListDate.DataSource = result.DateList;
                this.DropDownListDate.DataTextField = "Date";
                this.DropDownListDate.DataValueField = "DateValue";
                this.DropDownListDate.DataBind();

                this.DropDownListBeginTime.DataSource = result.BeginTimeList;
                this.DropDownListBeginTime.DataTextField = "Start";
                this.DropDownListBeginTime.DataValueField = "StartValue";
                this.DropDownListBeginTime.DataBind();

                this.DropDownListEndTime.DataSource = result.BeginTimeList;
                this.DropDownListEndTime.DataTextField = "Start";
                this.DropDownListEndTime.DataValueField = "StartValue";
                this.DropDownListEndTime.DataBind();

                ReamMoveDropDownList rmd = new ReamMoveDropDownList();
                rmd.RegisterObjectPrepare(this.DropDownListDate, "DateValue",
                    this.DropDownListBeginTime, "Date", false);
                rmd.RegisterObjectPrepare(this.DropDownListDate, "DateValue",
                    this.DropDownListEndTime, "Date", false);
                rmd.RegisterObjectComplete();
                rmd.RegisterEvent(DropDownListDate, DropDownListBeginTime);
                rmd.RegisterEvent(DropDownListDate, DropDownListEndTime);

                this.LabelDate.Visible = true;
                this.DropDownListDate.Visible = true;

                this.LabelEndDatatime.Visible = true;
                this.DropDownListBeginTime.Visible = true;

                this.LabelBeginDatatime.Visible = true;
                this.DropDownListEndTime.Visible = true;
            }
            else if (result.Unit == 1) //時間範囲
            {
                this.DropDownListDate.DataSource = result.DateList;
                this.DropDownListDate.DataTextField = "Date";
                this.DropDownListDate.DataValueField = "DateValue";
                this.DropDownListDate.DataBind();

                this.DropDownListBeginTime.DataSource = result.BeginTimeList;
                this.DropDownListBeginTime.DataTextField = "Start";
                this.DropDownListBeginTime.DataValueField = "StartValue";
                this.DropDownListBeginTime.DataBind();

                ReamMoveDropDownList rmd = new ReamMoveDropDownList();
                rmd.RegisterObjectPrepare(this.DropDownListDate, "DateValue",
                    this.DropDownListBeginTime, "Date", false);
                rmd.RegisterObjectComplete();
                rmd.RegisterEvent(DropDownListDate, DropDownListBeginTime);

                this.LabelEndDatatime.Visible = false;
                this.DropDownListEndTime.Visible = false;
            }
        }
        #endregion

        protected void ButtonUpdate_Click(object sender, EventArgs e)
        {
            InsertReservationBizProcess param = new InsertReservationBizProcess();
            param.ItemID = QueryString_ReservationItemID;
            param.ReservateDatetime = DateTime.Now;

            if (Convert.ToInt32(this.ViewState[ItemUnit]) == 1) //時間範囲
            {
                string reservateDateTime = this.DropDownListDate.SelectedValue + " " + this.DropDownListBeginTime.SelectedValue;
                CheckReservatedBizProcess checkParam = new CheckReservatedBizProcess();
                checkParam.ReservatedDateTime = reservateDateTime;

                CheckReservatedBizLogic checkLogic = new CheckReservatedBizLogic();
                BizResult checkResult = checkLogic.Execute(checkParam);

                if (checkResult.ResultData != null && Convert.ToInt32(checkResult.ResultData) >= Convert.ToInt32(this.ViewState[SimultaneousNumber]))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0055));
                    return;
                }

                param.ReservationBegin = Convert.ToDateTime(reservateDateTime);
                param.ReservationEnd = DateTime.MaxValue;
            }
            else if (Convert.ToInt32(this.ViewState[ItemUnit]) == -1) //終日
            {
                string reservateDateTime = this.DropDownListDate.SelectedValue;
                CheckReservatedBizProcess checkParam = new CheckReservatedBizProcess();
                checkParam.ReservatedDateTime = reservateDateTime;

                CheckReservatedBizLogic checkLogic = new CheckReservatedBizLogic();
                BizResult checkResult = checkLogic.Execute(checkParam);

                if (checkResult.ResultData != null && Convert.ToInt32(checkResult.ResultData) >= Convert.ToInt32(this.ViewState[SimultaneousNumber]))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0055));
                    return;
                }

                param.ReservationBegin = Convert.ToDateTime(reservateDateTime);
                param.ReservationEnd = DateTime.MaxValue;
            }
            else if (Convert.ToInt32(this.ViewState[ItemUnit]) == -2) //連続日
            {
                DateTime reservationBegin = Convert.ToDateTime(this.DropDownListBeginTime.SelectedValue);
                DateTime reservationEnd = Convert.ToDateTime(this.DropDownListEndTime.SelectedValue);

                if (DatetimeUtil.ComparerDate(reservationEnd, reservationBegin) == -1)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0056));
                    return;
                }

                if (((reservationEnd - reservationBegin).Days + 1 ) > Convert.ToInt32(this.ViewState[DatetimeLength]))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0060, this.ViewState[DatetimeLength].ToString()));
                    return;
                }

                List<RangeDateTime> list = GetReservatedList(QueryString_ReservationItemID);

                if (IsReservatedRangeData(
                    list,
                    new RangeDateTime(DateTime.Parse(this.DropDownListBeginTime.SelectedValue), DateTime.Parse(this.DropDownListEndTime.SelectedValue)),
                    Convert.ToInt32(this.ViewState[SimultaneousNumber])))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0055));
                    return;
                }
 

                for (int i = 1; i < (reservationEnd - reservationBegin).Days; i++)
                {
                    if (CycleDatetime.Compare(reservationBegin.AddDays(i),
                            CycleDatetime.Parse(this.ViewState[HolidayList].ToString())))
                    {
                        WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0059, reservationBegin.AddDays(i).ToString("yyyy/MM/dd")));
                        return;
                    }
                }

                param.ReservationBegin = reservationBegin;
                param.ReservationEnd = reservationEnd;
            }
            else if (Convert.ToInt32(this.ViewState[ItemUnit]) == 0) //任意の時間
            {
                if (DatetimeUtil.ComparerTime(DateTime.Parse(this.DropDownListEndTime.SelectedValue), DateTime.Parse(this.DropDownListBeginTime.SelectedValue)) == -1
                    || DatetimeUtil.ComparerTime(DateTime.Parse(this.DropDownListEndTime.SelectedValue), DateTime.Parse(this.DropDownListBeginTime.SelectedValue)) == 0)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0056));
                    return;
                }

                List<RangeDateTime> list = GetReservatedList(QueryString_ReservationItemID);

                if (IsReservatedRangeData(
                    list,
                    new RangeDateTime(DateTime.Parse(this.DropDownListBeginTime.SelectedValue), DateTime.Parse(this.DropDownListEndTime.SelectedValue)),
                    Convert.ToInt32(this.ViewState[SimultaneousNumber])))
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0055));
                    return;
                }
                param.ReservationBegin = Convert.ToDateTime(this.DropDownListDate.SelectedValue + " " + this.DropDownListBeginTime.SelectedValue);
                param.ReservationEnd = Convert.ToDateTime(this.DropDownListDate.SelectedValue + " " + this.DropDownListEndTime.SelectedValue);
            }

            param.UserMail = this.TextBoxMailAddress.Text;
            param.UserName = this.TextBoxUserName.Text;
            param.UserPhone = this.TextBoxPhone.Text;

            InsertReservationBizLogic logic = new InsertReservationBizLogic();
            BizResult result = logic.Execute(param);

            if (result.Result)
            {
                StringBuilder messageContents = new StringBuilder();
                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0012));
                messageContents.Append(":");
                messageContents.Append(result.ResultData.ToString());
                messageContents.Append(Environment.NewLine);

                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0008));
                messageContents.Append(":");
                messageContents.Append(this.LabelReservationItemName.Text);
                messageContents.Append(Environment.NewLine);

                messageContents.Append(this.LabelItemDetail.Text);
                messageContents.Append(Environment.NewLine);
                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0003));
                messageContents.Append(":");
                messageContents.Append(this.TextBoxUserName.Text);
                messageContents.Append(Environment.NewLine);

                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0020));
                messageContents.Append(":");
                messageContents.Append(this.TextBoxPhone.Text);
                messageContents.Append(Environment.NewLine);

                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0019));
                messageContents.Append(":");
                messageContents.Append(this.TextBoxMailAddress.Text);
                messageContents.Append(Environment.NewLine);

                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0004));
                messageContents.Append(":"); messageContents.Append(this.DropDownListDate.SelectedValue);
                messageContents.Append(Environment.NewLine);

                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0005));
                messageContents.Append(":"); messageContents.Append(this.DropDownListBeginTime.SelectedValue);
                messageContents.Append(Environment.NewLine);

                messageContents.Append(MessageManager.GetValue(MessageKey.PageD0006));
                messageContents.Append(":"); messageContents.Append(this.DropDownListEndTime.SelectedValue);
                messageContents.Append(Environment.NewLine);

                MailUtil mail = new MailUtil();
                mail.SendMail(
                     "【予約】" + this.LabelReservationItemName.Text,
                    messageContents.ToString()
                     );

                Response.Redirect("UserOperateResult.aspx?Result=true&MessageId=" + MessageKey.PageD0057);
            }
        }

        private bool IsReservatedRangeData(List<RangeDateTime> list, RangeDateTime datetime, int simultaneousNumber)
        {
            int count = list.FindAll(delegate(RangeDateTime rd)
            {
                return rd.HasRangeDateIntersection(datetime);
            }
            ).Count;

            if (count >= simultaneousNumber)
                return true;
            else
                return false;
        }

        private bool IsReservatedTime(List<RangeDateTime> list, RangeDateTime datetime, int simultaneousNumber)
        {
            int count = list.FindAll(delegate(RangeDateTime rd)
            {
                return rd.HasRangeTimeIntersection(datetime);
            }
            ).Count;

            if (count >= simultaneousNumber)
                return true;
            else
                return false;
        }

        private List<RangeDateTime> GetReservatedList(string itemId)
        {
            List <RangeDateTime> result = new List<RangeDateTime>();

            ListDataBizProcess getParam = new ListDataBizProcess();
            getParam.ItemId = itemId;
            getParam.IsFromNow = true;

            ListDataBizLogic logic = new ListDataBizLogic();
            ListDataBizResult fetchResult = (ListDataBizResult)logic.Execute(getParam);

            foreach (ListDataBizResultElement ele in fetchResult.DataList)
            {
                result.Add(new RangeDateTime(ele.ReservationBegin, ele.ReservationEnd));
            }

            return result;
        }

        public override bool AuthValidate(List<string> hostPagePluginList)
        {
            foreach (string str in hostPagePluginList)
            {
                Regex regex = new Regex(@"^(Reservation\()(\s*" + QueryString_ReservationItemID + @"\s*)(\))$");
                Match match = regex.Match(str);
                if (match.Success)
                {
                    return true;
                }
            }

            return false;
        }
    }
}
