﻿using System;
using System.Collections.Generic;

using ZXR.Core;
using ZXR.Web;
using ZXR.Web.Controls;

using CAUtility.Logic.Products;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Contents
{

    public partial class ShoppingCart : NormalMemberPage
    {

        private const string ShoppingCartCookieName = "ShoppingCart";

        private string TransitionDefinition_Postback = "ShoppingCart.aspx";

        private string TransitionDefinition_OperationResult = "CustomInfo.aspx";

        protected void Page_Init(object sender, EventArgs e)
        {
            System.Web.UI.HtmlControls.HtmlLink myHtmlLink1 = new System.Web.UI.HtmlControls.HtmlLink();
            myHtmlLink1.Href = CaSettings.SkinDirectory + "Product.css";
            myHtmlLink1.Attributes.Add("rel", "stylesheet");
            myHtmlLink1.Attributes.Add("type", "text/css");
            this.Page.Header.Controls.Add(myHtmlLink1);

            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (Request.Browser.Cookies == false)
            {
                this.LabelNotify.Text = MessageManager.GetValue(MessageKey.PageE0001);
                return;
            }
            else
            {
                this.LabelNotify.Visible = false;
            }

            InitPage();
        }

        private void InitInterface()
        {

            this.ZxrButtonCheckOut.Text = MessageManager.GetValue(MessageKey.ShoppingD0001);
        }

        private void InitPage()
        {
            CookieManager shooppingCookie = new CookieManager(ShoppingCartCookieName);

            Dictionary < string , string > cartList = shooppingCookie.GetAllValue();

            this.MenuTableShoppingTable.RowCount = cartList.Count + 1;
            this.MenuTableShoppingTable.TurnBackNumber = 5;
            this.MenuTableShoppingTable.CssClass = "DataTable";
            this.MenuTableShoppingTable.TextHorizontalAlign = System.Web.UI.WebControls.HorizontalAlign.Left;

            this.MenuTableShoppingTable.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0003));
            this.MenuTableShoppingTable.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0004));
            this.MenuTableShoppingTable.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0005));
            this.MenuTableShoppingTable.AddContex(MessageManager.GetValue(MessageKey.ShoppingD0009));
            this.MenuTableShoppingTable.AddContex(MessageManager.GetValue(MessageKey.PageD0040));

            decimal total = 0.0M;
            foreach (string productid in cartList.Keys )
            {
                GetProductDetailsBizProcess param = new GetProductDetailsBizProcess();
                param.ID = productid;

                GetProductDetailsBizLogic logic = new GetProductDetailsBizLogic();
                GetProductDetailsBizResult result = (GetProductDetailsBizResult)logic.Execute(param);

                Label titleLable = new Label();
                titleLable.Text = result.Name;
                this.MenuTableShoppingTable.AddControl(titleLable);

                Label priceLable = new Label();
                priceLable.Text = result.Price.ToString ();
                this.MenuTableShoppingTable.AddControl(priceLable);

                ValidatorTextBox countTextBox = new ValidatorTextBox();
                countTextBox.UserDatas["ProductID"] = productid;
                countTextBox.ValidateMode = ZXR.UI.ControlValidateMode.Figure;
                countTextBox.AutoPostBack = true;
                countTextBox.Text = cartList[productid];
                countTextBox.Width = new System.Web.UI.WebControls.Unit(20);
                countTextBox.TextChanged += new EventHandler(countTextBox_TextChanged);
                this.MenuTableShoppingTable.AddControl(countTextBox);

                Label subTotalLabel = new Label();

                decimal subTotal = 0;
                int count = 0;
                if (Int32.TryParse(countTextBox.Text, out count))
                    subTotal = result.Price * count;
                else
                    subTotal = result.Price * 1;

                subTotalLabel.Text = subTotal.ToString();
                this.MenuTableShoppingTable.AddControl(subTotalLabel);

                Button deleteButton = new Button();
                deleteButton.UserDatas["ProductID"] = productid;
                deleteButton.Text = MessageManager.GetValue(MessageKey.ShoppingD0013);
                deleteButton.Click += new EventHandler(deleteButton_Click);
                this.MenuTableShoppingTable.AddControl(deleteButton);

                total += subTotal;
            }

            this.MenuTableShoppingTable.Flush();

            this.LabelTotal.Text = MessageManager.GetValue(MessageKey.ShoppingD0006) + " : " + total.ToString();
            CaSession.ShoppingMonetaryAmount = total;
        }

        void countTextBox_TextChanged(object sender, EventArgs e)
        {
            CookieManager shooppingCookie = new CookieManager(ShoppingCartCookieName);

            string textValue =((ValidatorTextBox)sender).Text;

            if (ZXR.Core.Validate.ValidateInteger(textValue))
            {
                if (Convert.ToInt32(textValue) <= 0)
                    shooppingCookie.SetValue(((ValidatorTextBox)sender).UserDatas["ProductID"], "1");
                else
                    shooppingCookie.SetValue(((ValidatorTextBox)sender).UserDatas["ProductID"], textValue);
            }
            else
            {
                shooppingCookie.SetValue(((ValidatorTextBox)sender).UserDatas["ProductID"], "1");
            }

            Response.Redirect(TransitionDefinition_Postback);
        }

        void deleteButton_Click(object sender, EventArgs e)
        {
            CookieManager shooppingCookie = new CookieManager(ShoppingCartCookieName);
            shooppingCookie.RemoveValue(((Button)sender).UserDatas["ProductID"]);

            Response.Redirect(TransitionDefinition_Postback);
        }

        protected void ButtonCheckout_Click(object sender, EventArgs e)
        {
            Response.Redirect(TransitionDefinition_OperationResult);
        }
    }
}
