﻿using System;

using ZXR.Core;
using ZXR.Web;
using ZXR.Log;
using ZXR.Security;
using ZXR.Web.Controls;

using CAUtility.Logic.UserInfo;
using CAUtility.Pages;
using CAUtility;

namespace WebApplication.Contents
{
    public partial class UserLogin : NormalPage
    {

        private const string UserInfoCookieName = "UserInfo";

        private bool enableRegistButton_ = true;

        public string ChangePasswordUrl { get; set; }

        public bool EnableRegistButton
        {
            get { return enableRegistButton_; }
            set { enableRegistButton_ = value; }
        }

        public string UserName { get { return this.TextBoxUsername.Text; } }

        protected void Page_Init(object sender, EventArgs e)
        {
            if (!DesignMode)
            {
                InitInterface();
            }
        }

        protected void Page_Load(object sender, EventArgs e)
        {

            if (string.IsNullOrEmpty(this.ChangePasswordUrl))
                this.ChangePasswordUrl = "ChangePassword.aspx";

            this.HyperLinkRegist.NavigateUrl = "UserRegist.aspx";
            this.HyperLinkRegist.Visible = this.EnableRegistButton;

            if (ClientInfoContext.Current.UserPrincipal.IsLogined)
            {
                this.Panel1.Visible = false;
                this.PanelStatus.Visible = true;
                this.HyperLinkForgetPassword.Visible = false;
            }
            else
            {
                this.Panel1.Visible = true;
                this.PanelStatus.Visible = false;
                this.HyperLinkForgetPassword.Visible = true;
            }
        }

        private void InitInterface()
        {
            string culture = SupportCulture.GetCultureFromUrl();
            if (string.IsNullOrEmpty(culture))
                culture = CaSettings.PageDefaultCulture;

            MessageManager.CultureTarget = new System.Globalization.CultureInfo(culture);

            this.ButtonLogin.Text = MessageManager.GetValue(MessageKey.UserLoginS0003);
            this.LabelUserName.Text = MessageManager.GetValue(MessageKey.UserLoginS0001);
            this.LabelPassword.Text = MessageManager.GetValue(MessageKey.UserLoginS0002);
            this.LabelTitle.Text = MessageManager.GetValue(MessageKey.UserLoginS0005);
            this.CustomLinkButtonLogout.Text = MessageManager.GetValue(MessageKey.UserLoginS0006);
            this.HyperLinkForgetPassword.Text = MessageManager.GetValue(MessageKey.UserLoginS0035);

            this.HyperLinkForgetPassword.NavigateUrl = "ReturnPassword.aspx";
            this.HyperLinkProfile.NavigateUrl = "EditProfile.aspx";
            this.HyperLinkChangePassword.NavigateUrl = "ChangePassword.aspx";
        }

        protected void ButtonLogin_Click(object sender, EventArgs e)
        {
            LoginValidator lv = new LoginValidator();

            if (lv.CanLogin)
            {
                ValidationUserBizProcess param = new ValidationUserBizProcess();
                param.UserName = this.TextBoxUsername.Text;
                param.Password = Md5Cryptogram.Md5Hash(this.TextBoxPassword.Text);

                ValidationUserBizLogic logic = new ValidationUserBizLogic();
                ValidationUserBizResult result = (ValidationUserBizResult)logic.Execute(param);

                if (result.Result == true)
                {
                    lv.LoginSuccess();

                    CookieManager shooppingCookie = new CookieManager(UserInfoCookieName);
                    shooppingCookie.SetValue("UserName", this.TextBoxUsername.Text);
                    shooppingCookie.SetValue("UserToken", result.UserToken);
                    shooppingCookie.SetValue("FriendlyName", result.FriendlyName);

                    ClientInfoContext.Current.UserPrincipal.IsLogined = true;
                    ClientInfoContext.Current.UserPrincipal.UserGroup = result.UserGroup;
                    ClientInfoContext.Current.UserPrincipal.UserToken = result.UserToken;
                    ClientInfoContext.Current.UserPrincipal.UserName = this.TextBoxUsername.Text;
                    ClientInfoContext.Current.UserPrincipal.FriendlyName = result.FriendlyName;

                    Logger.Info(MessageManager.GetValue(MessageKey.UserLoginS0033, this.TextBoxUsername.Text));
                    this.ButtonLogin.Visible = false;

                    if (CaSettings.UserPasswordExpires > 0 && result.LastChangePasswordDate + TimeSpan.FromDays(CaSettings.UserPasswordExpires) < DateTime.Now)
                    {
                        WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0031), this.ChangePasswordUrl);
                    }
                    else
                    {
                        if (!string.IsNullOrEmpty(CaSession.CannotAccessUrlForNeedLogin))
                            Response.Redirect(CaSession.CannotAccessUrlForNeedLogin);
                        else
                            Response.Redirect("~/MemberPage.aspx");
                    }
                }
                else
                {
                    Logger.Info(MessageManager.GetValue(MessageKey.UserLoginS0034, this.TextBoxUsername.Text));
                    lv.LoginFailed();
                    this.ButtonLogin.Visible = true;
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.AdminE0010));
                }
            }
            else
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0032));
            }
        }

        protected void CustomLinkButtonLogout_Click(object sender, EventArgs e)
        {
            Session.Abandon();
            Response.Redirect("~/");
        }
    }
}
