﻿using System;
using System.Text.RegularExpressions;

using ZXR.Core;
using ZXR.Security;
using ZXR.BusinessLogic;
using ZXR.DataAccess;
using ZXR.Web.Controls; 

using CAUtility.Logic.UserInfo;
using CAUtility.Logic.UserShoppingInfo;
using CAUtility;
using CAUtility.Pages;

namespace WebApplication.Contents
{

    public partial class UserRegist : NormalPage
    {

        private const string TransitionDefinition_OperationResult = "UserOperateResult.aspx";

        protected void Page_Load(object sender, EventArgs e)
        {
            this.VerifyCodeTextBox1.Enabled = CaSettings.IsUserUseVerifyImage;
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            if (CaSettings.AllowRegist == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0019)) { ErrorType = ErrorType.OperationError };

            for (int i = 1920; i <= DateTime.Now.Year; i++)
            {
                this.DropDownListYear.AddItem(i.ToString(), i.ToString());
            }

            for (int i = 1; i <= 12; i++)
            {
                this.DropDownListMonth.AddItem(i.ToString(), i.ToString());
            }

            for (int i = 1; i <= 31; i++)
            {
                this.DropDownListDay.AddItem(i.ToString(), i.ToString());
            }
        }

        protected void ButtonConfirm_Click(object sender, EventArgs e)
        {
            foreach (string str in CaSettings.ForbidsNickName)
            {
                Regex regex = new Regex(str, RegexOptions.IgnoreCase);
                Match match = regex.Match(this.TextBoxUserid.Text);
                if (match.Success)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0058));
                    return;
                }
            }

            foreach (string str in CaSettings.ForbidsNickName)
            {
                Regex regex = new Regex(str, RegexOptions.IgnoreCase);
                Match match = regex.Match(this.TextBoxNickName.Text);
                if (match.Success)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.PageD0062, this.TextBoxNickName.Text));
                    return;
                }
            }

            string birthday = string.Empty;
            try
            {
                birthday = this.DropDownListYear.SelectedValue + "/" + this.DropDownListMonth.SelectedValue + "/" + this.DropDownListDay.SelectedValue;
                DateTime.Parse(birthday);
            }
            catch
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.CommonE0001));
                return;
            }

            UserExistCheckBizProcess userExistParam = new UserExistCheckBizProcess();
            userExistParam.UserID = this.TextBoxUserid.Text;

            UserExistCheckBizLogic userExistLogic = new UserExistCheckBizLogic();
            BizResult checkResult = userExistLogic.Execute(userExistParam);
            if (checkResult.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0022));
            }
            else
            {
                ZxrTransaction transaction = new ZxrTransaction();

                InsertUserBizProcess userBaseInfoParam = new InsertUserBizProcess();
                userBaseInfoParam.Password = Md5Cryptogram.Md5Hash(this.TextBoxPassword.Text);
                userBaseInfoParam.UserName = this.TextBoxUserid.Text;
                userBaseInfoParam.FriendlyName = this.TextBoxNickName.Text;
                userBaseInfoParam.UserGroup = CaSettings.NewRegistUserGroup;

                InsertUserBizLogic inserUserbaseLogic = new InsertUserBizLogic();
                inserUserbaseLogic.JoinTransaction(transaction);
                inserUserbaseLogic.Execute(userBaseInfoParam);

                UpdateUserDetailsBizProcess userDetailParam = new UpdateUserDetailsBizProcess();
                userDetailParam.Address = this.DropDownListTodofu.SelectedValue + this.TextBoxKunsiku.Text + this.TextBoxJyusyo.Text;
                userDetailParam.Birthday = birthday;
                userDetailParam.CompanyName = this.TextBoxCompany.Text;
                userDetailParam.Fax = this.TextBoxFax.Text;

                if (!string.IsNullOrEmpty(this.TextBoxFuriganaSei.Text) && !string.IsNullOrEmpty(this.TextBoxFuriganaMei.Text))
                    userDetailParam.Furigana = this.TextBoxFuriganaSei.Text + " " + this.TextBoxFuriganaMei.Text;

                userDetailParam.HomePhone = this.TextBoxHomePhone.Text;
                userDetailParam.MobileMail = this.TextBoxMobileEmail.Text;
                userDetailParam.OfficialPosition = this.TextBoxOfficialPosition.Text;
                userDetailParam.Mobile = this.TextBoxMobilePhone.Text;
                userDetailParam.PcMail = this.TextBoxPcEmail.Text;

                if (this.RadioButtonRegisterNameJitaku.Checked)
                {
                    userDetailParam.LoginType = "1";
                }
                else if (this.RadioButtonRegisterNameKinnmu.Checked)
                {
                    userDetailParam.LoginType = "2";
                }
                else
                {
                    userDetailParam.LoginType = this.TextBoxRegisterNameOther.Text;
                }

                userDetailParam.SecretAnswer = this.TextBoxSecretAnswer.Text;
                userDetailParam.SecretQuestion = Convert.ToInt32(this.DropDownListSecretQuestion.SelectedValue);

                if (!string.IsNullOrEmpty(this.TextBoxSimeiSei.Text) && !string.IsNullOrEmpty(this.TextBoxSimeiMei.Text))
                    userDetailParam.Simei = this.TextBoxSimeiSei.Text + " " + this.TextBoxSimeiMei.Text;

                userDetailParam.ZipCode = this.TextBoxYubin.Text;
                userDetailParam.UserID = this.TextBoxUserid.Text;

                if (this.RadioButtonSexMan.Checked)
                    userDetailParam.Sex = 1;
                else
                    userDetailParam.Sex = 2;

                UpdateUserDetailsBizLogic updateUserLogic = new UpdateUserDetailsBizLogic();
                updateUserLogic.JoinTransaction(transaction);
                BizResult result = updateUserLogic.Execute(userDetailParam);
                transaction.Commit();

                if (result.Result)
                {
                    Response.Redirect(TransitionDefinition_OperationResult + "?Result=true&MessageId="
                        + MessageKey.UserLoginS0050);
                }
            }
        }

        protected void ButtonCheckUserExists_Click(object sender, EventArgs e)
        {
            foreach (string str in CaSettings.ForbidsNickName)
            {
                Regex regex = new Regex(str, RegexOptions.IgnoreCase);
                Match match = regex.Match(this.TextBoxUserid.Text);
                if (match.Success)
                {
                    WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0058));
                    return;
                }
            }

            UserExistCheckBizProcess userExistParam = new UserExistCheckBizProcess();
            userExistParam.UserID = this.TextBoxUserid.Text;

            UserExistCheckBizLogic userExistLogic = new UserExistCheckBizLogic();
            BizResult checkResult = userExistLogic.Execute(userExistParam);
            if (checkResult.Result)
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0048));
            }
            else
            {
                WebMessageBox.Show(MessageManager.GetValue(MessageKey.UserLoginS0049));
            }
        }

    }
}
