﻿using System;
using System.Text.RegularExpressions;
using System.Collections.Generic;
using System.Web;

using ZXR.Core;
using ZXR.BusinessLogic;

using CAUtility;
using CAUtility.Logic.NewsLetter.News;
using CAUtility.Logic.PostThread;
using CAUtility.Logic.BBS;
using CAUtility.Logic.Page;

namespace WebApplication
{
    public partial class Rss2_0 : System.Web.UI.Page
    {

        private string QueryString_Target;

        private int QueryString_ID;

        private string QueryString_Culture;
        private string QueryString_PageId;

        protected void Page_Init(object sender, EventArgs e)
        {
            initQueryString();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            if (string.Equals(QueryString_Target, "QuickPost", StringComparison.InvariantCultureIgnoreCase))
            {
                writeQuickPostRss();
            }
            else if (string.Equals(QueryString_Target, "Forum", StringComparison.InvariantCultureIgnoreCase))
            {
                writeForumRss();
            }
        }

        private void writeQuickPostRss()
        {
            bool verifyResult = false;
            foreach (string str in getPluginAtPage())
            {
                Regex regex = new Regex(@"^(NewsLetter\()(\s*" + QueryString_ID + @"\s*|\s*" + QueryString_ID + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match = regex.Match(str);
                if (match.Success)
                {
                    verifyResult = true;
                    break;
                }

                Regex regex2 = new Regex(@"^(Document\()(\s*" + QueryString_ID + @"\s*|\s*" + QueryString_ID + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match2 = regex2.Match(str);
                if (match2.Success)
                {
                    verifyResult = true;
                    break;
                }
            }

            if (verifyResult == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };

            ListNewsForDisplayBizProcess param = new ListNewsForDisplayBizProcess();
            param.TagID = Convert.ToInt32(QueryString_ID);

            ListNewsForDisplayBizLogic logic = new ListNewsForDisplayBizLogic();
            ListNewsForDisplayBizResult result = (ListNewsForDisplayBizResult)logic.Execute(param);

            string path = string.Empty;
            if (CaSettings.PageDefaultCulture.Equals(QueryString_Culture))
                path = "";
            else
                path = QueryString_Culture + "/";

            string strRSS = "";
            strRSS = strRSS + "<?xml version=\"1.0\"?> " + System.Environment.NewLine;
            strRSS = strRSS + "<rss xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"" + System.Environment.NewLine;
            strRSS = strRSS + "xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\"   " + System.Environment.NewLine;
            strRSS = strRSS + "xmlns:slash=\"http://purl.org/rss/1.0/modules/slash/\" version=\"2.0\">" + System.Environment.NewLine;
            strRSS = strRSS + "<channel>" + System.Environment.NewLine;
            strRSS = strRSS + "<title>" + result.TagName + "</title> " + System.Environment.NewLine;
            strRSS = strRSS + "<link>" + path + "NewsTag.aspx?NewsTagID=" + QueryString_ID + "&#38;PageId=" + QueryString_PageId + "</link>" + System.Environment.NewLine;
            strRSS = strRSS + "<description>コンテンツ</description>" + System.Environment.NewLine;
            strRSS = strRSS + "<language>" + QueryString_Culture + "</language>" + System.Environment.NewLine;
            strRSS = strRSS + "<generator>www.soffic.com</generator>  " + System.Environment.NewLine;
            strRSS = strRSS + "<copyright>www.soffic.com</copyright> " + System.Environment.NewLine;

            foreach (ListNewsForDisplayBizResultElement ele in result.DataList)
            {
                strRSS = strRSS + "<item>" + System.Environment.NewLine;
                strRSS = strRSS + "<title>" + ele.NewsTitle + "</title> " + System.Environment.NewLine;
                strRSS = strRSS + "<link>" + path + "News.aspx?NewsID=" + ele.NewsID + "&#38;NewsTagID=" + QueryString_ID + "&#38;PageId=" + QueryString_PageId + "</link> " + System.Environment.NewLine;
                strRSS = strRSS + "<author /> " + System.Environment.NewLine;
                strRSS = strRSS + "<guid>" + ele.NewsID + "</guid>   " + System.Environment.NewLine;
                strRSS = strRSS + "<pubDate>" + Convert.ToDateTime(ele.RegDatetime).ToString("yyyy-MM-dd HH:mm") + "</pubDate> " + System.Environment.NewLine;
                strRSS = strRSS + "<slash:comments>0</slash:comments>    " + System.Environment.NewLine;
                strRSS = strRSS + "<description>" + ele.NewsContent + "</description>" + System.Environment.NewLine;
                strRSS = strRSS + "</item>" + System.Environment.NewLine;
            }
            strRSS = strRSS + "</channel>" + System.Environment.NewLine;
            strRSS = strRSS + "</rss>" + System.Environment.NewLine;

            Response.ClearContent();
            Response.ContentType = "text/xml";
            Response.Write(strRSS);
            Response.End();
        }

        private void writeForumRss()
        {
            bool verifyResult = false;
            foreach (string str in getPluginAtPage())
            {
                Regex regex = new Regex(@"^(Forum\()(\s*" + QueryString_ID + @"\s*|\s*" + QueryString_ID + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match = regex.Match(str);
                if (match.Success)
                {
                    verifyResult = true;
                    break;
                }

                Regex regex2 = new Regex(@"^(Blog\()(\s*" + QueryString_ID + @"\s*|\s*" + QueryString_ID + @"\s*[,]\s*[0-9]{1,}\s*)(\))$");
                Match match2 = regex2.Match(str);
                if (match2.Success)
                {
                    verifyResult = true;
                    break;
                }
            }

            if (verifyResult == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };

            SingleForunInfoBizProcess forumParam = new SingleForunInfoBizProcess();
            forumParam.ID = Convert.ToInt32(QueryString_ID);

            SingleForunInfoBizLogic forumLogic = new SingleForunInfoBizLogic();
            SingleForunInfoBizResult forumResult = (SingleForunInfoBizResult)forumLogic.Execute(forumParam);

            ListPostThreadBizProcess param = new ListPostThreadBizProcess();
            param.ForumId = Convert.ToInt32(QueryString_ID);
            param.PageIndex = 0;
            param.OnePageMaxItemsCount = 20;

            ListPostThreadBizLogic logic = new ListPostThreadBizLogic();
            ListPostThreadBizResult result = (ListPostThreadBizResult)logic.Execute(param);

            string path = string.Empty;
            if (CaSettings.PageDefaultCulture.Equals(QueryString_Culture))
                path = "";
            else
                path = QueryString_Culture + "/";

            string strRSS = "";
            strRSS = strRSS + "<?xml version=\"1.0\"?> " + System.Environment.NewLine;
            strRSS = strRSS + "<rss xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"" + System.Environment.NewLine;
            strRSS = strRSS + "xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\"   " + System.Environment.NewLine;
            strRSS = strRSS + "xmlns:slash=\"http://purl.org/rss/1.0/modules/slash/\" version=\"2.0\">" + System.Environment.NewLine;
            strRSS = strRSS + "<channel>" + System.Environment.NewLine;
            strRSS = strRSS + "<title>" + forumResult.ForumName + "</title> " + System.Environment.NewLine;
            strRSS = strRSS + "<link>" + path + "Page.aspx?PageId=" + QueryString_PageId + "</link>" + System.Environment.NewLine;
            strRSS = strRSS + "<description>コンテンツ</description>" + System.Environment.NewLine;
            strRSS = strRSS + "<language>" + QueryString_Culture + "</language>" + System.Environment.NewLine;
            strRSS = strRSS + "<generator>www.soffic.com</generator>  " + System.Environment.NewLine;
            strRSS = strRSS + "<copyright>www.soffic.com</copyright> " + System.Environment.NewLine;

            foreach (ListPostThreadBizResultElement ele in result.DataList)
            {
                strRSS = strRSS + "<item>" + System.Environment.NewLine;
                strRSS = strRSS + "<title>" + ele.PostTitle + "</title> " + System.Environment.NewLine;
                strRSS = strRSS + "<link>" + path + "ForumThread.aspx?ThreadId=" + ele.ID + "&#38;ForumId=" + QueryString_ID + "&#38;PageId=" + QueryString_PageId + "</link> " + System.Environment.NewLine;
                strRSS = strRSS + "<author /> " + System.Environment.NewLine;
                strRSS = strRSS + "<guid>" + ele.ID + "</guid>   " + System.Environment.NewLine;
                strRSS = strRSS + "<pubDate>" + Convert.ToDateTime(ele.PostDatetime).ToString("yyyy-MM-dd HH:mm") + "</pubDate> " + System.Environment.NewLine;
                strRSS = strRSS + "<slash:comments>0</slash:comments>    " + System.Environment.NewLine;
                strRSS = strRSS + "<description>" + ele.PostContent + "</description>" + System.Environment.NewLine;
                strRSS = strRSS + "</item>" + System.Environment.NewLine;
            }
            strRSS = strRSS + "</channel>" + System.Environment.NewLine;
            strRSS = strRSS + "</rss>" + System.Environment.NewLine;

            Response.ClearContent();
            Response.ContentType = "text/xml";
            Response.Write(strRSS);
            Response.End();
        }

        private List<string> getPluginAtPage()
        {
            GetSinglePageBizProcess param = new GetSinglePageBizProcess();
            param.ID = QueryString_PageId;

            BizLogic logic = new GetSinglePageBizLogic();
            GetSinglePageBizResult pageInfo_ = (GetSinglePageBizResult)logic.Execute(param);

            if (pageInfo_ == null)
            {
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            }

            string disText = StringUtility.StringDecode(pageInfo_.Contents);
            CAUtility.Plugin.ContentConvertor cc = new CAUtility.Plugin.ContentConvertor();

            List<string> hostPagePluginList = new List<string>();
            int index = 0;
            foreach (string plugin in cc.GetTargets(disText))
            {
                if (index % 2 != 0)
                    hostPagePluginList.Add(plugin);

                index++;
            }

            return hostPagePluginList;
        }

        private void initQueryString()
        {
            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["Target"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Target = Request.QueryString["Target"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["ID"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
            {
                QueryString_ID = Convert.ToInt32(Request.QueryString["ID"]);
                QueryString_ID = QueryString_ID == 0 ? 1 : QueryString_ID;
            }

            if (ZXR.Core.Validate.ValidataRequired(Request.QueryString["Culture"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_Culture = Request.QueryString["Culture"];

            if (ZXR.Core.Validate.ValidateInteger(Request.QueryString["PageID"]) == false)
                throw new ZxrException(MessageManager.GetValue(MessageKey.AdminE0002)) { ErrorType = ErrorType.IntrusionAttempt };
            else
                QueryString_PageId = Request.QueryString["PageID"];
        }
    }
}