﻿using System;

using ZXR.Core;
using ZXR.Web.Controls;

using CAUtility;

namespace WebApplication.WebParts
{
    public partial class FileGridView : UserControl
    {

        public delegate void OperationButtonHandler(object sender, EventArgs e);

        public delegate void OperationCompletedHandler(object sender, EventArgs e);

        public delegate void RowSelectedHandler(object sender, EventArgs e);

        public event OperationButtonHandler OperationButtonClick;

        public event OperationCompletedHandler OperationCompleted;

        public event RowSelectedHandler RowSelected;

        private static object dataSourceObject_ = null;

        private bool allowSelect_ = false;

        private bool allowCheck_ = false;

        private string selectColumnHeaderText_ = string.Empty;

        private string selectRowText_ = string.Empty;

        public bool OperationPanelVisible
        {
            get { return this.OperationPanel.Visible; }
            set { this.OperationPanel.Visible = value; }
        }

        private bool ControlVisible
        {
            get { return this.PanelControls.Visible; }
            set
            {
                this.DisplayLabelMessage.Visible = !value;
                this.PanelControls.Visible = value;
            }
        }

        public bool AllowSelect
        {
            get { return allowSelect_; }
            set { allowSelect_ = value; }
        }

        public string SelectColumnHeaderText
        {
            get { return selectColumnHeaderText_; }
            set
            {
                selectColumnHeaderText_ = value;

                if (allowCheck_)
                    this.GridView1.Columns[1].HeaderText = selectColumnHeaderText_;
            }
        }

        public string SelectRowText
        {
            get { return selectRowText_; }
            set
            {
                selectRowText_ = value;

                if (allowCheck_)
                    (this.GridView1.Columns[1] as System.Web.UI.WebControls.CommandField).SelectText = selectRowText_;
            }
        }

        public bool AllowCheck
        {
            get { return allowCheck_; }
            set { allowCheck_ = value; }
        }

        public string OperationButtonText
        {
            get { return this.CustomLinkButtonOperation.Text; }
            set { this.CustomLinkButtonOperation.Text = value; }
        }

        public object DataSource
        {
            get
            {
                dataSourceObject_ = this.GridView1.DataSource;
                return dataSourceObject_;
            }
            set
            {
                dataSourceObject_ = value;
                this.GridView1.DataSource = dataSourceObject_;
            }
        }

        public override void DataBind()
        {
            this.GridView1.DataBind();
            if (this.GridView1.Rows.Count == 0)
            {
                this.ControlVisible = false;
            }
            else
            {
                this.ControlVisible = true;
            }
        }

        public int PageSize
        {
            get { return this.GridView1.PageSize; }
            set { this.GridView1.PageSize = value; }
        }

        public System.Web.UI.WebControls.GridViewRowCollection Rows
        {
            get
            {
                return this.GridView1.Rows;
            }
        }

        public System.Web.UI.WebControls.GridViewRow SelectedRow
        {
            get
            {
                int index = this.GridView1.SelectedIndex;

                return this.GridView1.Rows[index];
            }
        }

        protected void Page_Init(object sender, EventArgs e)
        {
            InitInterface();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            this.GridView1.Columns[0].Visible = allowCheck_;
            this.GridView1.Columns[1].Visible = allowSelect_;

            if (allowCheck_)
            {
                this.GridView1.Columns[1].HeaderText = selectColumnHeaderText_;
                (this.GridView1.Columns[1] as System.Web.UI.WebControls.CommandField).SelectText = selectRowText_;
            }
        }

        private void InitInterface()
        {
            this.CustomLinkButtonOperation.ConfirmMessage = MessageManager.GetValue(MessageKey.AdminD0037);
            this.CustomLinkButtonCancelAll.Text = MessageManager.GetValue(MessageKey.AdminD0093);
            this.CustomLinkButtonSelectAll.Text = MessageManager.GetValue(MessageKey.AdminD0092);
            this.DisplayLabelMessage.Text = MessageManager.GetValue(MessageKey.AdminD0095);
        }

        protected void CustomLinkButtonSelectAll_Click(object sender, EventArgs e)
        {
            foreach (System.Web.UI.WebControls.GridViewRow gvr in this.GridView1.Rows)
            {
                CheckBox cb = (CheckBox)gvr.FindControl("CustomCheckBoxSelect");
                cb.Checked = true;
            }
        }

        protected void CustomLinkButtonCancelAll_Click(object sender, EventArgs e)
        {
            foreach (System.Web.UI.WebControls.GridViewRow gvr in this.GridView1.Rows)
            {
                CheckBox cb = (CheckBox)gvr.FindControl("CustomCheckBoxSelect");
                cb.Checked = false;
            }
        }

        protected void CustomLinkButtonOperation_Click(object sender, EventArgs e)
        {
            foreach (System.Web.UI.WebControls.GridViewRow gvr in this.GridView1.Rows)
            {
                CheckBox cb = (CheckBox)gvr.FindControl("CustomCheckBoxSelect");

                if (cb!=null && cb.Checked == true && this.OperationButtonClick != null)
                {
                    this.OperationButtonClick(gvr, e);
                }
            }

            if (this.OperationCompleted != null)
            {
                this.OperationCompleted(sender, e);
            }
        }

        protected void GridView1_PageIndexChanging(object sender, System.Web.UI.WebControls.GridViewPageEventArgs e)
        {
            if (e.NewPageIndex <= this.GridView1.PageCount)
            {
                this.GridView1.PageIndex = e.NewPageIndex;
            }

            this.GridView1.DataSource = dataSourceObject_;
            this.GridView1.DataBind();
        }

        protected void GridView1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (this.RowSelected != null)
            {
                this.RowSelected(sender, e);
            }
        }

    }
}